@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2018 Neil Lathwood
  * @author     Neil Lathwood <gh+n@laf.io>
@@ -33,7 +32,6 @@ class Template
     public $template;
 
     /**
-     *
      * Get the template details
      *
      * @param null $obj
@@ -48,9 +46,10 @@ class Template
         $this->template = AlertTemplate::whereHas('map', function ($query) use ($obj) {
             $query->where('alert_rule_id', '=', $obj['rule_id']);
         })->first();
-        if (!$this->template) {
+        if (! $this->template) {
             $this->template = AlertTemplate::where('name', '=', 'Default Alert Template')->first();
         }
+
         return $this->template;
     }
 
@@ -65,7 +64,6 @@ class Template
     }
 
     /**
-     *
      * Parse Blade body
      *
      * @param $data
@@ -82,7 +80,6 @@ class Template
     }
 
     /**
-     *
      * Parse Blade title
      *
      * @param $data
@@ -94,12 +91,11 @@ class Template
         try {
             return view(['template' => $data['title']], $alert)->__toString();
         } catch (\Exception $e) {
-            return $data['title'] ?: view(['template' => "Template " . $data['name']], $alert)->__toString();
+            return $data['title'] ?: view(['template' => 'Template ' . $data['name']], $alert)->__toString();
         }
     }
 
     /**
-     *
      * Get the default template
      *
      * @return string
@@ -108,7 +104,7 @@ class Template
     {
         return '{{ $alert->title }}' . PHP_EOL .
             'Severity: {{ $alert->severity }}' . PHP_EOL .
-            '@if ($alert->state == '.AlertState::RECOVERED.')Time elapsed: {{ $alert->elapsed }} @endif ' . PHP_EOL .
+            '@if ($alert->state == ' . AlertState::RECOVERED . ')Time elapsed: {{ $alert->elapsed }} @endif ' . PHP_EOL .
             'Timestamp: {{ $alert->timestamp }}' . PHP_EOL .
             'Unique-ID: {{ $alert->uid }}' . PHP_EOL .
             'Rule: @if ($alert->name) {{ $alert->name }} @else {{ $alert->rule }} @endif ' . PHP_EOL .
