@@ -18,12 +18,10 @@
  * @author f0o <f0o@devilcode.org>
  * @copyright 2014 f0o, LibreNMS
  * @license GPL
- * @package LibreNMS
- * @subpackage Alerts
  */
+
 namespace LibreNMS\Alert\Transport;
 
-use LibreNMS\Enum\AlertState;
 use LibreNMS\Alert\Transport;
 use LibreNMS\Config;
 
@@ -36,9 +34,9 @@ class Irc extends Transport
 
     public function contactIrc($obj, $opts)
     {
-        $f = Config::get('install_dir') . "/.ircbot.alert";
-        if (file_exists($f) && filetype($f) == "fifo") {
-            $f = fopen($f, "w+");
+        $f = Config::get('install_dir') . '/.ircbot.alert';
+        if (file_exists($f) && filetype($f) == 'fifo') {
+            $f = fopen($f, 'w+');
             $r = fwrite($f, json_encode($obj) . "\n");
             $f = fclose($f);
             if ($r === false) {
@@ -61,11 +59,11 @@ class Irc extends Transport
                     'descr' => 'Enable IRC alerts',
                     'type'  => 'checkbox',
                     'default' => true,
-                ]
+                ],
             ],
             'validation' => [
-                'irc' => 'required'
-            ]
+                'irc' => 'required',
+            ],
         ];
     }
 }
