@@ -18,25 +18,24 @@
  * @author  Aldemir Akpinar <aldemir.akpinar@gmail.com>
  * @copyright 2017 Aldemir Akpinar, LibreNMS
  * @license GPL
- * @package LibreNMS
- * @subpackage Alerts
  */
+
 namespace LibreNMS\Alert\Transport;
 
-use LibreNMS\Enum\AlertState;
 use LibreNMS\Alert\Transport;
 
 class Jira extends Transport
 {
     public function deliverAlert($obj, $opts)
     {
-        if (!empty($this->config)) {
+        if (! empty($this->config)) {
             $opts['username'] = $this->config['jira-username'];
             $opts['password'] = $this->config['jira-password'];
             $opts['prjkey'] = $this->config['jira-key'];
             $opts['issuetype'] = $this->config['jira-type'];
             $opts['url'] = $this->config['jira-url'];
         }
+
         return $this->contactJira($obj, $opts);
     }
 
@@ -49,46 +48,48 @@ class Jira extends Transport
 
         $device = device_by_id_cache($obj['device_id']); // for event logging
 
-        $username    = $opts['username'];
-        $password    = $opts['password'];
-        $prjkey      = $opts['prjkey'];
-        $issuetype   = $opts['issuetype'];
-        $details     = "Librenms alert for: " . $obj['hostname'];
+        $username = $opts['username'];
+        $password = $opts['password'];
+        $prjkey = $opts['prjkey'];
+        $issuetype = $opts['issuetype'];
+        $details = 'Librenms alert for: ' . $obj['hostname'];
         $description = $obj['msg'];
-        $url         = $opts['url'] . '/rest/api/latest/issue';
-        $curl        = curl_init();
+        $url = $opts['url'] . '/rest/api/latest/issue';
+        $curl = curl_init();
 
-        $data       = array("project" => array("key" => $prjkey),
-                            "summary" => $details,
-                            "description" => $description,
-                            "issuetype" => array("name" => $issuetype));
-        $postdata   = array("fields" => $data);
+        $data = ['project' => ['key' => $prjkey],
+            'summary' => $details,
+            'description' => $description,
+            'issuetype' => ['name' => $issuetype], ];
+        $postdata = ['fields' => $data];
         $datastring = json_encode($postdata);
 
         set_curl_proxy($curl);
 
-        $headers = array('Accept: application/json', 'Content-Type: application/json');
+        $headers = ['Accept: application/json', 'Content-Type: application/json'];
 
         curl_setopt($curl, CURLOPT_URL, $url);
         curl_setopt($curl, CURLOPT_HTTPHEADER, $headers);
         curl_setopt($curl, CURLOPT_USERPWD, "$username:$password");
-        curl_setopt($curl, CURLOPT_CUSTOMREQUEST, "POST");
+        curl_setopt($curl, CURLOPT_CUSTOMREQUEST, 'POST');
         curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
         curl_setopt($curl, CURLOPT_VERBOSE, 1);
         curl_setopt($curl, CURLOPT_POSTFIELDS, $datastring);
 
-        $ret  = curl_exec($curl);
+        $ret = curl_exec($curl);
         $code = curl_getinfo($curl, CURLINFO_HTTP_CODE);
         if ($code == 200) {
             $jiraout = json_decode($ret, true);
-            d_echo("Created jira issue " . $jiraout['key'] . " for " . $device);
+            d_echo('Created jira issue ' . $jiraout['key'] . ' for ' . $device);
+
             return true;
         } else {
-            d_echo("Jira connection error: " . serialize($ret));
+            d_echo('Jira connection error: ' . serialize($ret));
+
             return false;
         }
     }
-    
+
     public static function configTemplate()
     {
         return [
@@ -97,31 +98,31 @@ class Jira extends Transport
                     'title' => 'URL',
                     'name' => 'jira-url',
                     'descr' => 'Jira URL',
-                    'type' => 'text'
+                    'type' => 'text',
                 ],
                 [
                     'title' => 'Project Key',
                     'name' => 'jira-key',
                     'descr' => 'Jira Project Key',
-                    'type' => 'text'
+                    'type' => 'text',
                 ],
                 [
                     'title' => 'Issue Type',
                     'name' => 'jira-type',
                     'descr' => 'Jira Issue Type',
-                    'type' => 'text'
+                    'type' => 'text',
                 ],
                 [
                     'title' => 'Jira Username',
                     'name' => 'jira-username',
                     'descr' => 'Jira Username',
-                    'type' => 'text'
+                    'type' => 'text',
                 ],
                 [
                     'title' => 'Jira Password',
                     'name' => 'jira-password',
                     'descr' => 'Jira Password',
-                    'type' => 'text'
+                    'type' => 'text',
                 ],
             ],
             'validation' => [
@@ -130,7 +131,7 @@ class Jira extends Transport
                 'jira-type' => 'required|string',
                 'jira-username' => 'required|string',
                 'jira-password' => 'required|string',
-            ]
+            ],
         ];
     }
 }
