@@ -18,21 +18,20 @@
  * @author Celal Emre CICEK <celal.emre@opsgenie.com>
  * @copyright 2017 Celal Emre CICEK
  * @license GPL
- * @package LibreNMS
- * @subpackage Alerts
  */
+
 namespace LibreNMS\Alert\Transport;
 
-use LibreNMS\Enum\AlertState;
 use LibreNMS\Alert\Transport;
 
 class Opsgenie extends Transport
 {
     public function deliverAlert($obj, $opts)
     {
-        if (!empty($this->config)) {
+        if (! empty($this->config)) {
             $opts['url'] = $this->config['genie-url'];
         }
+
         return $this->contactOpsgenie($obj, $opts);
     }
 
@@ -44,16 +43,17 @@ class Opsgenie extends Transport
 
         set_curl_proxy($curl);
         curl_setopt($curl, CURLOPT_URL, $url);
-        curl_setopt($curl, CURLOPT_CUSTOMREQUEST, "POST");
+        curl_setopt($curl, CURLOPT_CUSTOMREQUEST, 'POST');
         curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);
-        curl_setopt($curl, CURLOPT_HTTPHEADER, array('Content-Type: application/json'));
+        curl_setopt($curl, CURLOPT_HTTPHEADER, ['Content-Type: application/json']);
         curl_setopt($curl, CURLOPT_POSTFIELDS, json_encode($obj));
 
-        $ret  = curl_exec($curl);
+        $ret = curl_exec($curl);
         $code = curl_getinfo($curl, CURLINFO_HTTP_CODE);
 
         if ($code != 200) {
-            var_dump("Error when sending post request to OpsGenie. Response code: " . $code . " Response body: " . $ret); //FIXME: proper debugging
+            var_dump('Error when sending post request to OpsGenie. Response code: ' . $code . ' Response body: ' . $ret); //FIXME: proper debugging
+
             return false;
         }
 
@@ -68,12 +68,12 @@ class Opsgenie extends Transport
                     'title' => 'Webhook URL',
                     'name' => 'genie-url',
                     'descr' => 'OpsGenie Webhook URL',
-                    'type' => 'text'
-                ]
+                    'type' => 'text',
+                ],
             ],
             'validation' => [
-                'genie-url' => 'required|url'
-            ]
+                'genie-url' => 'required|url',
+            ],
         ];
     }
 }
