@@ -18,8 +18,6 @@
  * @author f0o <f0o@devilcode.org>
  * @copyright 2015 f0o, LibreNMS
  * @license GPL
- * @package LibreNMS
- * @subpackage Alerts
  */
 
 namespace LibreNMS\Alert\Transport;
@@ -27,8 +25,8 @@ namespace LibreNMS\Alert\Transport;
 use GuzzleHttp\Client;
 use GuzzleHttp\Exception\GuzzleException;
 use Illuminate\Http\Request;
-use LibreNMS\Enum\AlertState;
 use LibreNMS\Alert\Transport;
+use LibreNMS\Enum\AlertState;
 use Log;
 use Validator;
 
@@ -45,6 +43,7 @@ class Pagerduty extends Transport
         } else {
             $obj['event_type'] = 'trigger';
         }
+
         return $this->contactPagerduty($obj, $this->config);
     }
 
@@ -58,7 +57,7 @@ class Pagerduty extends Transport
         $data = [
             'routing_key'  => $config['service_key'],
             'event_action' => $obj['event_type'],
-            'dedup_key'    => (string)$obj['alert_id'],
+            'dedup_key'    => (string) $obj['alert_id'],
             'payload'    => [
                 'custom_details'  => strip_tags($obj['msg']) ?: 'Test',
                 'device_groups'   => \DeviceCache::get($obj['device_id'])->groups->pluck('name'),
@@ -71,8 +70,11 @@ class Pagerduty extends Transport
         $url = 'https://events.pagerduty.com/v2/enqueue';
         $client = new Client();
 
+        $request_opts = ['json' => $data];
+        $request_opts['proxy'] = get_proxy();
+
         try {
-            $result = $client->request('POST', $url, ['json' => $data]);
+            $result = $client->request('POST', $url, $request_opts);
 
             if ($result->getStatusCode() == 202) {
                 return true;
@@ -80,7 +82,7 @@ class Pagerduty extends Transport
 
             return $result->getReasonPhrase();
         } catch (GuzzleException $e) {
-            return "Request to PagerDuty API failed. " . $e->getMessage();
+            return 'Request to PagerDuty API failed. ' . $e->getMessage();
         }
     }
 
@@ -94,7 +96,7 @@ class Pagerduty extends Transport
                     'type'  => 'oauth',
                     'icon'  => 'pagerduty-white.svg',
                     'class' => 'btn-success',
-                    'url'   => 'https://connect.pagerduty.com/connect?vendor=' . self::$integrationKey . '&callback='
+                    'url'   => 'https://connect.pagerduty.com/connect?vendor=' . self::$integrationKey . '&callback=',
                 ],
                 [
                     'title' => 'Account',
@@ -110,9 +112,9 @@ class Pagerduty extends Transport
                     'title' => 'Integration Key',
                     'type'  => 'text',
                     'name'  => 'service_key',
-                ]
+                ],
             ],
-            'validation' => []
+            'validation' => [],
         ];
     }
 
@@ -126,15 +128,16 @@ class Pagerduty extends Transport
 
         if ($validator->fails()) {
             Log::error('Pagerduty oauth failed validation.', ['request' => $request->all()]);
+
             return false;
         }
 
         $config = json_encode($request->only('account', 'service_key', 'service_name'));
 
         if ($id = $request->get('id')) {
-            return (bool)dbUpdate(['transport_config' => $config], 'alert_transports', 'transport_id=?', [$id]);
+            return (bool) dbUpdate(['transport_config' => $config], 'alert_transports', 'transport_id=?', [$id]);
         } else {
-            return (bool)dbInsert([
+            return (bool) dbInsert([
                 'transport_name' => $request->get('service_name', 'PagerDuty'),
                 'transport_type' => 'pagerduty',
                 'is_default' => 0,
