@@ -18,44 +18,44 @@
  * @author f0o <f0o@librenms.org>
  * @copyright 2015 f0o, LibreNMS
  * @license GPL
- * @package LibreNMS
- * @subpackage Alerts
  */
+
 namespace LibreNMS\Alert\Transport;
 
-use LibreNMS\Enum\AlertState;
 use LibreNMS\Alert\Transport;
 
 class Playsms extends Transport
 {
     public function deliverAlert($obj, $opts)
     {
-        $playsms_opts['url']   = $this->config['playsms-url'];
-        $playsms_opts['user']  = $this->config['playsms-user'];
+        $playsms_opts['url'] = $this->config['playsms-url'];
+        $playsms_opts['user'] = $this->config['playsms-user'];
         $playsms_opts['token'] = $this->config['playsms-token'];
-        $playsms_opts['from']  = $this->config['playsms-from'];
-        $playsms_opts['to']    = preg_split('/([,\r\n]+)/', $this->config['playsms-mobiles']);
+        $playsms_opts['from'] = $this->config['playsms-from'];
+        $playsms_opts['to'] = preg_split('/([,\r\n]+)/', $this->config['playsms-mobiles']);
+
         return $this->contactPlaysms($obj, $playsms_opts);
     }
 
     public static function contactPlaysms($obj, $opts)
     {
-        $data = array("u" => $opts['user'], "h" => $opts['token'], "to" => implode(',', $opts['to']), "msg" => $obj['title']);
-        if (!empty($opts['from'])) {
-            $data["from"] = $opts['from'];
+        $data = ['u' => $opts['user'], 'h' => $opts['token'], 'to' => implode(',', $opts['to']), 'msg' => $obj['title']];
+        if (! empty($opts['from'])) {
+            $data['from'] = $opts['from'];
         }
-        $url  = $opts['url'] . '&op=pv&' . http_build_query($data);
+        $url = $opts['url'] . '&op=pv&' . http_build_query($data);
         $curl = curl_init($url);
 
         set_curl_proxy($curl);
-        curl_setopt($curl, CURLOPT_CUSTOMREQUEST, "GET");
+        curl_setopt($curl, CURLOPT_CUSTOMREQUEST, 'GET');
         curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
 
-        $ret  = curl_exec($curl);
+        $ret = curl_exec($curl);
         $code = curl_getinfo($curl, CURLINFO_HTTP_CODE);
         if ($code > 202) {
             return var_dump($ret);
         }
+
         return true;
     }
 
@@ -99,7 +99,7 @@ class Playsms extends Transport
                 'playsms-user'    => 'required|string',
                 'playsms-token'   => 'required|string',
                 'playsms-mobiles' => 'required',
-            ]
+            ],
         ];
     }
 }
