@@ -18,12 +18,10 @@
  * @author ToeiRei <vbauer@stargazer.at>
  * @copyright 2017 ToeiRei, LibreNMS work based on the work of f0o. It's his work.
  * @license GPL
- * @package LibreNMS
- * @subpackage Alerts
  */
+
 namespace LibreNMS\Alert\Transport;
 
-use LibreNMS\Enum\AlertState;
 use LibreNMS\Alert\Transport;
 
 class Rocket extends Transport
@@ -38,40 +36,42 @@ class Rocket extends Transport
 
     public static function contactRocket($obj, $api)
     {
-        $host          = $api['url'];
-        $curl          = curl_init();
-        $rocket_msg    = strip_tags($obj['msg']);
-        $color         = self::getColorForState($obj['state']);
-        $data          = array(
-            'attachments' => array(
-                0 => array(
+        $host = $api['url'];
+        $curl = curl_init();
+        $rocket_msg = strip_tags($obj['msg']);
+        $color = self::getColorForState($obj['state']);
+        $data = [
+            'attachments' => [
+                0 => [
                     'fallback' => $rocket_msg,
                     'color' => $color,
                     'title' => $obj['title'],
                     'text' => $rocket_msg,
-                )
-            ),
+                ],
+            ],
             'channel' => $api['channel'],
             'username' => $api['username'],
             'icon_url' => $api['icon_url'],
             'icon_emoji' => $api['icon_emoji'],
-        );
+        ];
         $alert_message = json_encode($data);
-        curl_setopt($curl, CURLOPT_HTTPHEADER, array('Content-Type: application/json'));
+        curl_setopt($curl, CURLOPT_HTTPHEADER, ['Content-Type: application/json']);
         set_curl_proxy($curl);
         curl_setopt($curl, CURLOPT_URL, $host);
         curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);
         curl_setopt($curl, CURLOPT_POST, true);
         curl_setopt($curl, CURLOPT_POSTFIELDS, $alert_message);
 
-        $ret  = curl_exec($curl);
+        $ret = curl_exec($curl);
         $code = curl_getinfo($curl, CURLINFO_HTTP_CODE);
         if ($code != 200) {
             var_dump("API '$host' returned Error"); //FIXME: propper debuging
-            var_dump("Params: " . $alert_message); //FIXME: propper debuging
-            var_dump("Return: " . $ret); //FIXME: propper debuging
+            var_dump('Params: ' . $alert_message); //FIXME: propper debuging
+            var_dump('Return: ' . $ret); //FIXME: propper debuging
+
             return 'HTTP Status code ' . $code;
         }
+
         return true;
     }
 
@@ -90,11 +90,11 @@ class Rocket extends Transport
                     'name' => 'rocket-options',
                     'descr' => 'Rocket.chat Options',
                     'type' => 'textarea',
-                ]
+                ],
             ],
             'validation' => [
                 'rocket-url' => 'required|url',
-            ]
+            ],
         ];
     }
 }
