@@ -18,12 +18,10 @@
  * @author f0o <f0o@devilcode.org>
  * @copyright 2014 f0o, LibreNMS
  * @license GPL
- * @package LibreNMS
- * @subpackage Alerts
  */
+
 namespace LibreNMS\Alert\Transport;
 
-use LibreNMS\Enum\AlertState;
 use LibreNMS\Alert\Transport;
 
 class Slack extends Transport
@@ -38,11 +36,11 @@ class Slack extends Transport
 
     public static function contactSlack($obj, $api)
     {
-        $host          = $api['url'];
-        $curl          = curl_init();
-        $slack_msg     = strip_tags($obj['msg']);
-        $color         = self::getColorForState($obj['state']);
-        $data          = [
+        $host = $api['url'];
+        $curl = curl_init();
+        $slack_msg = strip_tags($obj['msg']);
+        $color = self::getColorForState($obj['state']);
+        $data = [
             'attachments' => [
                 0 => [
                     'fallback' => $slack_msg,
@@ -55,7 +53,7 @@ class Slack extends Transport
             ],
             'channel' => $api['channel'],
             'username' => $api['username'],
-            'icon_emoji' => ':' .$api['icon_emoji'].':',
+            'icon_emoji' => ':' . $api['icon_emoji'] . ':',
         ];
         $alert_message = json_encode($data);
         curl_setopt($curl, CURLOPT_HTTPHEADER, ['Content-Type: application/json']);
@@ -65,14 +63,16 @@ class Slack extends Transport
         curl_setopt($curl, CURLOPT_POST, true);
         curl_setopt($curl, CURLOPT_POSTFIELDS, $alert_message);
 
-        $ret  = curl_exec($curl);
+        $ret = curl_exec($curl);
         $code = curl_getinfo($curl, CURLINFO_HTTP_CODE);
         if ($code != 200) {
             var_dump("API '$host' returned Error"); //FIXME: propper debuging
-            var_dump("Params: " . $alert_message); //FIXME: propper debuging
-            var_dump("Return: " . $ret); //FIXME: propper debuging
+            var_dump('Params: ' . $alert_message); //FIXME: propper debuging
+            var_dump('Return: ' . $ret); //FIXME: propper debuging
+
             return 'HTTP Status code ' . $code;
         }
+
         return true;
     }
 
@@ -91,11 +91,11 @@ class Slack extends Transport
                     'name' => 'slack-options',
                     'descr' => 'Slack Options',
                     'type' => 'textarea',
-                ]
+                ],
             ],
             'validation' => [
                 'slack-url' => 'required|url',
-            ]
+            ],
         ];
     }
 }
