@@ -14,20 +14,22 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>. */
+
 namespace LibreNMS\Alert\Transport;
 
-use LibreNMS\Enum\AlertState;
 use LibreNMS\Alert\Transport;
+use LibreNMS\Enum\AlertState;
 
 class Syslog extends Transport
 {
     public function deliverAlert($obj, $opts)
     {
-        if (!empty($this->config)) {
+        if (! empty($this->config)) {
             $opts['syslog_host'] = $this->config['syslog-host'];
             $opts['syslog_port'] = $this->config['syslog-port'];
             $opts['syslog_facility'] = $this->config['syslog-facility'];
         }
+
         return $this->contactSyslog($obj, $opts);
     }
 
@@ -35,60 +37,62 @@ class Syslog extends Transport
     {
         $syslog_host = '127.0.0.1';
         $syslog_port = 514;
-        $state       = "Unknown";
-        $facility    = 24; // Default facility is 3 * 8 (daemon)
-        $severity    = 6; // Default severity is 6 (Informational)
-        $sev_txt     = "OK";
-        $device      = device_by_id_cache($obj['device_id']); // for event logging
+        $state = 'Unknown';
+        $facility = 24; // Default facility is 3 * 8 (daemon)
+        $severity = 6; // Default severity is 6 (Informational)
+        $sev_txt = 'OK';
+        $device = device_by_id_cache($obj['device_id']); // for event logging
 
-        if (!empty($opts['syslog_facility']) && preg_match("/^\d+$/", $opts['syslog_facility'])) {
-            $facility = (int)$opts['syslog_facility'] * 8;
+        if (! empty($opts['syslog_facility']) && preg_match("/^\d+$/", $opts['syslog_facility'])) {
+            $facility = (int) $opts['syslog_facility'] * 8;
         } else {
-            log_event("Syslog facility is not an integer: " . $opts['syslog_facility'], $device, 'poller', 5);
+            log_event('Syslog facility is not an integer: ' . $opts['syslog_facility'], $device, 'poller', 5);
         }
-        if (!empty($opts['syslog_host'])) {
-            if (preg_match("/[a-zA-Z]/", $opts['syslog_host'])) {
+        if (! empty($opts['syslog_host'])) {
+            if (preg_match('/[a-zA-Z]/', $opts['syslog_host'])) {
                 $syslog_host = gethostbyname($opts['syslog_host']);
                 if ($syslog_host === $opts['syslog_host']) {
-                    log_event("Alphanumeric hostname found but does not resolve to an IP.", $device, 'poller', 5);
+                    log_event('Alphanumeric hostname found but does not resolve to an IP.', $device, 'poller', 5);
+
                     return false;
                 }
             } elseif (filter_var($opts['syslog_host'], FILTER_VALIDATE_IP)) {
                 $syslog_host = $opts['syslog_host'];
             } else {
-                log_event("Syslog host is not a valid IP: " . $opts['syslog_host'], $device, 'poller', 5);
+                log_event('Syslog host is not a valid IP: ' . $opts['syslog_host'], $device, 'poller', 5);
+
                 return false;
             }
         } else {
-            log_event("Syslog host is empty.", $device, 'poller');
+            log_event('Syslog host is empty.', $device, 'poller');
         }
-        if (!empty($opts['syslog_port']) && preg_match("/^\d+$/", $opts['syslog_port'])) {
+        if (! empty($opts['syslog_port']) && preg_match("/^\d+$/", $opts['syslog_port'])) {
             $syslog_port = $opts['syslog_port'];
         } else {
-            log_event("Syslog port is not an integer.", $device, 'poller', 5);
+            log_event('Syslog port is not an integer.', $device, 'poller', 5);
         }
 
         switch ($obj['severity']) {
-            case "critical":
+            case 'critical':
                 $severity = 2;
-                $sev_txt  = "Critical";
+                $sev_txt = 'Critical';
                 break;
-            case "warning":
+            case 'warning':
                 $severity = 4;
-                $sev_txt  = "Warning";
+                $sev_txt = 'Warning';
                 break;
         }
 
         switch ($obj['state']) {
             case AlertState::RECOVERED:
-                $state    = "OK";
+                $state = 'OK';
                 $severity = 6;
                 break;
             case AlertState::ACTIVE:
                 $state = $sev_txt;
                 break;
             case AlertState::ACKNOWLEDGED:
-                $state    = "Acknowledged";
+                $state = 'Acknowledged';
                 $severity = 6;
                 break;
         }
@@ -111,10 +115,11 @@ class Syslog extends Transport
             . $obj['name'];
 
         if (($socket = socket_create(AF_INET, SOCK_DGRAM, SOL_UDP)) === false) {
-            log_event("socket_create() failed: reason: " . socket_strerror(socket_last_error()), $device, 'poller', 5);
+            log_event('socket_create() failed: reason: ' . socket_strerror(socket_last_error()), $device, 'poller', 5);
+
             return false;
         } else {
-            if (!empty($obj['faults'])) {
+            if (! empty($obj['faults'])) {
                 foreach ($obj['faults'] as $k => $v) {
                     $syslog_msg = $syslog_prefix . ' - ' . $v['string'];
                     socket_sendto($socket, $syslog_msg, strlen($syslog_msg), 0, $syslog_host, $syslog_port);
@@ -125,9 +130,10 @@ class Syslog extends Transport
             }
             socket_close($socket);
         }
+
         return true;
     }
-    
+
     public static function configTemplate()
     {
         return [
@@ -136,26 +142,26 @@ class Syslog extends Transport
                     'title' => 'Host',
                     'name' => 'syslog-host',
                     'descr' => 'Syslog Host',
-                    'type' => 'text'
+                    'type' => 'text',
                 ],
                 [
                     'title' => 'Port',
                     'name' => 'syslog-port',
                     'descr' => 'Syslog Port',
-                    'type' => 'text'
+                    'type' => 'text',
                 ],
                 [
                     'title' => 'Facility',
                     'name' => 'syslog-facility',
                     'descr' => 'Syslog Facility',
-                    'type' => 'text'
-                ]
+                    'type' => 'text',
+                ],
             ],
             'validation' => [
                 'syslog-host' => 'required|string',
                 'syslog-port' => 'required|numeric',
-                'syslog-facility' => 'required|string'
-            ]
+                'syslog-facility' => 'required|string',
+            ],
         ];
     }
 }
