@@ -19,21 +19,21 @@
  * @author laf <neil@librenms.org>
  * @copyright 2015 f0o, laf, LibreNMS
  * @license GPL
- * @package LibreNMS
- * @subpackage Alerts
  */
+
 namespace LibreNMS\Alert\Transport;
 
-use LibreNMS\Enum\AlertState;
 use LibreNMS\Alert\Transport;
+use LibreNMS\Enum\AlertState;
 
 class Victorops extends Transport
 {
     public function deliverAlert($obj, $opts)
     {
-        if (!empty($this->config)) {
+        if (! empty($this->config)) {
             $opts['url'] = $this->config['victorops-url'];
         }
+
         return $this->contactVictorops($obj, $opts);
     }
 
@@ -41,13 +41,13 @@ class Victorops extends Transport
     {
         $url = $opts['url'];
 
-        $protocol = array(
+        $protocol = [
             'entity_id' => strval($obj['id'] ? $obj['id'] : $obj['uid']),
             'state_start_time' => strtotime($obj['timestamp']),
             'entity_display_name' => $obj['title'],
             'state_message' => $obj['msg'],
             'monitoring_tool' => 'librenms',
-        );
+        ];
         if ($obj['state'] == AlertState::RECOVERED) {
             $protocol['message_type'] = 'recovery';
         } elseif ($obj['state'] == AlertState::ACKNOWLEDGED) {
@@ -64,14 +64,16 @@ class Victorops extends Transport
         set_curl_proxy($curl);
         curl_setopt($curl, CURLOPT_URL, $url);
         curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);
-        curl_setopt($curl, CURLOPT_HTTPHEADER, array('Content-type' => 'application/json'));
+        curl_setopt($curl, CURLOPT_HTTPHEADER, ['Content-type' => 'application/json']);
         curl_setopt($curl, CURLOPT_POSTFIELDS, json_encode($protocol));
-        $ret  = curl_exec($curl);
+        $ret = curl_exec($curl);
         $code = curl_getinfo($curl, CURLINFO_HTTP_CODE);
         if ($code != 200) {
-            var_dump("VictorOps returned Error, retry later"); //FIXME: propper debuging
+            var_dump('VictorOps returned Error, retry later'); //FIXME: propper debuging
+
             return false;
         }
+
         return true;
     }
 
@@ -83,12 +85,12 @@ class Victorops extends Transport
                     'title' => 'Post URL',
                     'name' => 'victorops-url',
                     'descr' => 'Victorops Post URL',
-                    'type' => 'text'
-                ]
+                    'type' => 'text',
+                ],
             ],
             'validation' => [
-                'victorops-url' => 'required|string'
-            ]
+                'victorops-url' => 'required|string',
+            ],
         ];
     }
 }
