@@ -17,15 +17,14 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2017 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
  */
+
 namespace LibreNMS\Authentication;
 
 use LibreNMS\Interfaces\Authentication\Authorizer;
-use Session;
 
 abstract class AuthorizerBase implements Authorizer
 {
