@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2018 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
@@ -25,11 +24,12 @@
 
 namespace LibreNMS\DB;
 
+use DB;
 use Illuminate\Support\Str;
 use LibreNMS\Config;
 use LibreNMS\Util\Version;
+use Schema as LaravelSchema;
 use Symfony\Component\Yaml\Yaml;
-use \Schema as LaravelSchema;
 
 class Schema
 {
@@ -75,6 +75,7 @@ class Schema
             ->map(function ($migration_file) {
                 return basename($migration_file, '.php');
             });
+
         return $migrations;
     }
 
@@ -102,7 +103,7 @@ class Schema
 
     public function getSchema()
     {
-        if (!isset($this->schema)) {
+        if (! isset($this->schema)) {
             $file = Config::get('install_dir') . '/misc/db_schema.yaml';
             $this->schema = Yaml::parse(file_get_contents($file));
         }
@@ -129,6 +130,7 @@ class Schema
     public function getColumns($table)
     {
         $schema = $this->getSchema();
+
         return array_column($schema[$table]['Columns'], 'Field');
     }
 
@@ -163,7 +165,7 @@ class Schema
 
             $cache = [
                 'version' => $db_version,
-                $base => $paths
+                $base => $paths,
             ];
 
             if (is_writable($cache_file)) {
@@ -201,25 +203,27 @@ class Schema
     {
         $relationships = $this->getTableRelationships();
 
-        d_echo("Starting Tables: " . json_encode($tables) . PHP_EOL);
-        if (!empty($history)) {
+        d_echo('Starting Tables: ' . json_encode($tables) . PHP_EOL);
+        if (! empty($history)) {
             $tables = array_diff($tables, $history);
-            d_echo("Filtered Tables: " . json_encode($tables) . PHP_EOL);
+            d_echo('Filtered Tables: ' . json_encode($tables) . PHP_EOL);
         }
 
         foreach ($tables as $table) {
             // check for direct relationships
             if (in_array($table, $relationships[$target])) {
                 d_echo("Direct relationship found $target -> $table\n");
+
                 return [$table, $target];
             }
 
             $table_relations = $relationships[$table] ?? [];
             d_echo("Searching $table: " . json_encode($table_relations) . PHP_EOL);
 
-            if (!empty($table_relations)) {
+            if (! empty($table_relations)) {
                 if (in_array($target, $relationships[$table])) {
                     d_echo("Found in $table\n");
+
                     return [$target, $table]; // found it
                 } else {
                     $recurse = $this->findPathRecursive($relationships[$table], $target, array_merge($history, $tables));
@@ -245,7 +249,7 @@ class Schema
 
     public function getTableRelationships()
     {
-        if (!isset($this->relationships)) {
+        if (! isset($this->relationships)) {
             $schema = $this->getSchema();
 
             $relations = array_column(array_map(function ($table, $data) {
@@ -284,7 +288,7 @@ class Schema
             // try to guess assuming key_id = keys table
             $guessed_table = substr($key, 0, -3);
 
-            if (!Str::endsWith($guessed_table, 's')) {
+            if (! Str::endsWith($guessed_table, 's')) {
                 if (Str::endsWith($guessed_table, 'x')) {
                     $guessed_table .= 'es';
                 } else {
@@ -304,4 +308,81 @@ class Schema
     {
         return in_array($column, $this->getColumns($table));
     }
+
+    /**
+     * Dump the database schema to an array.
+     * The top level will be a list of tables
+     * Each table contains the keys Columns and Indexes.
+     *
+     * Each entry in the Columns array contains these keys: Field, Type, Null, Default, Extra
+     * Each entry in the Indexes array contains these keys: Name, Columns(array), Unique
+     *
+     * @param string $connection use a specific connection
+     * @return array
+     */
+    public static function dump($connection = null)
+    {
+        $output = [];
+        $db_name = DB::connection($connection)->getDatabaseName();
+
+        foreach (DB::connection($connection)->select(DB::raw("SELECT TABLE_NAME FROM information_schema.TABLES WHERE TABLE_SCHEMA = '$db_name' ORDER BY TABLE_NAME;")) as $table) {
+            $table = $table->TABLE_NAME;
+            foreach (DB::connection($connection)->select(DB::raw("SELECT COLUMN_NAME, COLUMN_TYPE, IS_NULLABLE, COLUMN_DEFAULT, EXTRA FROM information_schema.COLUMNS WHERE TABLE_SCHEMA = '$db_name' AND TABLE_NAME='$table'")) as $data) {
+                $def = [
+                    'Field' => $data->COLUMN_NAME,
+                    'Type' => preg_replace('/int\([0-9]+\)/', 'int', $data->COLUMN_TYPE),
+                    'Null' => $data->IS_NULLABLE === 'YES',
+                    'Extra' => str_replace('current_timestamp()', 'CURRENT_TIMESTAMP', $data->EXTRA),
+                ];
+
+                if (isset($data->COLUMN_DEFAULT) && $data->COLUMN_DEFAULT != 'NULL') {
+                    $default = trim($data->COLUMN_DEFAULT, "'");
+                    $def['Default'] = str_replace('current_timestamp()', 'CURRENT_TIMESTAMP', $default);
+                }
+                // MySQL 8 fix, remove DEFAULT_GENERATED from timestamp extra columns
+                if ($def['Type'] == 'timestamp') {
+                    $def['Extra'] = preg_replace('/DEFAULT_GENERATED[ ]*/', '', $def['Extra']);
+                }
+
+                $output[$table]['Columns'][] = $def;
+            }
+
+            $keys = DB::connection($connection)->select(DB::raw("SHOW INDEX FROM `$table`"));
+            usort($keys, function ($a, $b) {
+                return $a->Key_name <=> $b->Key_name;
+            });
+            foreach ($keys as $key) {
+                $key_name = $key->Key_name;
+                if (isset($output[$table]['Indexes'][$key_name])) {
+                    $output[$table]['Indexes'][$key_name]['Columns'][] = $key->Column_name;
+                } else {
+                    $output[$table]['Indexes'][$key_name] = [
+                        'Name' => $key->Key_name,
+                        'Columns' => [$key->Column_name],
+                        'Unique' => ! $key->Non_unique,
+                        'Type' => $key->Index_type,
+                    ];
+                }
+            }
+
+            $create = DB::connection($connection)->select(DB::raw("SHOW CREATE TABLE `$table`"))[0];
+
+            if (isset($create->{'Create Table'})) {
+                $constraint_regex = '/CONSTRAINT `(?<name>[A-Za-z_0-9]+)` FOREIGN KEY \(`(?<foreign_key>[A-Za-z_0-9]+)`\) REFERENCES `(?<table>[A-Za-z_0-9]+)` \(`(?<key>[A-Za-z_0-9]+)`\) ?(?<extra>[ A-Z]+)?/';
+                $constraint_count = preg_match_all($constraint_regex, $create->{'Create Table'}, $constraints);
+                for ($i = 0; $i < $constraint_count; $i++) {
+                    $constraint_name = $constraints['name'][$i];
+                    $output[$table]['Constraints'][$constraint_name] = [
+                        'name' => $constraint_name,
+                        'foreign_key' => $constraints['foreign_key'][$i],
+                        'table' => $constraints['table'][$i],
+                        'key' => $constraints['key'][$i],
+                        'extra' => $constraints['extra'][$i],
+                    ];
+                }
+            }
+        }
+
+        return $output;
+    }
 }
