@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2017 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
@@ -26,7 +25,6 @@
 namespace LibreNMS\Device;
 
 use Illuminate\Support\Str;
-use LibreNMS\Config;
 use LibreNMS\Interfaces\Discovery\DiscoveryItem;
 use LibreNMS\Interfaces\Discovery\DiscoveryModule;
 use LibreNMS\Interfaces\Discovery\ProcessorDiscovery;
@@ -84,7 +82,7 @@ class Processor extends Model implements DiscoveryModule, PollerModule, Discover
         $proc = new static();
         $proc->processor_type = $type;
         $proc->device_id = $device_id;
-        $proc->processor_index = (string)$index;
+        $proc->processor_index = (string) $index;
         $proc->processor_descr = $description;
         $proc->processor_precision = $precision;
         $proc->processor_usage = $current_usage;
@@ -99,8 +97,7 @@ class Processor extends Model implements DiscoveryModule, PollerModule, Discover
         }
         $proc->processor_oid = '.' . ltrim($oid, '.');
 
-
-        if (!is_null($warn_percent)) {
+        if (! is_null($warn_percent)) {
             $proc->processor_perc_warn = $warn_percent;
         }
 
@@ -108,7 +105,7 @@ class Processor extends Model implements DiscoveryModule, PollerModule, Discover
         if (is_null($proc->processor_usage)) {
             $data = snmp_get(device_by_id_cache($proc->device_id), $proc->processor_oid, '-Ovq');
             $proc->valid = ($data !== false);
-            if (!$proc->valid) {
+            if (! $proc->valid) {
                 return $proc;
             }
             $proc->processor_usage = static::processData($data, $proc->processor_precision);
@@ -161,14 +158,14 @@ class Processor extends Model implements DiscoveryModule, PollerModule, Discover
             );
         }
 
-        dbDeleteOrphans(static::$table, array('devices.device_id'));
+        dbDeleteOrphans(static::$table, ['devices.device_id']);
 
         echo PHP_EOL;
     }
 
     public static function poll(OS $os)
     {
-        $processors = dbFetchRows('SELECT * FROM processors WHERE device_id=?', array($os->getDeviceId()));
+        $processors = dbFetchRows('SELECT * FROM processors WHERE device_id=?', [$os->getDeviceId()]);
 
         if ($os instanceof ProcessorPolling) {
             $data = $os->pollProcessors($processors);
@@ -184,18 +181,18 @@ class Processor extends Model implements DiscoveryModule, PollerModule, Discover
             /** @var string $processor_type */
             /** @var int $processor_index */
             /** @var int $processor_usage */
-
+            /** @var string $processor_descr */
             if (array_key_exists($processor_id, $data)) {
                 $usage = round($data[$processor_id], 2);
-                echo "$usage%\n";
+                echo "$processor_descr: $usage%\n";
 
-                $rrd_name = array('processor', $processor_type, $processor_index);
+                $rrd_name = ['processor', $processor_type, $processor_index];
                 $fields = compact('usage');
                 $tags = compact('processor_type', 'processor_index', 'rrd_name', 'rrd_def');
-                data_update($os->getDevice(), 'processors', $tags, $fields);
+                data_update($os->getDeviceArray(), 'processors', $tags, $fields);
 
                 if ($usage != $processor_usage) {
-                    dbUpdate(array('processor_usage' => $usage), 'processors', '`processor_id` = ?', array($processor_id));
+                    dbUpdate(['processor_usage' => $usage], 'processors', '`processor_id` = ?', [$processor_id]);
                 }
             }
         }
@@ -204,21 +201,21 @@ class Processor extends Model implements DiscoveryModule, PollerModule, Discover
     private static function pollProcessors(OS $os, $processors)
     {
         if (empty($processors)) {
-            return array();
+            return [];
         }
 
         $oids = array_column($processors, 'processor_oid');
 
         // don't fetch too many at a time TODO build into snmp_get_multi_oid?
-        $snmp_data = array();
-        foreach (array_chunk($oids, get_device_oid_limit($os->getDevice())) as $oid_chunk) {
-            $multi_data = snmp_get_multi_oid($os->getDevice(), $oid_chunk);
+        $snmp_data = [];
+        foreach (array_chunk($oids, get_device_oid_limit($os->getDeviceArray())) as $oid_chunk) {
+            $multi_data = snmp_get_multi_oid($os->getDeviceArray(), $oid_chunk);
             $snmp_data = array_merge($snmp_data, $multi_data);
         }
 
         d_echo($snmp_data);
 
-        $results = array();
+        $results = [];
         foreach ($processors as $processor) {
             if (isset($snmp_data[$processor['processor_oid']])) {
                 $value = static::processData(
@@ -252,16 +249,16 @@ class Processor extends Model implements DiscoveryModule, PollerModule, Discover
 
     public static function processYaml(OS $os)
     {
-        $device = $os->getDevice();
+        $device = $os->getDeviceArray();
         if (empty($device['dynamic_discovery']['modules']['processors'])) {
             d_echo("No YAML Discovery data.\n");
-            return array();
+
+            return [];
         }
 
         return YamlDiscovery::discover($os, get_class(), $device['dynamic_discovery']['modules']['processors']);
     }
 
-
     /**
      * Is this sensor valid?
      * If not, it should not be added to or in the database
@@ -279,21 +276,21 @@ class Processor extends Model implements DiscoveryModule, PollerModule, Discover
      * @param array $exclude exclude columns
      * @return array
      */
-    public function toArray($exclude = array())
+    public function toArray($exclude = [])
     {
-        $array = array(
+        $array = [
             'processor_id' => $this->processor_id,
-            'entPhysicalIndex' => (int)$this->entPhysicalIndex,
-            'hrDeviceIndex' => (int)$this->hrDeviceIndex,
+            'entPhysicalIndex' => (int) $this->entPhysicalIndex,
+            'hrDeviceIndex' => (int) $this->hrDeviceIndex,
             'device_id' => $this->device_id,
             'processor_oid' => $this->processor_oid,
             'processor_index' => $this->processor_index,
             'processor_type' => $this->processor_type,
             'processor_usage' => $this->processor_usage,
             'processor_descr' => $this->processor_descr,
-            'processor_precision' => (int)$this->processor_precision,
-            'processor_perc_warn' => (int)$this->processor_perc_warn,
-        );
+            'processor_precision' => (int) $this->processor_precision,
+            'processor_perc_warn' => (int) $this->processor_perc_warn,
+        ];
 
         return array_diff_key($array, array_flip($exclude));
     }
