@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2017 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
@@ -99,7 +98,7 @@ class Sensor implements DiscoveryModule, PollerModule
     ) {
         $this->type = $type;
         $this->device_id = $device_id;
-        $this->oids = (array)$oids;
+        $this->oids = (array) $oids;
         $this->subtype = $subtype;
         $this->index = $index;
         $this->description = $description;
@@ -123,7 +122,7 @@ class Sensor implements DiscoveryModule, PollerModule
         // validity not checked yet
         if (is_null($this->current)) {
             $sensor['sensor_oids'] = $this->oids;
-            $sensors = array($sensor);
+            $sensors = [$sensor];
 
             $prefetch = self::fetchSnmpData(device_by_id_cache($device_id), $sensors);
             $data = static::processSensorData($sensors, $prefetch);
@@ -159,7 +158,7 @@ class Sensor implements DiscoveryModule, PollerModule
             if (empty($update)) {
                 echo '.';
             } else {
-                dbUpdate($this->escapeNull($update), $this->getTable(), '`sensor_id`=?', array($this->sensor_id));
+                dbUpdate($this->escapeNull($update), $this->getTable(), '`sensor_id`=?', [$this->sensor_id]);
                 echo 'U';
             }
         } else {
@@ -187,16 +186,17 @@ class Sensor implements DiscoveryModule, PollerModule
         if (isset($this->sensor_id)) {
             return dbFetchRow(
                 "SELECT `$table` FROM ? WHERE `sensor_id`=?",
-                array($this->sensor_id)
+                [$this->sensor_id]
             );
         }
 
         $sensor = dbFetchRow(
             "SELECT * FROM `$table` " .
-            "WHERE `device_id`=? AND `sensor_class`=? AND `sensor_type`=? AND `sensor_index`=?",
-            array($this->device_id, $this->type, $this->subtype, $this->index)
+            'WHERE `device_id`=? AND `sensor_class`=? AND `sensor_type`=? AND `sensor_index`=?',
+            [$this->device_id, $this->type, $this->subtype, $this->index]
         );
         $this->sensor_id = $sensor['sensor_id'];
+
         return $sensor;
     }
 
@@ -217,7 +217,7 @@ class Sensor implements DiscoveryModule, PollerModule
      */
     protected function toArray()
     {
-        return array(
+        return [
             'sensor_class' => $this->type,
             'device_id' => $this->device_id,
             'sensor_oids' => json_encode($this->oids),
@@ -234,7 +234,7 @@ class Sensor implements DiscoveryModule, PollerModule
             'sensor_current' => $this->current,
             'entPhysicalIndex' => $this->entPhysicalIndex,
             'entPhysicalIndex_measured' => $this->entPhysicalMeasured,
-        );
+        ];
     }
 
     /**
@@ -247,7 +247,7 @@ class Sensor implements DiscoveryModule, PollerModule
     private function escapeNull($array)
     {
         return array_map(function ($value) {
-            return is_null($value) ? array('NULL') : $value;
+            return is_null($value) ? ['NULL'] : $value;
         }, $array);
     }
 
@@ -274,8 +274,8 @@ class Sensor implements DiscoveryModule, PollerModule
         $params = [$os->getDeviceId()];
 
         $submodules = Config::get('poller_submodules.wireless', []);
-        if (!empty($submodules)) {
-            $query .= " AND `sensor_class` IN " . dbGenPlaceholders(count($submodules));
+        if (! empty($submodules)) {
+            $query .= ' AND `sensor_class` IN ' . dbGenPlaceholders(count($submodules));
             $params = array_merge($params, $submodules);
         }
 
@@ -285,15 +285,16 @@ class Sensor implements DiscoveryModule, PollerModule
             function ($carry, $sensor) {
                 $sensor['sensor_oids'] = json_decode($sensor['sensor_oids']);
                 $carry[$sensor['sensor_class']][] = $sensor;
+
                 return $carry;
             },
-            array()
+            []
         );
 
         foreach ($sensors as $type => $type_sensors) {
             // check for custom polling
             $typeInterface = static::getPollingInterface($type);
-            if (!interface_exists($typeInterface)) {
+            if (! interface_exists($typeInterface)) {
                 echo "ERROR: Polling Interface doesn't exist! $typeInterface\n";
             }
 
@@ -306,7 +307,7 @@ class Sensor implements DiscoveryModule, PollerModule
 
         // pre-fetch all standard sensors
         $standard_sensors = collect($sensors)->flatten(1)->all();
-        $pre_fetch = self::fetchSnmpData($os->getDevice(), $standard_sensors);
+        $pre_fetch = self::fetchSnmpData($os->getDeviceArray(), $standard_sensors);
 
         // poll standard sensors
         foreach ($sensors as $type => $type_sensors) {
@@ -322,7 +323,7 @@ class Sensor implements DiscoveryModule, PollerModule
      * @param array $sensors
      * @param array $prefetch
      */
-    protected static function pollSensorType($os, $type, $sensors, $prefetch = array())
+    protected static function pollSensorType($os, $type, $sensors, $prefetch = [])
     {
         echo "$type:\n";
 
@@ -353,7 +354,7 @@ class Sensor implements DiscoveryModule, PollerModule
     {
         $oids = self::getOidsFromSensors($sensors, get_device_oid_limit($device));
 
-        $snmp_data = array();
+        $snmp_data = [];
         foreach ($oids as $oid_chunk) {
             $multi_data = snmp_get_multi_oid($device, $oid_chunk, '-OUQnt');
             $snmp_data = array_merge($snmp_data, $multi_data);
@@ -372,7 +373,6 @@ class Sensor implements DiscoveryModule, PollerModule
         return $snmp_data;
     }
 
-
     /**
      * Process the snmp data for the specified sensors
      * Returns an array sensor_id => value
@@ -384,7 +384,7 @@ class Sensor implements DiscoveryModule, PollerModule
      */
     protected static function processSensorData($sensors, $prefetch)
     {
-        $sensor_data = array();
+        $sensor_data = [];
         foreach ($sensors as $sensor) {
             // pull out the data for this sensor
             $requested_oids = array_flip($sensor['sensor_oids']);
@@ -422,7 +422,6 @@ class Sensor implements DiscoveryModule, PollerModule
         return $sensor_data;
     }
 
-
     /**
      * Get a list of unique oids from an array of sensors and break it into chunks.
      *
@@ -435,7 +434,7 @@ class Sensor implements DiscoveryModule, PollerModule
         // Sort the incoming oids and sensors
         $oids = array_reduce($sensors, function ($carry, $sensor) {
             return array_merge($carry, $sensor['sensor_oids']);
-        }, array());
+        }, []);
 
         // only unique oids and chunk
         $oids = array_chunk(array_keys(array_flip($oids)), $chunk);
@@ -446,7 +445,7 @@ class Sensor implements DiscoveryModule, PollerModule
     protected static function discoverType(OS $os, $type)
     {
         $typeInterface = static::getDiscoveryInterface($type);
-        if (!interface_exists($typeInterface)) {
+        if (! interface_exists($typeInterface)) {
             echo "ERROR: Discovery Interface doesn't exist! $typeInterface\n";
         }
 
@@ -455,12 +454,12 @@ class Sensor implements DiscoveryModule, PollerModule
             echo "$type: ";
             $function = static::getDiscoveryMethod($type);
             $sensors = $os->$function();
-            if (!is_array($sensors)) {
+            if (! is_array($sensors)) {
                 c_echo("%RERROR:%n $function did not return an array! Skipping discovery.");
-                $sensors = array();
+                $sensors = [];
             }
         } else {
-            $sensors = array();  // delete non existent sensors
+            $sensors = [];  // delete non existent sensors
         }
 
         self::checkForDuplicateSensors($sensors);
@@ -474,7 +473,7 @@ class Sensor implements DiscoveryModule, PollerModule
 
     private static function checkForDuplicateSensors($sensors)
     {
-        $duplicate_check = array();
+        $duplicate_check = [];
         $dup = false;
 
         foreach ($sensors as $sensor) {
@@ -544,7 +543,7 @@ class Sensor implements DiscoveryModule, PollerModule
     final public static function sync($device_id, $type, array $sensors)
     {
         // save and collect valid ids
-        $valid_sensor_ids = array();
+        $valid_sensor_ids = [];
         foreach ($sensors as $sensor) {
             /** @var $this $sensor */
             if ($sensor->isValid()) {
@@ -566,10 +565,10 @@ class Sensor implements DiscoveryModule, PollerModule
     private static function clean($device_id, $type, $sensor_ids)
     {
         $table = static::$table;
-        $params = array($device_id, $type);
+        $params = [$device_id, $type];
         $where = '`device_id`=? AND `sensor_class`=?';
 
-        if (!empty($sensor_ids)) {
+        if (! empty($sensor_ids)) {
             $where .= ' AND `sensor_id` NOT IN ' . dbGenPlaceholders(count($sensor_ids));
             $params = array_merge($params, $sensor_ids);
         }
@@ -582,7 +581,7 @@ class Sensor implements DiscoveryModule, PollerModule
             $message .= " Deleted: $type {$sensor['sensor_type']} {$sensor['sensor_index']} {$sensor['sensor_descr']}";
             log_event($message, $device_id, static::$table, 3, $sensor['sensor_id']);
         }
-        if (!empty($delete)) {
+        if (! empty($delete)) {
             dbDelete($table, $where, $params);
         }
     }
@@ -601,7 +600,7 @@ class Sensor implements DiscoveryModule, PollerModule
      */
     public static function getTypes($valid = false, $device_id = null)
     {
-        return array();
+        return [];
     }
 
     /**
@@ -621,35 +620,35 @@ class Sensor implements DiscoveryModule, PollerModule
             echo "  {$sensor['sensor_descr']}: $sensor_value " . __(static::$translation_prefix . '.' . $sensor['sensor_class'] . '.unit') . PHP_EOL;
 
             // update rrd and database
-            $rrd_name = array(
+            $rrd_name = [
                 static::$data_name,
                 $sensor['sensor_class'],
                 $sensor['sensor_type'],
-                $sensor['sensor_index']
-            );
+                $sensor['sensor_index'],
+            ];
             $rrd_type = isset($types[$sensor['sensor_class']]['type']) ? strtoupper($types[$sensor['sensor_class']]['type']) : 'GAUGE';
             $rrd_def = RrdDefinition::make()->addDataset('sensor', $rrd_type);
 
-            $fields = array(
+            $fields = [
                 'sensor' => isset($sensor_value) ? $sensor_value : 'U',
-            );
+            ];
 
-            $tags = array(
+            $tags = [
                 'sensor_class' => $sensor['sensor_class'],
                 'sensor_type' => $sensor['sensor_type'],
                 'sensor_descr' => $sensor['sensor_descr'],
                 'sensor_index' => $sensor['sensor_index'],
                 'rrd_name' => $rrd_name,
-                'rrd_def' => $rrd_def
-            );
-            data_update($os->getDevice(), static::$data_name, $tags, $fields);
+                'rrd_def' => $rrd_def,
+            ];
+            data_update($os->getDeviceArray(), static::$data_name, $tags, $fields);
 
-            $update = array(
+            $update = [
                 'sensor_prev' => $sensor['sensor_current'],
                 'sensor_current' => $sensor_value,
-                'lastupdate' => array('NOW()'),
-            );
-            dbUpdate($update, static::$table, "`sensor_id` = ?", array($sensor['sensor_id']));
+                'lastupdate' => ['NOW()'],
+            ];
+            dbUpdate($update, static::$table, '`sensor_id` = ?', [$sensor['sensor_id']]);
         }
     }
 }
