@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2019 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
@@ -29,7 +28,7 @@ class ApiException extends \Exception
 {
     private $output;
 
-    public function __construct($message = "", $output = [])
+    public function __construct($message = '', $output = [])
     {
         parent::__construct($message, 0, null);
         $this->output = $output;
