@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2016 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
@@ -27,7 +26,7 @@ namespace LibreNMS\Exceptions;
 
 class HostUnreachableException extends \Exception
 {
-    protected $reasons = array();
+    protected $reasons = [];
 
     public function __toString()
     {
@@ -35,6 +34,7 @@ class HostUnreachableException extends \Exception
         foreach ($this->reasons as $reason) {
             $string .= "  $reason\n";
         }
+
         return $string;
     }
 
