@@ -3,6 +3,7 @@
 namespace LibreNMS\OS;
 
 use LibreNMS\Device\WirelessSensor;
+use LibreNMS\Interfaces\Discovery\OSDiscovery;
 use LibreNMS\Interfaces\Discovery\Sensors\WirelessDistanceDiscovery;
 use LibreNMS\Interfaces\Discovery\Sensors\WirelessFrequencyDiscovery;
 use LibreNMS\Interfaces\Discovery\Sensors\WirelessPowerDiscovery;
@@ -11,6 +12,7 @@ use LibreNMS\Interfaces\Discovery\Sensors\WirelessRateDiscovery;
 use LibreNMS\OS;
 
 class AirosAfLtu extends OS implements
+    OSDiscovery,
     WirelessDistanceDiscovery,
     WirelessFrequencyDiscovery,
     WirelessPowerDiscovery,
@@ -26,9 +28,10 @@ class AirosAfLtu extends OS implements
     public function discoverWirelessFrequency()
     {
         $oid = '.1.3.6.1.4.1.41112.1.10.1.2.2.0'; //UBNT-AFLTU-MIB::afLTUFrequency.1
-        return array(
+
+        return [
             new WirelessSensor('frequency', $this->getDeviceId(), $oid, 'airos-af-ltu', 1, 'Radio Frequency'),
-        );
+        ];
     }
 
     /**
@@ -39,12 +42,12 @@ class AirosAfLtu extends OS implements
      */
     public function discoverWirelessDistance()
     {
-        $oids = snmpwalk_cache_oid($this->getDevice(), 'afLTUStaRemoteDistance', array(), 'UBNT-AFLTU-MIB', null, '-OteQUsb');
+        $oids = snmpwalk_cache_oid($this->getDeviceArray(), 'afLTUStaRemoteDistance', [], 'UBNT-AFLTU-MIB', null, '-OteQUsb');
 
         foreach ($oids as $index => $entry) {
-            return array(
+            return [
                 new WirelessSensor('distance', $this->getDeviceId(), '.1.3.6.1.4.1.41112.1.10.1.4.1.23.' . $index, 'airos-af-ltu', 1, 'Distance', $entry['afLTUStaRemoteDistance'], 1, 1000), //UBNT-AFLTU-MIB::afLTUStaRemoteDistance
-            );
+            ];
         }
     }
 
@@ -56,14 +59,14 @@ class AirosAfLtu extends OS implements
      */
     public function discoverWirelessPower()
     {
-        $sensors = array();
+        $sensors = [];
 
         $tx_eirp_oid = '.1.3.6.1.4.1.41112.1.10.1.2.6.0'; //UBNT-AFLTU-MIB::afLTUTxEIRP
 
-        $oids = snmpwalk_cache_oid($this->getDevice(), 'afLTUStaRxPower0', array(), 'UBNT-AFLTU-MIB', null, '-OteQUsb');
-        $oids = snmpwalk_cache_oid($this->getDevice(), 'afLTUStaRxPower1', $oids, 'UBNT-AFLTU-MIB', null, '-OteQUsb');
-        $oids = snmpwalk_cache_oid($this->getDevice(), 'afLTUStaIdealRxPower0', $oids, 'UBNT-AFLTU-MIB', null, '-OteQUsb');
-        $oids = snmpwalk_cache_oid($this->getDevice(), 'afLTUStaIdealRxPower1', $oids, 'UBNT-AFLTU-MIB', null, '-OteQUsb');
+        $oids = snmpwalk_cache_oid($this->getDeviceArray(), 'afLTUStaRxPower0', [], 'UBNT-AFLTU-MIB', null, '-OteQUsb');
+        $oids = snmpwalk_cache_oid($this->getDeviceArray(), 'afLTUStaRxPower1', $oids, 'UBNT-AFLTU-MIB', null, '-OteQUsb');
+        $oids = snmpwalk_cache_oid($this->getDeviceArray(), 'afLTUStaIdealRxPower0', $oids, 'UBNT-AFLTU-MIB', null, '-OteQUsb');
+        $oids = snmpwalk_cache_oid($this->getDeviceArray(), 'afLTUStaIdealRxPower1', $oids, 'UBNT-AFLTU-MIB', null, '-OteQUsb');
 
         foreach ($oids as $index => $entry) {
             $sensors[] = new WirelessSensor('power', $this->getDeviceId(), '.1.3.6.1.4.1.41112.1.10.1.4.1.5.' . $index, 'airos-af-ltu-rx-chain-0', 1, 'RX Power Chain 0', $entry['afLTUStaRxPower0']); //UBNT-AFLTU-MIB::afLTUStaRxPower0
@@ -74,6 +77,7 @@ class AirosAfLtu extends OS implements
         }
 
         $sensors[] = new WirelessSensor('power', $this->getDeviceId(), $tx_eirp_oid, 'airos-af-ltu-tx-eirp', 1, 'TX EIRP');
+
         return $sensors;
     }
 
@@ -85,10 +89,10 @@ class AirosAfLtu extends OS implements
      */
     public function discoverWirelessQuality()
     {
-        $sensors = array();
+        $sensors = [];
 
-        $oids = snmpwalk_cache_oid($this->getDevice(), 'afLTUStaRxPowerLevel0', array(), 'UBNT-AFLTU-MIB', null, '-OteQUsb');
-        $oids = snmpwalk_cache_oid($this->getDevice(), 'afLTUStaRxPowerLevel1', $oids, 'UBNT-AFLTU-MIB', null, '-OteQUsb');
+        $oids = snmpwalk_cache_oid($this->getDeviceArray(), 'afLTUStaRxPowerLevel0', [], 'UBNT-AFLTU-MIB', null, '-OteQUsb');
+        $oids = snmpwalk_cache_oid($this->getDeviceArray(), 'afLTUStaRxPowerLevel1', $oids, 'UBNT-AFLTU-MIB', null, '-OteQUsb');
 
         foreach ($oids as $index => $entry) {
             $sensors[] = new WirelessSensor('quality', $this->getDeviceId(), '.1.3.6.1.4.1.41112.1.10.1.4.1.9.' . $index, 'airos-af-ltu-level-rx-chain-0', 1, 'Signal Level Chain 0', $entry['afLTUStaRxPower0']); //UBNT-AFLTU-MIB::afLTUStaRxPowerLevel0
@@ -107,10 +111,10 @@ class AirosAfLtu extends OS implements
      */
     public function discoverWirelessRate()
     {
-        $sensors = array();
+        $sensors = [];
 
-        $oids = snmpwalk_cache_oid($this->getDevice(), 'afLTUStaTxCapacity', array(), 'UBNT-AFLTU-MIB', null, '-OteQUsb');
-        $oids = snmpwalk_cache_oid($this->getDevice(), 'afLTUStaRxCapacity', $oids, 'UBNT-AFLTU-MIB', null, '-OteQUsb');
+        $oids = snmpwalk_cache_oid($this->getDeviceArray(), 'afLTUStaTxCapacity', [], 'UBNT-AFLTU-MIB', null, '-OteQUsb');
+        $oids = snmpwalk_cache_oid($this->getDeviceArray(), 'afLTUStaRxCapacity', $oids, 'UBNT-AFLTU-MIB', null, '-OteQUsb');
 
         foreach ($oids as $index => $entry) {
             $sensors[] = new WirelessSensor('rate', $this->getDeviceId(), '.1.3.6.1.4.1.41112.1.10.1.4.1.3.' . $index, 'airos-af-ltu-tx', 1, 'TX Rate', $entry['afLTUStaTxCapacity'], 1000); //UBNT-AFLTU-MIB::afLTUStaTxCapacity
