@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2017 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
@@ -26,10 +25,8 @@
 namespace LibreNMS\OS;
 
 use LibreNMS\Device\WirelessSensor;
-use LibreNMS\Interfaces\Discovery\ProcessorDiscovery;
 use LibreNMS\Interfaces\Discovery\Sensors\WirelessApCountDiscovery;
 use LibreNMS\Interfaces\Discovery\Sensors\WirelessClientsDiscovery;
-use LibreNMS\OS;
 use LibreNMS\OS\Shared\Cisco;
 
 class Ciscowlc extends Cisco implements
@@ -47,8 +44,8 @@ class Ciscowlc extends Cisco implements
         $ssids = $this->getCacheByIndex('bsnDot11EssSsid', 'AIRESPACE-WIRELESS-MIB');
         $counts = $this->getCacheByIndex('bsnDot11EssNumberOfMobileStations', 'AIRESPACE-WIRELESS-MIB');
 
-        $sensors = array();
-        $total_oids = array();
+        $sensors = [];
+        $total_oids = [];
         $total = 0;
         foreach ($counts as $index => $count) {
             $oid = '.1.3.6.1.4.1.14179.2.1.1.1.38.' . $index;
@@ -66,7 +63,7 @@ class Ciscowlc extends Cisco implements
             );
         }
 
-        if (!empty($counts)) {
+        if (! empty($counts)) {
             $sensors[] = new WirelessSensor(
                 'clients',
                 $this->getDeviceId(),
@@ -89,14 +86,14 @@ class Ciscowlc extends Cisco implements
      */
     public function discoverWirelessApCount()
     {
-        $oids = array(
+        $oids = [
             'CISCO-LWAPP-SYS-MIB::clsSysApConnectCount.0',
             'AIRESPACE-SWITCHING-MIB::agentInventoryMaxNumberOfAPsSupported.0',
-        );
-        $data = snmp_get_multi($this->getDevice(), $oids);
+        ];
+        $data = snmp_get_multi($this->getDeviceArray(), $oids);
 
         if (isset($data[0]['clsSysApConnectCount'])) {
-            return array(
+            return [
                 new WirelessSensor(
                     'ap-count',
                     $this->getDeviceId(),
@@ -112,9 +109,9 @@ class Ciscowlc extends Cisco implements
                     $data[0]['agentInventoryMaxNumberOfAPsSupported'],
                     0
                 ),
-            );
+            ];
         }
 
-        return array();
+        return [];
     }
 }
