@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2017 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
@@ -38,7 +37,7 @@ class Hpmsm extends OS implements WirelessClientsDiscovery
      */
     public function discoverWirelessClients()
     {
-        return array(
+        return [
             new WirelessSensor(
                 'clients',
                 $this->getDeviceId(),
@@ -46,7 +45,7 @@ class Hpmsm extends OS implements WirelessClientsDiscovery
                 'hpmsm',
                 0,
                 'Clients: Total'
-            )
-        );
+            ),
+        ];
     }
 }
