@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2017 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
@@ -52,7 +51,8 @@ class Mimosa extends OS implements
     {
         $tx_oid = '.1.3.6.1.4.1.43356.2.1.2.7.3.0'; // MIMOSA-NETWORKS-BFIVE-MIB::mimosaPerTxRate
         $rx_oid = '.1.3.6.1.4.1.43356.2.1.2.7.4.0'; // MIMOSA-NETWORKS-BFIVE-MIB::mimosaPerRxRate
-        return array(
+
+        return [
             new WirelessSensor(
                 'error-ratio',
                 $this->getDeviceId(),
@@ -75,7 +75,7 @@ class Mimosa extends OS implements
                 1,
                 100
             ),
-        );
+        ];
     }
 
     /**
@@ -86,7 +86,7 @@ class Mimosa extends OS implements
      */
     public function discoverWirelessFrequency()
     {
-        $sensors = array();
+        $sensors = [];
 
         // ptp radios
         $polar = $this->getCacheByIndex('mimosaPolarization', 'MIMOSA-NETWORKS-BFIVE-MIB');
@@ -113,7 +113,7 @@ class Mimosa extends OS implements
 
         // ptmp radios
         $ptmpRadioName = $this->getCacheByIndex('mimosaPtmpChPwrRadioName', 'MIMOSA-NETWORKS-PTMP-MIB');
-        $ptmpFreq = snmpwalk_group($this->getDevice(), 'mimosaPtmpChPwrCntrFreqCur', 'MIMOSA-NETWORKS-PTMP-MIB');
+        $ptmpFreq = snmpwalk_group($this->getDeviceArray(), 'mimosaPtmpChPwrCntrFreqCur', 'MIMOSA-NETWORKS-PTMP-MIB');
 
         foreach ($ptmpFreq as $index => $frequency) {
             $sensors[] = new WirelessSensor(
@@ -145,9 +145,9 @@ class Mimosa extends OS implements
     {
         // FIXME: is Noise different from Noise Floor?
         $polar = $this->getCacheByIndex('mimosaPolarization', 'MIMOSA-NETWORKS-BFIVE-MIB');
-        $oids = snmpwalk_cache_oid($this->getDevice(), 'mimosaRxNoise', array(), 'MIMOSA-NETWORKS-BFIVE-MIB');
+        $oids = snmpwalk_cache_oid($this->getDeviceArray(), 'mimosaRxNoise', [], 'MIMOSA-NETWORKS-BFIVE-MIB');
 
-        $sensors = array();
+        $sensors = [];
         foreach ($oids as $index => $entry) {
             $sensors[] = new WirelessSensor(
                 'noise-floor',
@@ -161,6 +161,7 @@ class Mimosa extends OS implements
                 10
             );
         }
+
         return $sensors;
     }
 
@@ -172,12 +173,12 @@ class Mimosa extends OS implements
      */
     public function discoverWirelessPower()
     {
-        $sensors = array();
+        $sensors = [];
 
         // ptp radios
         $polar = $this->getCacheByIndex('mimosaPolarization', 'MIMOSA-NETWORKS-BFIVE-MIB');
-        $oids = snmpwalk_cache_oid($this->getDevice(), 'mimosaTxPower', array(), 'MIMOSA-NETWORKS-BFIVE-MIB');
-        $oids = snmpwalk_cache_oid($this->getDevice(), 'mimosaRxPower', $oids, 'MIMOSA-NETWORKS-BFIVE-MIB');
+        $oids = snmpwalk_cache_oid($this->getDeviceArray(), 'mimosaTxPower', [], 'MIMOSA-NETWORKS-BFIVE-MIB');
+        $oids = snmpwalk_cache_oid($this->getDeviceArray(), 'mimosaRxPower', $oids, 'MIMOSA-NETWORKS-BFIVE-MIB');
 
         foreach ($oids as $index => $entry) {
             $sensors[] = new WirelessSensor(
@@ -206,7 +207,7 @@ class Mimosa extends OS implements
 
         // ptmp radios
         $ptmpRadioName = $this->getCacheByIndex('mimosaPtmpChPwrRadioName', 'MIMOSA-NETWORKS-PTMP-MIB');
-        $ptmpTxPow = snmpwalk_group($this->getDevice(), 'mimosaPtmpChPwrTxPowerCur', 'MIMOSA-NETWORKS-PTMP-MIB');
+        $ptmpTxPow = snmpwalk_group($this->getDeviceArray(), 'mimosaPtmpChPwrTxPowerCur', 'MIMOSA-NETWORKS-PTMP-MIB');
 
         foreach ($ptmpTxPow as $index => $entry) {
             $sensors[] = new WirelessSensor(
@@ -220,7 +221,7 @@ class Mimosa extends OS implements
             );
         }
 
-        $ptmpRxPow = snmpwalk_group($this->getDevice(), 'mimosaPtmpChPwrMinRxPower', 'MIMOSA-NETWORKS-PTMP-MIB');
+        $ptmpRxPow = snmpwalk_group($this->getDeviceArray(), 'mimosaPtmpChPwrMinRxPower', 'MIMOSA-NETWORKS-PTMP-MIB');
 
         foreach ($ptmpRxPow as $index => $entry) {
             $sensors[] = new WirelessSensor(
@@ -245,10 +246,10 @@ class Mimosa extends OS implements
      */
     public function discoverWirelessRate()
     {
-        $oids = snmpwalk_cache_oid($this->getDevice(), 'mimosaTxPhy', array(), 'MIMOSA-NETWORKS-BFIVE-MIB');
-        $oids = snmpwalk_cache_oid($this->getDevice(), 'mimosaRxPhy', $oids, 'MIMOSA-NETWORKS-BFIVE-MIB');
+        $oids = snmpwalk_cache_oid($this->getDeviceArray(), 'mimosaTxPhy', [], 'MIMOSA-NETWORKS-BFIVE-MIB');
+        $oids = snmpwalk_cache_oid($this->getDeviceArray(), 'mimosaRxPhy', $oids, 'MIMOSA-NETWORKS-BFIVE-MIB');
 
-        $sensors = array();
+        $sensors = [];
         foreach ($oids as $index => $entry) {
             $sensors[] = new WirelessSensor(
                 'rate',
@@ -284,9 +285,9 @@ class Mimosa extends OS implements
     public function discoverWirelessSnr()
     {
         $polar = $this->getCacheByIndex('mimosaPolarization', 'MIMOSA-NETWORKS-BFIVE-MIB');
-        $oids = snmpwalk_cache_oid($this->getDevice(), 'mimosaSNR', array(), 'MIMOSA-NETWORKS-BFIVE-MIB');
+        $oids = snmpwalk_cache_oid($this->getDeviceArray(), 'mimosaSNR', [], 'MIMOSA-NETWORKS-BFIVE-MIB');
 
-        $sensors = array();
+        $sensors = [];
         foreach ($oids as $index => $entry) {
             $sensors[] = new WirelessSensor(
                 'snr',
@@ -300,6 +301,7 @@ class Mimosa extends OS implements
                 10
             );
         }
+
         return $sensors;
     }
 }
