@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2017 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
@@ -30,9 +29,9 @@ use LibreNMS\Device\WirelessSensor;
 use LibreNMS\Interfaces\Discovery\ProcessorDiscovery;
 use LibreNMS\Interfaces\Discovery\Sensors\WirelessFrequencyDiscovery;
 use LibreNMS\Interfaces\Discovery\Sensors\WirelessPowerDiscovery;
+use LibreNMS\Interfaces\Discovery\Sensors\WirelessRateDiscovery;
 use LibreNMS\Interfaces\Discovery\Sensors\WirelessRssiDiscovery;
 use LibreNMS\Interfaces\Discovery\Sensors\WirelessSnrDiscovery;
-use LibreNMS\Interfaces\Discovery\Sensors\WirelessRateDiscovery;
 use LibreNMS\OS;
 
 class Ray extends OS implements
@@ -53,14 +52,14 @@ class Ray extends OS implements
     {
         // RAY-MIB::useCpu has no index, so it won't work in yaml
 
-        return array(
+        return [
             Processor::discover(
                 $this->getName(),
                 $this->getDeviceId(),
                 '.1.3.6.1.4.1.33555.1.1.5.1',
                 0
-            )
-        );
+            ),
+        ];
     }
 
     /**
@@ -71,12 +70,12 @@ class Ray extends OS implements
      */
     public function discoverWirelessFrequency()
     {
-        return array(
+        return [
             // RAY-MIB::txFreq.0
             new WirelessSensor('frequency', $this->getDeviceId(), '.1.3.6.1.4.1.33555.1.2.1.4', 'racom-tx', 1, 'TX Frequency', null, 1, 1000),
             // RAY-MIB::rxFreq.0
             new WirelessSensor('frequency', $this->getDeviceId(), '.1.3.6.1.4.1.33555.1.2.1.3', 'racom-rx', 1, 'RX Frequency', null, 1, 1000),
-        );
+        ];
     }
 
     /**
@@ -87,12 +86,12 @@ class Ray extends OS implements
      */
     public function discoverWirelessPower()
     {
-        return array(
+        return [
             // RAY-MIB::rfPowerCurrent.0
             new WirelessSensor('power', $this->getDeviceId(), '.1.3.6.1.4.1.33555.1.2.1.17', 'racom-pow-cur', 1, 'Tx Power Current'),
             //RAY-MIB::rfPowerConfigured.0
             new WirelessSensor('power', $this->getDeviceId(), '.1.3.6.1.4.1.33555.1.2.1.12', 'racom-pow-conf', 1, 'Tx Power Configured'),
-        );
+        ];
     }
 
     /**
@@ -104,9 +103,10 @@ class Ray extends OS implements
     public function discoverWirelessRssi()
     {
         $oid = '.1.3.6.1.4.1.33555.1.3.2.1'; // RAY-MIB::rss.0
-        return array(
+
+        return [
             new WirelessSensor('rssi', $this->getDeviceId(), $oid, 'racom', 1, 'RSSI', null, 1, 10),
-        );
+        ];
     }
 
     /**
@@ -118,10 +118,12 @@ class Ray extends OS implements
     public function discoverWirelessSnr()
     {
         $oid = '.1.3.6.1.4.1.33555.1.3.2.2'; // RAY-MIB::snr.0
-        return array(
+
+        return [
             new WirelessSensor('snr', $this->getDeviceId(), $oid, 'racom', 1, 'CINR', null, 1, 10),
-        );
+        ];
     }
+
     /**
      * Discover wireless RATE.  This is in bps. Type is rate.
      * Returns an array of LibreNMS\Device\Sensor objects that have been discovered
@@ -132,9 +134,10 @@ class Ray extends OS implements
     {
         $oid_bitrate = '.1.3.6.1.4.1.33555.1.2.1.13'; // RAY-MIB::netBitrate.0
         $oid_maxbitrate = '.1.3.6.1.4.1.33555.1.2.1.14'; // RAY-MIB::maxNetBitrate.0
-        return array(
+
+        return [
             new WirelessSensor('rate', $this->getDeviceId(), $oid_bitrate, 'racom-netBitrate', 1, 'Net Bitrate', null, 1000, 1),
             new WirelessSensor('rate', $this->getDeviceId(), $oid_maxbitrate, 'racom-maxNetBitrate', 2, 'Max Net Bitrate', null, 1000, 1),
-        );
+        ];
     }
 }
