@@ -20,10 +20,33 @@ namespace LibreNMS\OS;
 use Illuminate\Support\Str;
 use LibreNMS\Device\Processor;
 use LibreNMS\Interfaces\Discovery\ProcessorDiscovery;
+use LibreNMS\Interfaces\Polling\OSPolling;
 use LibreNMS\OS;
+use LibreNMS\RRD\RrdDefinition;
 
-class Sonicwall extends OS implements ProcessorDiscovery
+class Sonicwall extends OS implements OSPolling, ProcessorDiscovery
 {
+    public function pollOS()
+    {
+        $data = snmp_get_multi($this->getDeviceArray(), [
+            'sonicCurrentConnCacheEntries.0',
+            'sonicMaxConnCacheEntries.0',
+        ], '-OQUs', 'SONICWALL-FIREWALL-IP-STATISTICS-MIB');
+
+        if (is_numeric($data)) {
+            $rrd_def = RrdDefinition::make()
+                ->addDataset('activesessions', 'GAUGE', 0)
+                ->addDataset('maxsessions', 'GAUGE', 0);
+            $fields = [
+                'activesessions' => $data[0]['sonicCurrentConnCacheEntries'],
+                'maxsessions' => $data[0]['sonicMaxConnCacheEntries'],
+            ];
+            $tags = compact('rrd_def');
+            data_update($this->getDeviceArray(), 'sonicwall_sessions', $tags, $fields);
+            $this->enableGraph('sonicwall_sessions');
+        }
+    }
+
     /**
      * Discover processors.
      * Returns an array of LibreNMS\Device\Processor objects that have been discovered
@@ -32,8 +55,8 @@ class Sonicwall extends OS implements ProcessorDiscovery
      */
     public function discoverProcessors()
     {
-        if (Str::startsWith($this->getDevice()['sysObjectID'], '.1.3.6.1.4.1.8741.1')) {
-            return array(
+        if (Str::startsWith($this->getDeviceArray()['sysObjectID'], '.1.3.6.1.4.1.8741.1')) {
+            return [
                 Processor::discover(
                     'sonicwall',
                     $this->getDeviceId(),
@@ -41,19 +64,19 @@ class Sonicwall extends OS implements ProcessorDiscovery
                     0,
                     'CPU',
                     1
-                )
-            );
+                ),
+            ];
         } else {
-            return array(
+            return [
                 Processor::discover(
                     'sonicwall',
                     $this->getDeviceId(),
-                    $this->getDevice()['sysObjectID'] . '.2.1.3.0',  // different OID for each model
+                    $this->getDeviceArray()['sysObjectID'] . '.2.1.3.0',  // different OID for each model
                     0,
                     'CPU',
                     1
-                )
-            );
+                ),
+            ];
         }
     }
 }
