@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2018 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
@@ -37,13 +36,13 @@ trait FrogfootResources
      */
     public function discoverProcessors()
     {
-        return array(
+        return [
             Processor::discover(
                 $this->getName(),
                 $this->getDeviceID(),
                 '1.3.6.1.4.1.10002.1.1.1.4.2.1.3.2',
                 0
-            )
-        );
+            ),
+        ];
     }
 }
