@@ -14,20 +14,21 @@
  * @author     Thomas GAGNIERE <tgagniere@reseau-concept.com>
  */
 
-
 namespace LibreNMS\OS;
 
 use LibreNMS\Device\WirelessSensor;
+use LibreNMS\Interfaces\Discovery\OSDiscovery;
 use LibreNMS\Interfaces\Discovery\Sensors\WirelessClientsDiscovery;
-use LibreNMS\OS;
+use LibreNMS\OS\Shared\Zyxel;
 
-class Zyxelnwa extends OS implements WirelessClientsDiscovery
+class Zyxelnwa extends Zyxel implements OSDiscovery, WirelessClientsDiscovery
 {
     public function discoverWirelessClients()
     {
         $oid = '.1.3.6.1.4.1.890.1.15.3.5.1.1.2.1'; //ZYXEL-ES-SMI::esMgmt.5.1.1.2.1
-        return array(
-            new WirelessSensor('clients', $this->getDeviceId(), $oid, 'zyxelnwa', 1, 'Clients')
-        );
+
+        return [
+            new WirelessSensor('clients', $this->getDeviceId(), $oid, 'zyxelnwa', 1, 'Clients'),
+        ];
     }
 }
