@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2015 Daniel Preussker <f0o@devilcode.org>
  * @copyright  2015 LibreNMS
@@ -30,12 +29,10 @@ use ArrayAccess;
 
 class ObjectCache implements ArrayAccess
 {
-
-    private $data = array();
+    private $data = [];
 
     private $obj = '';
 
-
     /**
      * Initialize ObjectCache
      * @param string $obj Name of Object
@@ -46,31 +43,32 @@ class ObjectCache implements ArrayAccess
         if (isset($GLOBALS['_ObjCache'][$obj])) {
             $this->data = $GLOBALS['_ObjCacheSkell'][$obj];
         } else {
-            if (!isset($GLOBALS['_ObjCacheSkell']) || !is_array($GLOBALS['_ObjCacheSkell'])) {
-                $GLOBALS['_ObjCacheSkell'] = array();
+            if (! isset($GLOBALS['_ObjCacheSkell']) || ! is_array($GLOBALS['_ObjCacheSkell'])) {
+                $GLOBALS['_ObjCacheSkell'] = [];
             }
 
-            if (!isset($GLOBALS['_ObjCache']) || !is_array($GLOBALS['_ObjCache'])) {
-                $GLOBALS['_ObjCache'] = array();
+            if (! isset($GLOBALS['_ObjCache']) || ! is_array($GLOBALS['_ObjCache'])) {
+                $GLOBALS['_ObjCache'] = [];
             }
 
             if (file_exists(\LibreNMS\Config::get('install_dir') . '/includes/caches/' . $obj . '.inc.php')) {
-                $data = array();
+                $data = [];
                 include \LibreNMS\Config::get('install_dir') . '/includes/caches/' . $obj . '.inc.php';
                 $this->data = $data;
                 $GLOBALS['_ObjCacheSkell'][$obj] = $this->data;
-                if (!(isset($GLOBALS['_ObjCache'][$obj]) && is_array($GLOBALS['_ObjCache'][$obj]))) {
+                if (! (isset($GLOBALS['_ObjCache'][$obj]) && is_array($GLOBALS['_ObjCache'][$obj]))) {
                     $GLOBALS['_ObjCache'][$obj] = $this->data;
                 }
             }
         }//end if
-    }//end __construct()
+    }
 
+    //end __construct()
 
     /**
      * Check if data exists
      * @param string $obj Name of Data-Object
-     * @return boolean
+     * @return bool
      */
     public function offsetExists($obj)
     {
@@ -79,8 +77,9 @@ class ObjectCache implements ArrayAccess
         }
 
         return false;
-    }//end offsetExists()
+    }
 
+    //end offsetExists()
 
     /**
      * Get Data-Object
@@ -95,32 +94,36 @@ class ObjectCache implements ArrayAccess
             } elseif (isset($GLOBALS['_ObjCache'][$this->obj][$obj]['value'])) {
                 return $GLOBALS['_ObjCache'][$this->obj][$obj]['value'];
             } else {
-                $GLOBALS['_ObjCache'][$this->obj][$obj]['value'] = dbFetchRows($this->data[$obj]['query'], isset($this->data[$obj]['params']) ? $this->data[$obj]['params'] : array());
+                $GLOBALS['_ObjCache'][$this->obj][$obj]['value'] = dbFetchRows($this->data[$obj]['query'], isset($this->data[$obj]['params']) ? $this->data[$obj]['params'] : []);
                 if (sizeof($GLOBALS['_ObjCache'][$this->obj][$obj]['value']) == 1 && sizeof($GLOBALS['_ObjCache'][$this->obj][$obj]['value'][0]) == 1) {
                     $GLOBALS['_ObjCache'][$this->obj][$obj]['value'] = current($GLOBALS['_ObjCache'][$this->obj][$obj]['value'][0]);
                 }
+
                 return $GLOBALS['_ObjCache'][$this->obj][$obj]['value'];
             }
         }
-    }//end offsetGet()
+    }
 
+    //end offsetGet()
 
     /**
      * Overrides internal Cache-Object
      * @param string $obj   Name of Data-Object
      * @param mixed  $value Value
-     * @return boolean
+     * @return bool
      */
     public function offsetSet($obj, $value)
     {
-        if (!isset($this->data[$obj])) {
-            $this->data[$obj] = array();
+        if (! isset($this->data[$obj])) {
+            $this->data[$obj] = [];
         }
 
         $this->data[$obj]['value'] = $value;
-        return $this->data[$obj]['value'];
-    }//end offsetSet()
 
+        return $this->data[$obj]['value'];
+    }
+
+    //end offsetSet()
 
     /**
      * Reset Data-Object
@@ -130,6 +133,9 @@ class ObjectCache implements ArrayAccess
     public function offsetUnset($obj)
     {
         unset($this->data[$obj]['value']);
+
         return true;
-    }//end offsetUnset()
+    }
+
+    //end offsetUnset()
 }//end class
