@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2018 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
@@ -25,21 +24,30 @@
 
 namespace LibreNMS\Snmptrap;
 
+use LibreNMS\Alert\AlertRules;
 use LibreNMS\Config;
 use LibreNMS\Snmptrap\Handlers\Fallback;
-use LibreNMS\Alert\AlertRules;
 use Log;
 
 class Dispatcher
 {
     /**
      * Instantiate the correct handler for this trap and call it's handle method
-     *
      */
     public static function handle(Trap $trap)
     {
         if (empty($trap->getDevice())) {
-            Log::warning("Could not find device for trap", ['trap_text' => $trap->getRaw()]);
+            Log::warning('Could not find device for trap', ['trap_text' => $trap->getRaw()]);
+
+            return false;
+        }
+
+        if ($trap->findOid('iso.3.6.1.6.3.1.1.4.1.0')) {
+            // Even the TrapOid is not properly converted to text, so snmptrapd is probably not
+            // configured with any MIBs (-M and/or -m).
+            // LibreNMS snmptraps code cannot process received data. Let's inform the user.
+            Log::event('Misconfigured MIBS or MIBDIRS for snmptrapd, check https://docs.librenms.org/Extensions/SNMP-Trap-Handler/ : ' . $trap->getRaw(), $trap->getDevice(), 'system');
+
             return false;
         }
 
@@ -51,13 +59,14 @@ class Dispatcher
         // log an event if appropriate
         $fallback = $handler instanceof Fallback;
         $logging = Config::get('snmptraps.eventlog', 'unhandled');
+        $detailed = Config::get('snmptraps.eventlog_detailed', false);
         if ($logging == 'all' || ($fallback && $logging == 'unhandled')) {
-            Log::event("SNMP trap received: " . $trap->getTrapOid(), $trap->getDevice(), 'trap');
+            Log::event($trap->toString($detailed), $trap->getDevice(), 'trap');
         } else {
             $rules = new AlertRules;
             $rules->runRules($trap->getDevice()->device_id);
         }
 
-        return !$fallback;
+        return ! $fallback;
     }
 }
