@@ -20,7 +20,6 @@
  * Adva network element is in an alarm state. Gets the alarm description
  * and severity assigned by the Adva.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2018 KanREN, Inc
  * @author     Heath Barnhart <hbarnhart@kanren.net> & Neil Kahle <nkahle@kanren.net>
@@ -47,16 +46,16 @@ class AdvaNetworkElementAlmTrap implements SnmptrapHandler
     {
         $alSeverity = $trap->getOidData($trap->findOid('CM-ALARM-MIB::cmNetworkElementAlmNotifCode'));
         switch ($alSeverity) {
-            case "critical":
+            case 'critical':
                 $logSeverity = 5;
                 break;
-            case "major":
+            case 'major':
                 $logSeverity = 4;
                 break;
-            case "minor":
+            case 'minor':
                 $logSeverity = 3;
                 break;
-            case "cleared":
+            case 'cleared':
                 $logSeverity = 1;
                 break;
             default:
