@@ -20,7 +20,6 @@
  * Traps when Adva objects are deleted. This includes Remote User Login object,
  * Flow Deletion object, LAG Member Port Removed object, and Lag Deletion object.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2018 KanREN, Inc
  * @author     Heath Barnhart <hbarnhart@kanren.net> & Neil Kahle <nkahle@kanren.net>
@@ -49,11 +48,11 @@ class AdvaObjectDeletion implements SnmptrapHandler
             $UserName = $trap->getOidData($trap_oid);
             Log::event("User object $UserName deleted", $device->device_id, 'trap', 2);
         } elseif ($trap_oid = $trap->findOid('CM-FACILITY-MIB::cmFlowIndex')) {
-            $flowID = str_replace(".", "-", substr($trap_oid, 29));
+            $flowID = str_replace('.', '-', substr($trap_oid, 29));
             Log::event("Flow $flowID deleted", $device->device_id, 'trap', 2);
         } elseif ($trap_oid = $trap->findOid('F3-LAG-MIB::f3LagPortIndex')) {
             $lagPortID = $trap->getOidData($trap_oid);
-            $lagID = str_replace(".", "-", substr($trap_oid, -5, 3));
+            $lagID = str_replace('.', '-', substr($trap_oid, -5, 3));
             Log::event("LAG member port $lagPortID removed from LAG $lagID", $device->device_id, 'trap', 2);
         } elseif ($trap_oid = $trap->findOid('F3-LAG-MIB::f3LagIndex')) {
             $lagID = $trap->getOidData($trap_oid);
