@@ -19,7 +19,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2020 Kanren Inc.
  * @author     Heath Barnhart <hbarnhart@kanren.net>
@@ -29,7 +28,6 @@ namespace LibreNMS\Snmptrap\Handlers;
 
 use App\Models\Device;
 use LibreNMS\Interfaces\SnmptrapHandler;
-use LibreNMS\Snmptrap\Handlers\CyberPowerUtil;
 use LibreNMS\Snmptrap\Trap;
 use Log;
 
