@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2018 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
@@ -32,7 +31,6 @@ use Log;
 
 class Fallback implements SnmptrapHandler
 {
-
     /**
      * Handle snmptrap.
      * Data is pre-parsed and delivered as a Trap.
@@ -43,9 +41,9 @@ class Fallback implements SnmptrapHandler
      */
     public function handle(Device $device, Trap $trap)
     {
-        Log::info("Unhandled trap snmptrap", [
+        Log::info('Unhandled trap snmptrap', [
             'device' => $device->hostname,
-            'oid' => $trap->getTrapOid()
+            'oid' => $trap->getTrapOid(),
         ]);
     }
 }
