@@ -19,7 +19,6 @@
  *
  * Trap sent when a Juniper transciever lambda reaches an alert level threshold.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2018 KanREN, Inc.
  * @author     Heath Barnhart <hbarnhart@kanren.net>
@@ -30,7 +29,6 @@ namespace LibreNMS\Snmptrap\Handlers;
 use App\Models\Device;
 use LibreNMS\Interfaces\SnmptrapHandler;
 use LibreNMS\Snmptrap\Trap;
-use LibreNMS\Snmptrap\Handlers\JnxDomLaneAlarmId;
 use Log;
 
 class JnxDomLaneAlarmCleared implements SnmptrapHandler
@@ -51,8 +49,9 @@ class JnxDomLaneAlarmCleared implements SnmptrapHandler
 
         $ifIndex = substr(strrchr($trap->findOid('IF-MIB::ifDescr'), '.'), 1);
         $port = $device->ports()->where('ifIndex', $ifIndex)->first();
-        if (!$port) {
+        if (! $port) {
             Log::warning("Snmptrap JnxDomLaneAlarmCleared: Could not find port at ifIndex $port->ifIndex for device: " . $device->hostname);
+
             return;
         }
 
