@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2018 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
@@ -28,9 +27,7 @@ namespace LibreNMS\Snmptrap;
 use App\Models\Device;
 use Illuminate\Support\Collection;
 use Illuminate\Support\Str;
-use LibreNMS\Snmptrap\Handlers\Fallback;
 use LibreNMS\Util\IP;
-use Log;
 
 class Trap
 {
@@ -40,7 +37,7 @@ class Trap
 
     protected $device;
 
-    /** @var Collection $oid_data */
+    /** @var Collection */
     protected $oid_data;
 
     /**
@@ -62,11 +59,12 @@ class Trap
         $line = array_shift($lines);
         if (preg_match('/\[([0-9.:a-fA-F]+)\]/', $line, $matches)) {
             $this->ip = $matches[1];
-        };
+        }
 
         // parse the oid data
         $this->oid_data = collect($lines)->mapWithKeys(function ($line) {
-            list($oid, $data) = explode(' ', $line, 2);
+            [$oid, $data] = explode(' ', $line, 2);
+
             return [$oid => trim($data, '"')];
         });
     }
@@ -144,4 +142,21 @@ class Trap
     {
         return $this->raw;
     }
+
+    /**
+     * Render the Trap for debugging purpose
+     *
+     * @param $detailed
+     * @return string
+     */
+    public function toString($detailed = false)
+    {
+        if ($detailed) {
+            return $this->getTrapOid() . "\n" . json_encode($this->oid_data->reject(function ($value, $key) {
+                return Str::contains($key, 'SNMPv2-MIB::snmpTrapOID.0');
+            })->all());
+        }
+
+        return '' . $this->getTrapOid();
+    }
 }
