@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2019 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
@@ -25,7 +24,6 @@
 
 namespace LibreNMS\Util;
 
-use App\Models\Dashboard;
 use LibreNMS\Config;
 use Validator;
 
@@ -70,7 +68,7 @@ class DynamicConfigItem implements \ArrayAccess
         } elseif ($this->type == 'boolean') {
             return filter_var($value, FILTER_VALIDATE_BOOLEAN, FILTER_NULL_ON_FAILURE) !== null;
         } elseif ($this->type == 'integer') {
-            return (!is_bool($value) && filter_var($value, FILTER_VALIDATE_INT)) || $value === "0" || $value === 0;
+            return (! is_bool($value) && filter_var($value, FILTER_VALIDATE_INT)) || $value === '0' || $value === 0;
         } elseif ($this->type == 'select') {
             return in_array($value, array_keys($this->options));
         } elseif ($this->type == 'email') {
@@ -83,9 +81,9 @@ class DynamicConfigItem implements \ArrayAccess
         } elseif ($this->type == 'array') {
             return is_array($value); // this should probably have more complex validation via validator rules
         } elseif ($this->type == 'color') {
-            return (bool)preg_match('/^#?[0-9a-fA-F]{6}([0-9a-fA-F]{2})?$/', $value);
+            return (bool) preg_match('/^#?[0-9a-fA-F]{6}([0-9a-fA-F]{2})?$/', $value);
         } elseif (in_array($this->type, ['text', 'password'])) {
-            return !is_array($value);
+            return ! is_array($value);
         } elseif ($this->type === 'executable') {
             return is_file($value) && is_executable($value);
         } elseif ($this->type === 'directory') {
@@ -116,6 +114,7 @@ class DynamicConfigItem implements \ArrayAccess
             $key = $this->optionTranslationKey($option);
             $trans = __($key);
             $result[$option] = ($trans === $key ? $option : $trans);
+
             return $result;
         }, []);
     }
@@ -138,12 +137,14 @@ class DynamicConfigItem implements \ArrayAccess
     public function hasDescription()
     {
         $key = $this->descriptionTranslationKey();
+
         return __($key) !== $key;
     }
 
     public function hasHelp()
     {
         $key = $this->helpTranslationKey();
+
         return __($key) !== $key;
     }
 
@@ -161,6 +162,7 @@ class DynamicConfigItem implements \ArrayAccess
     {
         $key = $this->descriptionTranslationKey();
         $trans = __($key);
+
         return $trans === $key ? $this->name : $trans;
     }
 
@@ -187,7 +189,7 @@ class DynamicConfigItem implements \ArrayAccess
 
     public function isValid()
     {
-        return ($this->group == "" || $this->type) && !$this->hidden && !$this->disabled;
+        return ($this->group == '' || $this->type) && ! $this->hidden && ! $this->disabled;
     }
 
     /**
