@@ -18,7 +18,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2018 Neil Lathwood
  * @author     Neil Lathwood <gh+n@laf.io>
@@ -80,13 +79,12 @@ class GitHub
         $this->from = $from;
         $this->file = $file;
         $this->pr = $pr;
-        if (!is_null($token) || getenv('GH_TOKEN')) {
+        if (! is_null($token) || getenv('GH_TOKEN')) {
             $this->token = $token ?: getenv('GH_TOKEN');
         }
     }
 
     /**
-     *
      * Return the GitHub Authorization header for the API call
      *
      * @return array
@@ -94,17 +92,17 @@ class GitHub
     public function getHeaders()
     {
         $headers = [
-            'Content-Type' => 'application/json'
+            'Content-Type' => 'application/json',
         ];
 
-        if (!is_null($this->token)) {
+        if (! is_null($this->token)) {
             $headers['Authorization'] = "token {$this->token}";
         }
+
         return $headers;
     }
 
     /**
-     *
      * Get the release information for a specific tag
      *
      * @param $tag
@@ -113,13 +111,12 @@ class GitHub
     public function getRelease($tag)
     {
         $release = Requests::get($this->github . "/releases/tags/$tag", $this->getHeaders());
+
         return json_decode($release->body, true);
     }
 
     /**
-     *
      * Get a single pull request information
-     *
      */
     public function getPullRequest()
     {
@@ -128,7 +125,6 @@ class GitHub
     }
 
     /**
-     *
      * Get all closed pull requests up to a certain date
      *
      * @param $date
@@ -185,7 +181,7 @@ GRAPHQL;
         $data = json_encode(['query' => $query]);
         $prs = Requests::post($this->graphql, $this->getHeaders(), $data);
         $prs = json_decode($prs->body, true);
-        if (!isset($prs['data'])) {
+        if (! isset($prs['data'])) {
             var_dump($prs);
         }
 
@@ -211,14 +207,13 @@ GRAPHQL;
     {
         return array_map(function ($label) {
             $name = preg_replace('/ :[\S]+:/', '', strtolower($label['name']));
+
             return str_replace('-', ' ', $name);
         }, $labels);
     }
 
     /**
-     *
      * Build the data for the change log.
-     *
      */
     public function buildChangeLog()
     {
@@ -240,7 +235,7 @@ GRAPHQL;
             }
 
             // only add the changelog if it isn't set to ignore
-            if (!in_array('ignore changelog', $pr['labels'])) {
+            if (! in_array('ignore changelog', $pr['labels'])) {
                 $title = addcslashes(ucfirst(trim(preg_replace('/^[\S]+: /', '', $pr['title']))), '<>');
                 $this->changelog[$category][] = "$title ([#{$pr['number']}]({$pr['url']})) - [{$pr['author']['login']}]({$pr['author']['url']})" . PHP_EOL;
             }
@@ -253,7 +248,7 @@ GRAPHQL;
 
             $ignore = [$pr['author']['login'], $pr['mergedBy']['login']];
             foreach (array_unique($pr['reviews']['nodes'], SORT_REGULAR) as $reviewer) {
-                if (!in_array($reviewer['author']['login'], $ignore)) {
+                if (! in_array($reviewer['author']['login'], $ignore)) {
                     $this->recordUserInfo($reviewer['author'], 'changelog_mergers');
                 }
             }
@@ -275,36 +270,34 @@ GRAPHQL;
             ? $user_count[$user['login']] + 1
             : 1;
 
-        if (!isset($this->profile_links[$user['login']])) {
+        if (! isset($this->profile_links[$user['login']])) {
             $this->profile_links[$user['login']] = $user['url'];
         }
     }
 
     /**
-     *
      * Format the change log into Markdown.
-     *
      */
     public function formatChangeLog()
     {
         $tmp_markdown = "## $this->tag" . PHP_EOL;
         $tmp_markdown .= '*(' . date('Y-m-d') . ')*' . PHP_EOL . PHP_EOL;
 
-        if (!empty($this->changelog_users)) {
-            $tmp_markdown .= "A big thank you to the following " . count($this->changelog_users) . " contributors this last month:" . PHP_EOL . PHP_EOL;
+        if (! empty($this->changelog_users)) {
+            $tmp_markdown .= 'A big thank you to the following ' . count($this->changelog_users) . ' contributors this last month:' . PHP_EOL . PHP_EOL;
             $tmp_markdown .= $this->formatUserList($this->changelog_users);
         }
 
         $tmp_markdown .= PHP_EOL;
 
-        if (!empty($this->changelog_mergers)) {
-            $tmp_markdown .= "Thanks to maintainers and others that helped with pull requests this month:" . PHP_EOL . PHP_EOL;
+        if (! empty($this->changelog_mergers)) {
+            $tmp_markdown .= 'Thanks to maintainers and others that helped with pull requests this month:' . PHP_EOL . PHP_EOL;
             $tmp_markdown .= $this->formatUserList($this->changelog_mergers) . PHP_EOL;
         }
 
         foreach ($this->changelog as $section => $items) {
-            if (!empty($items)) {
-                $tmp_markdown .= "#### " . ucwords($section) . PHP_EOL;
+            if (! empty($items)) {
+                $tmp_markdown .= '#### ' . ucwords($section) . PHP_EOL;
                 $tmp_markdown .= '* ' . implode('* ', $items) . PHP_EOL;
             }
         }
@@ -324,13 +317,12 @@ GRAPHQL;
         foreach ($users as $user => $count) {
             $output .= "  - [$user]({$this->profile_links[$user]}) ($count)" . PHP_EOL;
         }
+
         return $output;
     }
 
     /**
-     *
      * Update the specified file with the new Change log info.
-     *
      */
     public function writeChangeLog()
     {
@@ -347,7 +339,6 @@ GRAPHQL;
     }
 
     /**
-     *
      * Return the generated markdown.
      *
      * @return mixed
@@ -372,7 +363,7 @@ GRAPHQL;
             $this->createChangelog(false);
         }
 
-        $release = Requests::post($this->github . "/releases", $this->getHeaders(), json_encode([
+        $release = Requests::post($this->github . '/releases', $this->getHeaders(), json_encode([
             'tag_name' => $this->tag,
             'target_commitish' => $updated_sha,
             'body' => $this->markdown,
@@ -390,11 +381,11 @@ GRAPHQL;
     public function createChangelog($write = true)
     {
         $previous_release = $this->getRelease($this->from);
-        if (!is_null($this->pr)) {
+        if (! is_null($this->pr)) {
             $this->getPullRequest();
         }
 
-        if (!isset($previous_release['published_at'])) {
+        if (! isset($previous_release['published_at'])) {
             throw new Exception(
                 $previous_release['message'] ??
                 "Could not find previous release tag. ($this->from)"
