@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2017 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
@@ -42,7 +41,7 @@ abstract class IP
      */
     public static function fromHexString($hex, $ignore_errors = false)
     {
-        $hex = str_replace(array(' ', '"'), '', $hex);
+        $hex = str_replace([' ', '"'], '', $hex);
 
         try {
             return self::parse($hex);
@@ -50,7 +49,7 @@ abstract class IP
             // ignore
         }
 
-        $hex = str_replace(array(':', '.'), '', $hex);
+        $hex = str_replace([':', '.'], '', $hex);
 
         try {
             if (strlen($hex) == 8) {
@@ -61,12 +60,12 @@ abstract class IP
                 return new IPv6(implode(':', str_split($hex, 4)));
             }
         } catch (InvalidIpException $e) {
-            if (!$ignore_errors) {
+            if (! $ignore_errors) {
                 throw $e;
             }
         }
 
-        if (!$ignore_errors) {
+        if (! $ignore_errors) {
             throw new InvalidIpException("Could not parse into IP: $hex");
         }
 
@@ -86,14 +85,15 @@ abstract class IP
     {
         $snmpOid = str_replace(['.', '"'], ' ', $snmpOid);
         $hex = implode(
-            ":",
+            ':',
             array_map(
                 function ($dec) {
                     return sprintf('%02x', $dec);
                 },
-                explode(" ", (string)$snmpOid)
+                explode(' ', (string) $snmpOid)
             )
         );
+
         return IP::fromHexString($hex, $ignore_errors);
     }
 
@@ -115,7 +115,7 @@ abstract class IP
         try {
             return new IPv6($ip);
         } catch (InvalidIpException $e) {
-            if (!$ignore_errors) {
+            if (! $ignore_errors) {
                 throw new InvalidIpException("$ip is not a valid IP address");
             }
         }
@@ -170,7 +170,7 @@ abstract class IP
      */
     public function inNetworks($networks)
     {
-        foreach ((array)$networks as $network) {
+        foreach ((array) $networks as $network) {
             if ($this->inNetwork($network)) {
                 return true;
             }
@@ -195,7 +195,7 @@ abstract class IP
      */
     public function compressed()
     {
-        return (string)$this->ip;
+        return (string) $this->ip;
     }
 
     /**
@@ -205,7 +205,7 @@ abstract class IP
      */
     public function uncompressed()
     {
-        return (string)$this->ip;
+        return (string) $this->ip;
     }
 
     /**
@@ -215,7 +215,7 @@ abstract class IP
      */
     public function packed()
     {
-        return inet_pton((string)$this->ip);
+        return inet_pton((string) $this->ip);
     }
 
     /**
@@ -230,7 +230,7 @@ abstract class IP
     public function __toString()
     {
         if ($this->cidr == $this->host_bits) {
-            return (string)$this->ip;
+            return (string) $this->ip;
         }
 
         return $this->ip . "/{$this->cidr}";
