@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2017 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
@@ -34,7 +33,7 @@ class Snmpsim
     private $ip;
     private $port;
     private $log;
-    /** @var Proc $proc */
+    /** @var Proc */
     private $proc;
 
     public function __construct($ip = '127.1.6.1', $port = 1161, $log = '/tmp/snmpsimd.log')
@@ -42,7 +41,7 @@ class Snmpsim
         $this->ip = $ip;
         $this->port = $port;
         $this->log = $log;
-        $this->snmprec_dir = Config::get('install_dir') . "/tests/snmpsim/";
+        $this->snmprec_dir = Config::get('install_dir') . '/tests/snmpsim/';
     }
 
     /**
@@ -55,6 +54,7 @@ class Snmpsim
     {
         if ($this->isRunning()) {
             echo "Snmpsim is already running!\n";
+
             return;
         }
 
@@ -71,16 +71,16 @@ class Snmpsim
             sleep($wait);
         }
 
-        if (isCli() && !$this->proc->isRunning()) {
+        if (isCli() && ! $this->proc->isRunning()) {
             // if starting failed, run snmpsim again and output to the console and validate the data
             passthru($this->getCmd(false) . ' --validate-data');
 
-            if (!is_executable($this->findSnmpsimd())) {
+            if (! is_executable($this->findSnmpsimd())) {
                 echo "\nCould not find snmpsim, you can install it with 'pip install snmpsim'.  If it is already installed, make sure snmpsimd or snmpsimd.py is in PATH\n";
             } else {
                 echo "\nFailed to start Snmpsim. Scroll up for error.\n";
             }
-            exit;
+            exit(1);
         }
     }
 
@@ -106,7 +106,6 @@ class Snmpsim
     /**
      * Run snmpsimd but keep it in the foreground
      * Outputs to stdout
-     *
      */
     public function run()
     {
@@ -160,7 +159,7 @@ class Snmpsim
         $cmd .= " --data-dir={$this->snmprec_dir} --agent-udpv4-endpoint={$this->ip}:{$this->port}";
 
         if (is_null($this->log)) {
-            $cmd .= " --logging-method=null";
+            $cmd .= ' --logging-method=null';
         } elseif ($with_log) {
             $cmd .= " --logging-method=file:{$this->log}";
         }
@@ -177,9 +176,10 @@ class Snmpsim
     private function findSnmpsimd()
     {
         $cmd = Config::locateBinary('snmpsimd');
-        if (!is_executable($cmd)) {
+        if (! is_executable($cmd)) {
             $cmd = Config::locateBinary('snmpsimd.py');
         }
+
         return $cmd;
     }
 }
