@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2017 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
@@ -30,6 +29,7 @@ class ValidationResult
     const FAILURE = 0;
     const WARNING = 1;
     const SUCCESS = 2;
+    const INFO = 3;
 
     private $message;
     private $status;
@@ -72,6 +72,16 @@ class ValidationResult
         return new self($message, self::WARNING, $fix);
     }
 
+    /**
+     * Create a new informational Validation result
+     * @param string $message The message to describe this result
+     * @return ValidationResult
+     */
+    public static function info($message)
+    {
+        return new self($message, self::INFO);
+    }
+
     /**
      * Create a new failure Validation result
      * @param string $message The message to describe this result
@@ -101,7 +111,7 @@ class ValidationResult
 
     public function hasList()
     {
-        return !empty($this->list);
+        return ! empty($this->list);
     }
 
     public function getList()
@@ -119,12 +129,13 @@ class ValidationResult
 
         $this->list_description = $description;
         $this->list = $list;
+
         return $this;
     }
 
     public function hasFix()
     {
-        return !empty($this->fix);
+        return ! empty($this->fix);
     }
 
     public function getFix()
@@ -142,6 +153,7 @@ class ValidationResult
     public function setFix($fix)
     {
         $this->fix = $fix;
+
         return $this;
     }
 
@@ -154,12 +166,12 @@ class ValidationResult
 
         if (isset($this->fix)) {
             c_echo("\t[%BFIX%n]: \n");
-            foreach ((array)$this->fix as $fix) {
+            foreach ((array) $this->fix as $fix) {
                 c_echo("\t%B$fix%n\n");
             }
         }
 
-        if (!empty($this->list)) {
+        if (! empty($this->list)) {
             echo "\t" . $this->getListDescription() . ":\n";
             $this->printList();
         }
@@ -172,14 +184,14 @@ class ValidationResult
      */
     public static function getStatusText($status)
     {
-        if ($status === self::SUCCESS) {
-            return '%gOK%n';
-        } elseif ($status === self::WARNING) {
-            return '%YWARN%n';
-        } elseif ($status === self::FAILURE) {
-            return '%RFAIL%n';
-        }
-        return 'Unknown';
+        $table = [
+            self::SUCCESS => '%gOK%n',
+            self::WARNING => '%YWARN%n',
+            self::FAILURE => '%RFAIL%n',
+            self::INFO => '%CINFO%n',
+        ];
+
+        return $table[$status] ?? 'Unknown';
     }
 
     public function getListDescription()
