@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2018 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
@@ -35,51 +34,13 @@ use Toastr;
 
 class Checks
 {
-    public static function preAutoload()
-    {
-        // Check PHP version otherwise it will just say server error
-        if (version_compare('7.2.5', PHP_VERSION, '>=')) {
-            self::printMessage(
-                'PHP version 7.2.5 or newer is required to run LibreNMS',
-                null,
-                true
-            );
-        };
-    }
-
-    /**
-     * Pre-boot dependency check
-     */
-    public static function postAutoload()
-    {
-        if (!class_exists(\Illuminate\Foundation\Application::class)) {
-            self::printMessage(
-                'Error: Missing dependencies! Run the following command to fix:',
-                './scripts/composer_wrapper.php install --no-dev',
-                true
-            );
-        }
-    }
-
-    public static function preBoot()
-    {
-        // check php extensions
-        if ($missing = self::missingPhpExtensions()) {
-            self::printMessage(
-                "Missing PHP extensions.  Please install and enable them on your LibreNMS server.",
-                $missing,
-                true
-            );
-        }
-    }
-
     /**
      * Post boot Toast messages
      */
     public static function postAuth()
     {
         // limit popup messages frequency
-        if (Cache::get('checks_popup_timeout') || !Auth::check()) {
+        if (Cache::get('checks_popup_timeout') || ! Auth::check()) {
             return;
         }
 
@@ -101,14 +62,14 @@ class Checks
 
             // Directory access checks
             $rrd_dir = Config::get('rrd_dir');
-            if (!is_dir($rrd_dir)) {
-                Toastr::error("RRD Directory is missing ($rrd_dir).  Graphing may fail. <a href=" . url('validate') . ">Validate your install</a>");
+            if (! is_dir($rrd_dir)) {
+                Toastr::error("RRD Directory is missing ($rrd_dir).  Graphing may fail. <a href=" . url('validate') . '>Validate your install</a>');
             }
 
             $temp_dir = Config::get('temp_dir');
-            if (!is_dir($temp_dir)) {
-                Toastr::error("Temp Directory is missing ($temp_dir).  Graphing may fail. <a href=" . url('validate') . ">Validate your install</a>");
-            } elseif (!is_writable($temp_dir)) {
+            if (! is_dir($temp_dir)) {
+                Toastr::error("Temp Directory is missing ($temp_dir).  Graphing may fail. <a href=" . url('validate') . '>Validate your install</a>');
+            } elseif (! is_writable($temp_dir)) {
                 Toastr::error("Temp Directory is not writable ($temp_dir).  Graphing may fail. <a href='" . url('validate') . "'>Validate your install</a>");
             }
         }
@@ -138,7 +99,7 @@ class Checks
 
     private static function printMessage($title, $content, $exit = false)
     {
-        $content = (array)$content;
+        $content = (array) $content;
 
         if (PHP_SAPI == 'cli') {
             $format = "%s\n\n%s\n\n";
@@ -157,18 +118,4 @@ class Checks
             exit(1);
         }
     }
-
-    private static function missingPhpExtensions()
-    {
-        // allow mysqli, but prefer mysqlnd
-        if (!extension_loaded('mysqlnd') && !extension_loaded('mysqli')) {
-            return ['mysqlnd'];
-        }
-
-        $required_modules = ['mbstring', 'pcre', 'curl', 'xml', 'gd'];
-
-        return array_filter($required_modules, function ($module) {
-            return !extension_loaded($module);
-        });
-    }
 }
