@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2019 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
@@ -26,7 +25,6 @@
 namespace App\Console\Commands;
 
 use App\Console\LnmsCommand;
-use Storage;
 use Symfony\Component\Process\Process;
 
 class TranslationGenerateCommand extends LnmsCommand
@@ -62,6 +60,6 @@ class TranslationGenerateCommand extends LnmsCommand
             $manifest[$file_name] = $file_name . '?id=' . substr(md5(file_get_contents($file)), 0, 20);
         }
 
-        file_put_contents($manifest_file, json_encode($manifest, JSON_PRETTY_PRINT|JSON_UNESCAPED_SLASHES) . PHP_EOL);
+        file_put_contents($manifest_file, json_encode($manifest, JSON_PRETTY_PRINT | JSON_UNESCAPED_SLASHES) . PHP_EOL);
     }
 }
