@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2019 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
@@ -34,13 +33,13 @@ class ResolutionController extends Controller
     {
         $this->validate($request, [
             'width' => 'required|numeric',
-            'height' => 'required|numeric'
+            'height' => 'required|numeric',
         ]);
 
         // laravel session
         session([
             'screen_width' => $request->width,
-            'screen_height' => $request->height
+            'screen_height' => $request->height,
         ]);
 
         return $request->width . 'x' . $request->height;
