@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2020 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
@@ -33,7 +32,7 @@ class MibController implements DeviceTab
 {
     public function visible(Device $device): bool
     {
-        return Config::get("poller_modules.mib") && $device->getAttrib('poll_mib');
+        return Config::get('poller_modules.mib') && $device->getAttrib('poll_mib');
     }
 
     public function slug(): string
