@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2020 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
@@ -38,15 +37,15 @@ class RoutingController implements DeviceTab
     {
         $device = DeviceCache::getPrimary();
         $this->tabs = [
-            'ospf' => $device->ospfInstances()->exists(),
-            'bgp' => $device->bgppeers()->exists(),
-            'vrf' => $device->vrfs()->exists(),
-            'cef' => $device->cefSwitching()->exists(),
-            'mpls' => $device->mplsLsps()->exists(),
-            'cisco-otv' => Component::query()->where('device_id', $device->device_id)->where('type', 'Cisco-OTV')->exists(),
-            'loadbalancer_rservers' => $device->rServers()->exists(),
-            'ipsec_tunnels' => $device->ipsecTunnels()->exists(),
-            'routes' => $device->routes()->exists(),
+            'ospf' => $device->ospfInstances()->count(),
+            'bgp' => $device->bgppeers()->count(),
+            'vrf' => $device->vrfs()->count(),
+            'cef' => $device->cefSwitching()->count(),
+            'mpls' => $device->mplsLsps()->count(),
+            'cisco-otv' => Component::query()->where('device_id', $device->device_id)->where('type', 'Cisco-OTV')->count(),
+            'loadbalancer_rservers' => $device->rServers()->count(),
+            'ipsec_tunnels' => $device->ipsecTunnels()->count(),
+            'routes' => $device->routes()->count(),
         ];
     }
 
@@ -73,7 +72,7 @@ class RoutingController implements DeviceTab
     public function data(Device $device): array
     {
         return [
-            'routing_tabs' => array_keys(array_filter($this->tabs))
+            'routing_tabs' => array_filter($this->tabs),
         ];
     }
 }
