@@ -4,8 +4,8 @@ namespace App\Http\Controllers;
 
 use App\Models\Device;
 use App\Models\DeviceGroup;
-use Illuminate\Validation\Rule;
 use Illuminate\Http\Request;
+use Illuminate\Validation\Rule;
 use LibreNMS\Alerting\QueryBuilderFilter;
 use LibreNMS\Alerting\QueryBuilderFluentParser;
 use Toastr;
@@ -152,11 +152,12 @@ class DeviceGroupController extends Controller
                     Toastr::success(__('Device Group :name updated', ['name' => $deviceGroup->name]));
                 } else {
                     Toastr::error(__('Failed to save'));
+
                     return redirect()->back()->withInput();
                 }
             } catch (\Illuminate\Database\QueryException $e) {
                 return redirect()->back()->withInput()->withErrors([
-                    'rules' => __('Rules resulted in invalid query: ') . $e->getMessage()
+                    'rules' => __('Rules resulted in invalid query: ') . $e->getMessage(),
                 ]);
             }
         } else {
@@ -176,8 +177,8 @@ class DeviceGroupController extends Controller
     {
         $deviceGroup->delete();
 
-        Toastr::success(__('Device Group :name deleted', ['name' => $deviceGroup->name]));
+        $msg = __('Device Group :name deleted', ['name' => $deviceGroup->name]);
 
-        return redirect()->route('device-groups.index');
+        return response($msg, 200);
     }
 }
