@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2018 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
@@ -36,7 +35,7 @@ class DeviceController extends SelectController
         return [
             'access' => 'nullable|in:normal,inverted',
             'user' => 'nullable|int',
-            'id' => 'nullable|in:device_id,hostname'
+            'id' => 'nullable|in:device_id,hostname',
         ];
     }
 
