@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2018 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
@@ -27,7 +26,6 @@ namespace App\Http\Controllers\Table;
 
 use App\ApiClients\GraylogApi;
 use App\Models\Device;
-use App\Models\Port;
 use DateInterval;
 use DateTime;
 use DateTimeZone;
@@ -48,7 +46,7 @@ class GraylogController extends SimpleTableController
 
     public function __invoke(Request $request, GraylogApi $api)
     {
-        if (!$api->isConfigured()) {
+        if (! $api->isConfigured()) {
             return response()->json([
                 'error' => 'Graylog is not configured',
             ], 503);
@@ -64,14 +62,14 @@ class GraylogController extends SimpleTableController
         $search = $request->get('searchPhrase');
         $device_id = $request->get('device');
         $device = $device_id ? Device::find($device_id) : null;
-        $range = $request->get('range', 0) ;
+        $range = $request->get('range', 0);
         $limit = $request->get('rowCount', 10);
         $page = $request->get('current', 1);
         $offset = ($page - 1) * $limit;
         $loglevel = $request->get('loglevel') ?? Config::get('graylog.loglevel');
 
-        $query = $api->buildSimpleQuery($search, $device).
-            ($loglevel !== null ? ' AND level: <='. $loglevel : '');
+        $query = $api->buildSimpleQuery($search, $device) .
+            ($loglevel !== null ? ' AND level: <=' . $loglevel : '');
 
         $sort = null;
         foreach ($request->get('sort', []) as $field => $direction) {
@@ -83,6 +81,7 @@ class GraylogController extends SimpleTableController
 
         try {
             $data = $api->query($query, $range, $limit, $offset, $sort, $filter);
+
             return $this->formatResponse(
                 array_map([$this, 'formatMessage'], $data['messages']),
                 $page,
@@ -104,7 +103,7 @@ class GraylogController extends SimpleTableController
             $graylogTime = new DateTime($message['message']['timestamp']);
             $offset = $this->timezone->getOffset($graylogTime);
 
-            $timeInterval = DateInterval::createFromDateString((string)$offset . 'seconds');
+            $timeInterval = DateInterval::createFromDateString((string) $offset . 'seconds');
             $graylogTime->add($timeInterval);
             $displayTime = $graylogTime->format('Y-m-d H:i:s');
         } else {
@@ -120,7 +119,7 @@ class GraylogController extends SimpleTableController
             'timestamp' => $displayTime,
             'source'    => $device ? Url::deviceLink($device) : $message['message']['source'],
             'message'   => $message['message']['message'] ?? '',
-            'facility'  => is_numeric($facility) ? "($facility) " . __("syslog.facility.$facility"): $facility,
+            'facility'  => is_numeric($facility) ? "($facility) " . __("syslog.facility.$facility") : $facility,
             'level'     => (is_numeric($level) && $level >= 0) ? "($level) " . __("syslog.severity.$level") : $level,
         ];
     }
@@ -128,18 +127,19 @@ class GraylogController extends SimpleTableController
     private function severityLabel($severity)
     {
         $map = [
-            "0" => "label-danger",
-            "1" => "label-danger",
-            "2" => "label-danger",
-            "3" => "label-danger",
-            "4" => "label-warning",
-            "5" => "label-info",
-            "6" => "label-info",
-            "7" => "label-default",
-            ""  => "label-info",
+            '0' => 'label-danger',
+            '1' => 'label-danger',
+            '2' => 'label-danger',
+            '3' => 'label-danger',
+            '4' => 'label-warning',
+            '5' => 'label-info',
+            '6' => 'label-info',
+            '7' => 'label-default',
+            ''  => 'label-info',
         ];
         $barColor = isset($map[$severity]) ? $map[$severity] : 'label-info';
-        return '<span class="alert-status '.$barColor .'" style="margin-right:8px;float:left;"></span>';
+
+        return '<span class="alert-status ' . $barColor . '" style="margin-right:8px;float:left;"></span>';
     }
 
     /**
@@ -149,7 +149,7 @@ class GraylogController extends SimpleTableController
      */
     private function deviceFromSource($source)
     {
-        if (!isset($this->deviceCache[$source])) {
+        if (! isset($this->deviceCache[$source])) {
             $this->deviceCache[$source] = Device::findByIp($source) ?: Device::findByHostname($source);
         }
 
