@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2020 Thomas Berberich
  * @author     Thomas Berberich <sourcehhdoctor@gmail.com>
@@ -26,12 +25,9 @@
 namespace App\Http\Controllers\Table;
 
 use App\Models\DeviceOutage;
-use App\Models\Eventlog;
 use Carbon\Carbon;
 use LibreNMS\Config;
 use LibreNMS\Util\Url;
-use LibreNMS\Enum\Alert;
-use Illuminate\Database\Eloquent\Builder;
 
 class OutagesController extends TableController
 {
@@ -77,7 +73,7 @@ class OutagesController extends TableController
     public function formatItem($outage)
     {
         $start = $this->formatDatetime($outage->going_down);
-        $end =  $outage->up_again ? $this->formatDatetime($outage->up_again) : '-';
+        $end = $outage->up_again ? $this->formatDatetime($outage->up_again) : '-';
         $duration = ($outage->up_again ?: time()) - $outage->going_down;
 
         return [
@@ -93,7 +89,7 @@ class OutagesController extends TableController
     {
         $day_seconds = 86400;
 
-        $duration_days = (int)($duration / $day_seconds);
+        $duration_days = (int) ($duration / $day_seconds);
         $duration_time = $duration % $day_seconds;
 
         $output = "<span style='display:inline;'>";
@@ -101,7 +97,7 @@ class OutagesController extends TableController
             $output .= $duration_days . 'd ';
         }
         $output .= (new Carbon($duration))->format(Config::get('dateformat.time'));
-        $output .= "</span>";
+        $output .= '</span>';
 
         return $output;
     }
@@ -114,7 +110,7 @@ class OutagesController extends TableController
 
         $output = "<span style='display:inline;'>";
         $output .= (new Carbon($timestamp))->format(Config::get('dateformat.compact'));
-        $output .= "</span>";
+        $output .= '</span>';
 
         return $output;
     }
@@ -122,9 +118,9 @@ class OutagesController extends TableController
     private function statusLabel($outage)
     {
         if (empty($outage->up_again)) {
-            $label = "label-danger";
+            $label = 'label-danger';
         } else {
-            $label = "label-success";
+            $label = 'label-success';
         }
 
         $output = "<span class='alert-status " . $label . "'></span>";
