@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2018 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
@@ -59,7 +58,7 @@ class PortNacController extends TableController
             'time_left',
             'authc_status',
             'authz_status',
-            'method'
+            'method',
         ];
     }
 
