@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2019 PipoCanaja
  * @author     PipoCanaja
@@ -25,19 +24,12 @@
 
 namespace App\Http\Controllers\Table;
 
-use App\Models\Ipv4Address;
-use App\Models\Ipv4Network;
-use App\Models\Ipv6Address;
-use App\Models\Route;
-use App\Models\Port;
 use App\Models\Device;
+use App\Models\Route;
 use Illuminate\Database\Eloquent\Builder;
 use Illuminate\Http\Request;
-use Illuminate\Support\Facades\DB;
 use LibreNMS\Util\IP;
-use LibreNMS\Util\Rewrite;
 use LibreNMS\Util\Url;
-use LibreNMS\Exceptions\InvalidIpException;
 
 class RoutesTablesController extends TableController
 {
@@ -48,7 +40,7 @@ class RoutesTablesController extends TableController
         return [
             'device_id' => 'nullable|integer',
             'searchby' => 'in:inetCidrRouteNextHop,inetCidrRouteDest',
-            ];
+        ];
     }
 
     protected function filterFields($request)
@@ -56,7 +48,7 @@ class RoutesTablesController extends TableController
         return [
             'route.context_name' => 'context_name',
             'route.inetCidrRouteProto' => 'proto',
-            ];
+        ];
     }
 
     protected function sortFields($request)
@@ -90,12 +82,12 @@ class RoutesTablesController extends TableController
         $showAllRoutes = trim(\Request::get('showAllRoutes'));
         $showProtocols = trim(\Request::get('showProtocols'));
         if ($showProtocols == 'all') {
-            $protocols = array('ipv4', 'ipv6');
+            $protocols = ['ipv4', 'ipv6'];
         } else {
-            $protocols = array($showProtocols);
+            $protocols = [$showProtocols];
         }
         if ($request->device_id && $showAllRoutes == 'false') {
-            $query=Route::hasAccess($request->user())
+            $query = Route::hasAccess($request->user())
                 ->leftJoin('ports', $join)
                 ->where('route.device_id', $request->device_id)
                 ->whereIn('route.inetCidrRouteDestType', $protocols)
@@ -103,15 +95,18 @@ class RoutesTablesController extends TableController
                     ->where('route.device_id', $request->device_id)
                     ->select('updated_at')
                     ->max('updated_at'));
+
             return $query;
         }
         if ($request->device_id && $showAllRoutes == 'true') {
-            $query=Route::hasAccess($request->user())
+            $query = Route::hasAccess($request->user())
                 ->leftJoin('ports', $join)
                 ->where('route.device_id', $request->device_id)
                 ->whereIn('route.inetCidrRouteDestType', $protocols);
+
             return $query;
         }
+
         return Route::hasAccess($request->user())
             ->leftJoin('ports', $join);
     }
@@ -126,11 +121,13 @@ class RoutesTablesController extends TableController
     {
         if ($search = trim(\Request::get('searchPhrase'))) {
             $searchLike = '%' . $search . '%';
+
             return $query->where(function ($query) use ($searchLike) {
                 return $query->where('route.inetCidrRouteNextHop', 'like', $searchLike)
                     ->orWhere('route.inetCidrRouteDest', 'like', $searchLike);
             });
         }
+
         return $query;
     }
 
@@ -156,13 +153,14 @@ class RoutesTablesController extends TableController
             'updated_at',
             'created_at',
             'context_name',
-            'inetCidrRouteDest'
+            'inetCidrRouteDest',
         ];
         foreach ($s_fields as $s_field) {
             if (isset($sort[$s_field])) {
                 $query->orderBy($s_field, $sort[$s_field]);
             }
         }
+
         return $query;
     }
 
@@ -182,7 +180,7 @@ class RoutesTablesController extends TableController
         if ($route_entry->inetCidrRouteNextHop) {
             try {
                 $obj_inetCidrRouteNextHop = IP::parse($route_entry->inetCidrRouteNextHop);
-                $item['inetCidrRouteNextHop'] =  $obj_inetCidrRouteNextHop->compressed();
+                $item['inetCidrRouteNextHop'] = $obj_inetCidrRouteNextHop->compressed();
             } catch (Exception $e) {
                 $item['inetCidrRouteNextHop'] = $route_entry->inetCidrRouteNextHop;
             }
@@ -190,7 +188,7 @@ class RoutesTablesController extends TableController
         if ($route_entry->inetCidrRouteDest) {
             try {
                 $obj_inetCidrRouteDest = IP::parse($route_entry->inetCidrRouteDest);
-                $item['inetCidrRouteDest'] =  $obj_inetCidrRouteDest->compressed();
+                $item['inetCidrRouteDest'] = $obj_inetCidrRouteDest->compressed();
             } catch (Exception $e) {
                 $item['inetCidrRouteDest'] = $route_entry->inetCidrRouteDest;
             }
@@ -202,9 +200,9 @@ class RoutesTablesController extends TableController
         $device = Device::findByIp($route_entry->inetCidrRouteNextHop);
         if ($device) {
             if ($device->device_id == $route_entry->device_id || in_array($route_entry->inetCidrRouteNextHop, ['127.0.0.1', '::1'])) {
-                $item['inetCidrRouteNextHop'] = Url::deviceLink($device, "localhost");
+                $item['inetCidrRouteNextHop'] = Url::deviceLink($device, 'localhost');
             } else {
-                $item['inetCidrRouteNextHop'] = $item['inetCidrRouteNextHop'] . "<br>(" . Url::deviceLink($device) . ")";
+                $item['inetCidrRouteNextHop'] = $item['inetCidrRouteNextHop'] . '<br>(' . Url::deviceLink($device) . ')';
             }
         }
         if ($route_entry->inetCidrRouteProto && $route_entry::$translateProto[$route_entry->inetCidrRouteProto]) {
@@ -215,8 +213,9 @@ class RoutesTablesController extends TableController
         }
         $item['context_name'] = '[global]';
         if ($route_entry->context_name != '') {
-            $item['context_name'] = '<a href="' . Url::generate(['page' => 'routing', 'protocol' => 'vrf', 'vrf' => $route_entry->context_name]) . '">' . htmlspecialchars($route_entry->context_name) . '</a>' ;
+            $item['context_name'] = '<a href="' . Url::generate(['page' => 'routing', 'protocol' => 'vrf', 'vrf' => $route_entry->context_name]) . '">' . htmlspecialchars($route_entry->context_name) . '</a>';
         }
+
         return $item;
     }
 }
