@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2018 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
@@ -39,7 +38,7 @@ class AvailabilityMapController extends WidgetController
     {
         $this->defaults = [
             'title' => null,
-            'type' => (int)Config::get('webui.availability_map_compact', 0),
+            'type' => (int) Config::get('webui.availability_map_compact', 0),
             'tile_size' => 12,
             'color_only_select' => 0,
             'show_disabled_and_ignored' => 0,
@@ -60,10 +59,10 @@ class AvailabilityMapController extends WidgetController
 
         $mode = $data['mode_select'];
         if ($mode == 0 || $mode == 2) {
-            list($devices, $device_totals) = $this->getDevices($request);
+            [$devices, $device_totals] = $this->getDevices($request);
         }
         if ($mode > 0) {
-            list($services, $services_totals) = $this->getServices($request);
+            [$services, $services_totals] = $this->getServices($request);
         }
 
         $data['device'] = Device::first();
@@ -76,8 +75,6 @@ class AvailabilityMapController extends WidgetController
         return view('widgets.availability-map', $data);
     }
 
-
-
     public function getSettingsView(Request $request)
     {
         return view('widgets.settings.availability-map', $this->getSettings(true));
@@ -98,7 +95,7 @@ class AvailabilityMapController extends WidgetController
             $device_query = Device::hasAccess($request->user());
         }
 
-        if (!$settings['show_disabled_and_ignored']) {
+        if (! $settings['show_disabled_and_ignored']) {
             $device_query->isNotDisabled();
         }
         $device_query->orderBy($settings['order_by']);
@@ -110,12 +107,12 @@ class AvailabilityMapController extends WidgetController
         foreach ($devices as $device) {
             if ($device->disabled) {
                 $totals['disabled']++;
-                $device->stateName = "disabled";
-                $device->labelClass = "blackbg";
+                $device->stateName = 'disabled';
+                $device->labelClass = 'blackbg';
             } elseif ($device->disable_notify) {
                 $totals['ignored']++;
-                $device->stateName = "alert-dis";
-                $device->labelClass = "label-default";
+                $device->stateName = 'alert-dis';
+                $device->labelClass = 'label-default';
             } elseif ($device->status == 1) {
                 if (($device->uptime < $uptime_warn) && ($device->uptime != 0)) {
                     $totals['warn']++;
@@ -137,6 +134,7 @@ class AvailabilityMapController extends WidgetController
                 $totals['maintenance']++;
             }
         }
+
         return [$devices, $totals];
     }
 
@@ -164,19 +162,20 @@ class AvailabilityMapController extends WidgetController
         $totals = ['warn' => 0, 'up' => 0, 'down' => 0];
         foreach ($services as $service) {
             if ($service->service_status == 0) {
-                $service->labelClass = "label-success";
-                $service->stateName = "up";
+                $service->labelClass = 'label-success';
+                $service->stateName = 'up';
                 $totals['up']++;
             } elseif ($service->service_status == 1) {
-                $service->labelClass = "label-warning";
-                $service->stateName = "warn";
+                $service->labelClass = 'label-warning';
+                $service->stateName = 'warn';
                 $totals['warn']++;
             } else {
-                $service->labelClass = "label-danger";
-                $service->stateName = "down";
+                $service->labelClass = 'label-danger';
+                $service->stateName = 'down';
                 $totals['down']++;
             }
         }
+
         return [$services, $totals];
     }
 }
