@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2018 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
@@ -56,13 +55,13 @@ class ComponentStatusController extends WidgetController
             [
                 'color' => 'text-danger',
                 'text' => __('Critical'),
-            ]
+            ],
         ];
 
         $component_status = Component::query()
             ->select('status', DB::raw("count('status') as total"))
             ->groupBy('status')
-            ->where('disabled', "!=", 0)
+            ->where('disabled', '!=', 0)
             ->when($data['device_group'], function ($query) use ($data) {
                 $query->inDeviceGroup($data['device_group']);
             })
