@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2018 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
@@ -60,7 +59,7 @@ abstract class WidgetController extends Controller
 
     public function __invoke(Request $request)
     {
-        $this->show_settings = (bool)$request->get('settings');
+        $this->show_settings = (bool) $request->get('settings');
 
         if ($this->show_settings) {
             $view = $this->getSettingsView($request);
@@ -68,14 +67,14 @@ abstract class WidgetController extends Controller
 
         $settings = $this->getSettings();
 
-        if (!$this->show_settings) {
-            if (!empty($settings['device_group'])) {
+        if (! $this->show_settings) {
+            if (! empty($settings['device_group'])) {
                 $this->title .= ' (' . DeviceGroup::find($settings['device_group'])->name . ')';
             }
             $view = $this->getView($request);
         }
 
-        if (!empty($settings['title'])) {
+        if (! empty($settings['title'])) {
             $title = $settings['title'];
         } else {
             $title = __(method_exists($this, 'title') ? app()->call([$this, 'title']) : $this->title);
@@ -87,6 +86,7 @@ abstract class WidgetController extends Controller
     /**
      * Get the settings (with defaults applied)
      *
+     * @param bool $settingsView
      * @return array
      */
     public function getSettings($settingsView = false)
@@ -94,7 +94,8 @@ abstract class WidgetController extends Controller
         if (is_null($this->settings)) {
             $id = \Request::get('id');
             $widget = UserWidget::find($id);
-            $this->settings = array_replace($this->defaults, $widget ? (array)$widget->settings : []);
+            $this->defaults['refresh'] = $this->defaults['refresh'] ?? 60;
+            $this->settings = array_replace($this->defaults, $widget ? (array) $widget->settings : []);
             $this->settings['id'] = $id;
 
             if ($settingsView && isset($this->settings['device_group'])) {
@@ -116,10 +117,10 @@ abstract class WidgetController extends Controller
     {
         if ($view instanceof View) {
             $html = $view->__toString();
-            $show_settings = (int)Str::startsWith($view->getName(), 'widgets.settings.');
+            $show_settings = (int) Str::startsWith($view->getName(), 'widgets.settings.');
         } else {
-            $html = (string)$view;
-            $show_settings = (int)$this->show_settings;
+            $html = (string) $view;
+            $show_settings = (int) $this->show_settings;
         }
 
         return response()->json([
