@@ -6,9 +6,6 @@ use App\Models\User;
 use Auth;
 use Closure;
 use LibreNMS\Authentication\LegacyAuth;
-use LibreNMS\Config;
-use LibreNMS\Exceptions\AuthenticationException;
-use Log;
 
 class LegacyExternalAuth
 {
@@ -21,7 +18,7 @@ class LegacyExternalAuth
      */
     public function handle($request, Closure $next, $guard = null)
     {
-        if (!Auth::guard($guard)->check()) {
+        if (! Auth::guard($guard)->check()) {
             // check for get variables
             if ($request->isMethod('get') && $request->has(['username', 'password'])) {
                 Auth::attempt($request->only(['username', 'password']));
@@ -30,10 +27,10 @@ class LegacyExternalAuth
             if (LegacyAuth::get()->authIsExternal()) {
                 $credentials = [
                     'username' => LegacyAuth::get()->getExternalUsername(),
-                    'password' => isset($_SERVER['PHP_AUTH_PW']) ? $_SERVER['PHP_AUTH_PW'] : ''
+                    'password' => isset($_SERVER['PHP_AUTH_PW']) ? $_SERVER['PHP_AUTH_PW'] : '',
                 ];
 
-                if (!Auth::guard($guard)->attempt($credentials)) {
+                if (! Auth::guard($guard)->attempt($credentials)) {
                     $message = ''; // no debug info for now...
 
                     // force user to failure page
