@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2018 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
@@ -25,10 +24,13 @@
 
 namespace App\Models;
 
+use Illuminate\Database\Eloquent\Factories\HasFactory;
 use Illuminate\Database\Eloquent\Model;
 
 class Bill extends Model
 {
+    use HasFactory;
+
     public $timestamps = false;
     protected $primaryKey = 'bill_id';
 
@@ -40,7 +42,7 @@ class Bill extends Model
             return $query;
         }
 
-        return $query->join('bill_perms', 'bill_perms.bill_id', "bills.bill_id")
+        return $query->join('bill_perms', 'bill_perms.bill_id', 'bills.bill_id')
             ->where('bill_perms.user_id', $user->user_id);
     }
 
