@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2018 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
@@ -35,7 +34,7 @@ class Config extends BaseModel
         'config_value',
     ];
     protected $casts = [
-        'config_default' => 'array'
+        'config_default' => 'array',
     ];
 
     // ---- Accessors/Mutators ----
