@@ -18,7 +18,7 @@ class NotificationAttrib extends Model
      */
     public function user()
     {
-        return $this->belongsTo('App\Models\User', 'user_id');
+        return $this->belongsTo(\App\Models\User::class, 'user_id');
     }
 
     /**
@@ -26,6 +26,6 @@ class NotificationAttrib extends Model
      */
     public function notification()
     {
-        return $this->belongsTo('App\Models\Notification', 'notifications_id');
+        return $this->belongsTo(\App\Models\Notification::class, 'notifications_id');
     }
 }
