@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2018 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
@@ -25,8 +24,12 @@
 
 namespace App\Models;
 
+use Illuminate\Database\Eloquent\Factories\HasFactory;
+
 class OspfPort extends PortRelatedModel
 {
+    use HasFactory;
+
     public $timestamps = false;
     protected $fillable = [
         'device_id',
@@ -53,6 +56,11 @@ class OspfPort extends PortRelatedModel
         'ospfIfMulticastForwarding',
         'ospfIfDemand',
         'ospfIfAuthType',
+        'ospfIfMetricIpAddress',
+        'ospfIfMetricAddressLessIf',
+        'ospfIfMetricTOS',
+        'ospfIfMetricValue',
+        'ospfIfMetricStatus',
     ];
 
     // ---- Define Relationships ----
