@@ -7,8 +7,8 @@ use Illuminate\Database\Eloquent\Relations\Relation;
 use Illuminate\Support\Facades\Blade;
 use Illuminate\Support\Facades\Log;
 use Illuminate\Support\ServiceProvider;
+use LibreNMS\Cache\PermissionsCache;
 use LibreNMS\Config;
-use LibreNMS\Permissions;
 use LibreNMS\Util\IP;
 use LibreNMS\Util\Validate;
 use Validator;
@@ -26,7 +26,7 @@ class AppServiceProvider extends ServiceProvider
         $this->registerGeocoder();
 
         $this->app->singleton('permissions', function ($app) {
-            return new Permissions();
+            return new PermissionsCache();
         });
         $this->app->singleton('device-cache', function ($app) {
             return new \LibreNMS\Cache\Device();
@@ -40,6 +40,8 @@ class AppServiceProvider extends ServiceProvider
      */
     public function boot()
     {
+        \Illuminate\Pagination\Paginator::useBootstrap();
+
         $this->app->booted('\LibreNMS\DB\Eloquent::initLegacyListeners');
         $this->app->booted('\LibreNMS\Config::load');
 
@@ -55,7 +57,7 @@ class AppServiceProvider extends ServiceProvider
             return \LibreNMS\Config::get($key);
         });
         Blade::if('notconfig', function ($key) {
-            return !\LibreNMS\Config::get($key);
+            return ! \LibreNMS\Config::get($key);
         });
         Blade::if('admin', function () {
             return auth()->check() && auth()->user()->isAdmin();
@@ -79,7 +81,7 @@ class AppServiceProvider extends ServiceProvider
         $sensor_types = [];
         foreach (Sensor::getTypes() as $sensor_type) {
             $sensor_types[$sensor_type] = \App\Models\Sensor::class;
-        };
+        }
         Relation::morphMap(array_merge([
             'interface' => \App\Models\Port::class,
             'sensor' => \App\Models\Sensor::class,
@@ -106,16 +108,20 @@ class AppServiceProvider extends ServiceProvider
             switch ($engine) {
                 case 'mapquest':
                     Log::debug('MapQuest geocode engine');
+
                     return $app->make(\App\ApiClients\MapquestApi::class);
                 case 'bing':
                     Log::debug('Bing geocode engine');
+
                     return $app->make(\App\ApiClients\BingApi::class);
                 case 'openstreetmap':
                     Log::debug('OpenStreetMap geocode engine');
+
                     return $app->make(\App\ApiClients\NominatimApi::class);
                 default:
                 case 'google':
                     Log::debug('Google Maps geocode engine');
+
                     return $app->make(\App\ApiClients\GoogleMapsApi::class);
             }
         });
@@ -134,6 +140,7 @@ class AppServiceProvider extends ServiceProvider
 
         Validator::extend('ip_or_hostname', function ($attribute, $value, $parameters, $validator) {
             $ip = substr($value, 0, strpos($value, '/') ?: strlen($value)); // allow prefixes too
+
             return IP::isValid($ip) || Validate::hostname($value);
         }, __('The :attribute must a valid IP address/network or hostname.'));
 
@@ -147,6 +154,7 @@ class AppServiceProvider extends ServiceProvider
             }
 
             $validator = Validator::make([$attribute => $value], [$attribute => 'exists:' . implode(',', $parameters)]);
+
             return $validator->passes();
         }, __('validation.exists'));
     }
