@@ -15,7 +15,7 @@ class EventServiceProvider extends ServiceProvider
     protected $listen = [
         \Illuminate\Auth\Events\Login::class => ['App\Listeners\AuthEventListener@login'],
         \Illuminate\Auth\Events\Logout::class => ['App\Listeners\AuthEventListener@logout'],
-        \App\Events\UserCreated::class => [MarkNotificationsRead::class]
+        \App\Events\UserCreated::class => [MarkNotificationsRead::class],
     ];
 
     /**
@@ -25,7 +25,6 @@ class EventServiceProvider extends ServiceProvider
      */
     public function boot()
     {
-        parent::boot();
 
         //
     }
