@@ -15,7 +15,7 @@
 
 use LibreNMS\Data\Store\Datastore;
 
-$init_modules = array();
+$init_modules = [];
 require __DIR__ . '/includes/init.php';
 
 $options = getopt('drfpgh:');
@@ -33,33 +33,33 @@ $polled_services = 0;
 $where = '';
 if ($options['h']) {
     if (is_numeric($options['h'])) {
-        $where = "AND `S`.`device_id` = ".$options['h'];
+        $where = 'AND `S`.`device_id` = ' . $options['h'];
     } else {
         if (preg_match('/\*/', $options['h'])) {
-            $where = "AND `hostname` LIKE '".str_replace('*', '%', mres($options['h']))."'";
+            $where = "AND `hostname` LIKE '" . str_replace('*', '%', mres($options['h'])) . "'";
         } else {
-            $where = "AND `hostname` = '".mres($options['h'])."'";
+            $where = "AND `hostname` = '" . mres($options['h']) . "'";
         }
     }
 }
 
 $sql = 'SELECT D.*,S.*,attrib_value  FROM `devices` AS D'
-       .' INNER JOIN `services` AS S ON S.device_id = D.device_id AND D.disabled = 0 '.$where
-       .' LEFT JOIN `devices_attribs` as A ON D.device_id = A.device_id AND A.attrib_type = "override_icmp_disable"'
-       .' ORDER by D.device_id DESC;';
+       . ' INNER JOIN `services` AS S ON S.device_id = D.device_id AND D.disabled = 0 ' . $where
+       . ' LEFT JOIN `devices_attribs` as A ON D.device_id = A.device_id AND A.attrib_type = "override_icmp_disable"'
+       . ' ORDER by D.device_id DESC;';
 
 foreach (dbFetchRows($sql) as $service) {
     // Run the polling function if service is enabled and the associated device is up, "Disable ICMP Test" option is not enabled,
     // or service hostname/ip is different from associated device
-    if (!$service['service_disabled'] && ($service['status'] == 1 || ($service['status'] == 0 && $service['status_reason'] === 'snmp') ||
+    if (! $service['service_disabled'] && ($service['status'] == 1 || ($service['status'] == 0 && $service['status_reason'] === 'snmp') ||
         $service['attrib_value'] === 'true' || ($service['service_ip'] !== $service['hostname'] &&
-        $service['service_ip'] !== inet6_ntop($service['ip']) ))) {
+        $service['service_ip'] !== inet6_ntop($service['ip'])))) {
         poll_service($service);
         $polled_services++;
     } else {
-        if (!$service['service_disabled']) {
-            d_echo("\nService check - ".$service['service_id']."\nSkipping service check because device "
-                .$service['hostname']." is down due to icmp.\n");
+        if (! $service['service_disabled']) {
+            d_echo("\nService check - " . $service['service_id'] . "\nSkipping service check because device "
+                . $service['hostname'] . " is down due to icmp.\n");
             Log::event(
                 "Service check - {$service['service_desc']} ({$service['service_id']}) - 
                 Skipping service check because device {$service['hostname']} is down due to icmp",
@@ -69,19 +69,18 @@ foreach (dbFetchRows($sql) as $service) {
                 $service['service_id']
             );
         } else {
-            d_echo("\nService check - ".$service['service_id']."\nSkipping service check because device "
-                .$service['service_type']." is disabled.\n");
+            d_echo("\nService check - " . $service['service_id'] . "\nSkipping service check because device "
+                . $service['service_type'] . " is disabled.\n");
         }
     }
 }
 
-$poller_end  = microtime(true);
-$poller_run  = ($poller_end - $poller_start);
+$poller_end = microtime(true);
+$poller_run = ($poller_end - $poller_start);
 $poller_time = substr($poller_run, 0, 5);
 
-
-$string = $argv[0] . " " . date(\LibreNMS\Config::get('dateformat.compact'))
-    ." - $polled_services services polled in $poller_time secs";
+$string = $argv[0] . ' ' . date(\LibreNMS\Config::get('dateformat.compact'))
+    . " - $polled_services services polled in $poller_time secs";
 d_echo("$string\n");
 
 Datastore::terminate();
