@@ -1,4 +1,4 @@
-#!/usr/local/bin/php-7.3
+#!/usr/bin/env php
 <?php
 
 /*
@@ -13,5 +13,8 @@ $init_modules = ['nodb'];
 require __DIR__ . '/includes/init.php';
 
 if (isCli()) {
+    // fill in db variables for legacy external scripts
+    Config::populateLegacyDbCredentials();
+
     echo Config::toJson();
 }
