@@ -11,11 +11,9 @@ use App\Models\DeviceGroup;
 use Illuminate\Database\Eloquent\Collection;
 use LibreNMS\Alert\AlertDB;
 use LibreNMS\Config;
-use LibreNMS\Exceptions\LockException;
-use LibreNMS\Util\MemcacheLock;
 use LibreNMS\Validations\Php;
 
-$init_modules = array('alerts');
+$init_modules = ['alerts'];
 require __DIR__ . '/includes/init.php';
 include_once __DIR__ . '/includes/notifications.php';
 
@@ -27,7 +25,7 @@ if (isset($options['d'])) {
 }
 
 if ($options['f'] === 'update') {
-    if (!Config::get('update')) {
+    if (! Config::get('update')) {
         exit(0);
     }
 
@@ -40,59 +38,50 @@ if ($options['f'] === 'update') {
 }
 
 if ($options['f'] === 'rrd_purge') {
-    try {
-        if (Config::get('distributed_poller')) {
-            MemcacheLock::lock('rrd_purge', 0, 86000);
-        }
-
+    $lock = Cache::lock('rrd_purge', 86000);
+    if ($lock->get()) {
         $rrd_purge = Config::get('rrd_purge');
         $rrd_dir = Config::get('rrd_dir');
 
         if (is_numeric($rrd_purge) && $rrd_purge > 0) {
             $cmd = "find $rrd_dir -type f -mtime +$rrd_purge -print -exec rm -f {} +";
             $purge = `$cmd`;
-            if (!empty($purge)) {
+            if (! empty($purge)) {
                 echo "Purged the following RRD files due to old age (over $rrd_purge days old):\n";
                 echo $purge;
             }
         }
-    } catch (LockException $e) {
-        echo $e->getMessage() . PHP_EOL;
-        exit(-1);
+        $lock->release();
     }
 }
 
 if ($options['f'] === 'syslog') {
-    try {
-        if (Config::get('distributed_poller')) {
-            MemcacheLock::lock('syslog_purge', 0, 86000);
-        }
+    $lock = Cache::lock('syslog_purge', 86000);
+    if ($lock->get()) {
         $syslog_purge = Config::get('syslog_purge');
 
         if (is_numeric($syslog_purge)) {
-            $rows = (int)dbFetchCell('SELECT MIN(seq) FROM syslog');
+            $rows = (int) dbFetchCell('SELECT MIN(seq) FROM syslog');
             $initial_rows = $rows;
             while (true) {
-                $limit = dbFetchCell('SELECT seq FROM syslog WHERE seq >= ? ORDER BY seq LIMIT 1000,1', array($rows));
+                $limit = dbFetchCell('SELECT seq FROM syslog WHERE seq >= ? ORDER BY seq LIMIT 1000,1', [$rows]);
                 if (empty($limit)) {
                     break;
                 }
 
-                # Deletes are done in blocks of 1000 to avoid a single very large operation.
-                if (dbDelete('syslog', 'seq >= ? AND seq < ? AND timestamp < DATE_SUB(NOW(), INTERVAL ? DAY)', array($rows, $limit, $syslog_purge)) > 0) {
+                // Deletes are done in blocks of 1000 to avoid a single very large operation.
+                if (dbDelete('syslog', 'seq >= ? AND seq < ? AND timestamp < DATE_SUB(NOW(), INTERVAL ? DAY)', [$rows, $limit, $syslog_purge]) > 0) {
                     $rows = $limit;
                 } else {
                     break;
                 }
             }
 
-            dbDelete('syslog', 'seq >= ? AND timestamp < DATE_SUB(NOW(), INTERVAL ? DAY)', array($rows, $syslog_purge));
+            dbDelete('syslog', 'seq >= ? AND timestamp < DATE_SUB(NOW(), INTERVAL ? DAY)', [$rows, $syslog_purge]);
             $final_rows = $rows - $initial_rows;
             echo "Syslog cleared for entries over $syslog_purge days (about $final_rows rows)\n";
         }
-    } catch (LockException $e) {
-        echo $e->getMessage() . PHP_EOL;
-        exit(-1);
+        $lock->release();
     }
 }
 
@@ -129,13 +118,9 @@ if ($options['f'] === 'device_perf') {
 }
 
 if ($options['f'] === 'ports_purge') {
-    try {
-        if (Config::get('distributed_poller')) {
-            MemcacheLock::lock('ports_purge', 0, 86000);
-        }
-        $ports_purge = Config::get('ports_purge');
-
-        if ($ports_purge) {
+    if (Config::get('ports_purge')) {
+        $lock = Cache::lock('syslog_purge', 86000);
+        if ($lock->get()) {
             \App\Models\Port::query()->with(['device' => function ($query) {
                 $query->select('device_id', 'hostname');
             }])->isDeleted()->chunk(100, function ($ports) {
@@ -144,10 +129,8 @@ if ($options['f'] === 'ports_purge') {
                 }
             });
             echo "All deleted ports now purged\n";
+            $lock->release();
         }
-    } catch (LockException $e) {
-        echo $e->getMessage() . PHP_EOL;
-        exit(-1);
     }
 }
 
@@ -176,16 +159,16 @@ if ($options['f'] === 'handle_notifiable') {
         // if update is not set to false and version is min or newer
         if (Config::get('update') && $options['r']) {
             if ($options['r'] === 'php53') {
-                $phpver   = '5.6.4';
+                $phpver = '5.6.4';
                 $eol_date = 'January 10th, 2018';
-            } elseif ($options['r'] === 'php56' || $options['r'] === 'php71') {
-                $phpver   = Php::PHP_MIN_VERSION;
+            } elseif ($options['r'] === 'php56' || $options['r'] === 'php71' || $options['r'] === 'php72') {
+                $phpver = Php::PHP_MIN_VERSION;
                 $eol_date = Php::PHP_MIN_VERSION_DATE;
             }
             if (isset($phpver)) {
                 new_notification(
                     $error_title,
-                    "PHP version $phpver is the minimum supported version as of $eol_date.  We recommend you update to PHP a supported version of PHP (" . Php::PHP_RECOMMENDED_VERSION . " suggested) to continue to receive updates.  If you do not update PHP, LibreNMS will continue to function but stop receiving bug fixes and updates.",
+                    "PHP version $phpver is the minimum supported version as of $eol_date.  We recommend you update to PHP a supported version of PHP (" . Php::PHP_RECOMMENDED_VERSION . ' suggested) to continue to receive updates.  If you do not update PHP, LibreNMS will continue to function but stop receiving bug fixes and updates.',
                     2,
                     'daily.sh'
                 );
@@ -203,7 +186,7 @@ if ($options['f'] === 'handle_notifiable') {
             if ($options['r'] === 'python3-missing') {
                 new_notification(
                     $error_title,
-                    "Python 3 is required to run LibreNMS as of May, 2020. You need to install Python 3 to continue to receive updates.  If you do not install Python 3 and required packages, LibreNMS will continue to function but stop receiving bug fixes and updates.",
+                    'Python 3 is required to run LibreNMS as of May, 2020. You need to install Python 3 to continue to receive updates.  If you do not install Python 3 and required packages, LibreNMS will continue to function but stop receiving bug fixes and updates.',
                     2,
                     'daily.sh'
                 );
@@ -211,7 +194,7 @@ if ($options['f'] === 'handle_notifiable') {
             } elseif ($options['r'] === 'python3-deps') {
                 new_notification(
                     $error_title,
-                    "Python 3 dependencies are missing. You need to install them via pip3 install -r requirements.txt or system packages to continue to receive updates.  If you do not install Python 3 and required packages, LibreNMS will continue to function but stop receiving bug fixes and updates.",
+                    'Python 3 dependencies are missing. You need to install them via pip3 install -r requirements.txt or system packages to continue to receive updates.  If you do not install Python 3 and required packages, LibreNMS will continue to function but stop receiving bug fixes and updates.',
                     2,
                     'daily.sh'
                 );
@@ -225,23 +208,18 @@ if ($options['f'] === 'handle_notifiable') {
 }
 
 if ($options['f'] === 'notifications') {
-    try {
-        if (Config::get('distributed_poller')) {
-            MemcacheLock::lock('notifications', 0, 86000);
-        }
-
+    $lock = Cache::lock('notifications', 86000);
+    if ($lock->get()) {
         post_notifications();
-    } catch (LockException $e) {
-        echo $e->getMessage() . PHP_EOL;
-        exit(-1);
+        $lock->release();
     }
 }
 
 if ($options['f'] === 'bill_data') {
-    # Deletes data older than XX months before the start of the last complete billing period
+    // Deletes data older than XX months before the start of the last complete billing period
     $msg = "Deleting billing data more than %d month before the last completed billing cycle\n";
     $table = 'bill_data';
-    $sql = "DELETE bill_data
+    $sql = 'DELETE bill_data
             FROM bill_data
                 INNER JOIN (SELECT bill_id,
                     SUBDATE(
@@ -252,27 +230,27 @@ if ($options['f'] === 'bill_data') {
                             INTERVAL IF(bill_day > DAY(curdate()), 1, 0) MONTH),    # Deal with anniversary not yet happened this month
                         INTERVAL ? MONTH) AS threshold                              # Adjust based on config threshold
             FROM bills) q
-            ON bill_data.bill_id = q.bill_id AND bill_data.timestamp < q.threshold;";
+            ON bill_data.bill_id = q.bill_id AND bill_data.timestamp < q.threshold;';
     lock_and_purge_query($table, $sql, $msg);
 }
 
 if ($options['f'] === 'alert_log') {
     $msg = "Deleting alert_logs more than %d days that are not active\n";
     $table = 'alert_log';
-    $sql = "DELETE alert_log
+    $sql = 'DELETE alert_log
                 FROM alert_log
                 INNER JOIN alerts
                 ON alerts.device_id=alert_log.device_id AND alerts.rule_id=alert_log.rule_id
                 WHERE alerts.state=0 AND alert_log.time_logged < DATE_SUB(NOW(),INTERVAL ? DAY)
-                ";
+                ';
     lock_and_purge_query($table, $sql, $msg);
 
-    # alert_log older than $config['alert_log_purge'] days match now only the alert_log of active alerts
-    # in case of flapping of an alert, many entries are kept in alert_log
-    # we want only to keep the last alert_log that contains the alert details
+    // alert_log older than $config['alert_log_purge'] days match now only the alert_log of active alerts
+    // in case of flapping of an alert, many entries are kept in alert_log
+    // we want only to keep the last alert_log that contains the alert details
 
     $msg = "Deleting history of active alert_logs more than %d days\n";
-    $sql = "DELETE
+    $sql = 'DELETE
                     FROM alert_log
                     WHERE id IN(
                         SELECT id FROM(
@@ -287,22 +265,18 @@ if ($options['f'] === 'alert_log') {
                                 )
                         ) as c
                     )
-                ";
+                ';
     $purge_duration = Config::get('alert_log_purge');
-    if (!(is_numeric($purge_duration) && $purge_duration > 0)) {
+    if (! (is_numeric($purge_duration) && $purge_duration > 0)) {
         return -2;
     }
-    $sql = str_replace("?", strval($purge_duration), $sql);
+    $sql = str_replace('?', strval($purge_duration), $sql);
     lock_and_purge_query($table, $sql, $msg);
 }
 
-
 if ($options['f'] === 'purgeusers') {
-    try {
-        if (Config::get('distributed_poller')) {
-            MemcacheLock::lock('purgeusers', 0, 86000);
-        }
-
+    $lock = Cache::lock('purgeusers', 86000);
+    if ($lock->get()) {
         $purge = 0;
         if (is_numeric(\LibreNMS\Config::get('radius.users_purge')) && Config::get('auth_mechanism') === 'radius') {
             $purge = \LibreNMS\Config::get('radius.users_purge');
@@ -311,50 +285,41 @@ if ($options['f'] === 'purgeusers') {
             $purge = \LibreNMS\Config::get('active_directory.users_purge');
         }
         if ($purge > 0) {
-            foreach (dbFetchRows("SELECT DISTINCT(`user`) FROM `authlog` WHERE `datetime` >= DATE_SUB(NOW(), INTERVAL ? DAY)", array($purge)) as $user) {
-                $users[] = $user['user'];
-            }
+            $users = \App\Models\AuthLog::where('datetime', '>=', \Carbon\Carbon::now()->subDays($purge))
+                ->distinct()->pluck('user')
+                ->merge(\App\Models\User::has('apiToken')->pluck('username')) // don't purge users with api tokens
+                ->unique();
 
-            if (dbDelete('users', "username NOT IN " . dbGenPlaceholders(count($users)), $users)) {
-                echo "Removed users that haven't logged in for $purge days";
+            if (\App\Models\User::thisAuth()->whereNotIn('username', $users)->delete()) {
+                echo "Removed users that haven't logged in for $purge days\n";
             }
         }
-    } catch (LockException $e) {
-        echo $e->getMessage() . PHP_EOL;
-        exit(-1);
+        $lock->release();
     }
 }
 
 if ($options['f'] === 'refresh_alert_rules') {
-    try {
-        if (Config::get('distributed_poller')) {
-            MemcacheLock::lock('refresh_alert_rules', 0, 86000);
-        }
-
+    $lock = Cache::lock('refresh_alert_rules', 86000);
+    if ($lock->get()) {
         echo 'Refreshing alert rules queries' . PHP_EOL;
         $rules = dbFetchRows('SELECT `id`, `rule`, `builder`, `extra` FROM `alert_rules`');
         foreach ($rules as $rule) {
             $rule_options = json_decode($rule['extra'], true);
             if ($rule_options['options']['override_query'] !== 'on') {
                 $data['query'] = AlertDB::genSQL($rule['rule'], $rule['builder']);
-                if (!empty($data['query'])) {
-                    dbUpdate($data, 'alert_rules', 'id=?', array($rule['id']));
+                if (! empty($data['query'])) {
+                    dbUpdate($data, 'alert_rules', 'id=?', [$rule['id']]);
                     unset($data);
                 }
             }
         }
-    } catch (LockException $e) {
-        echo $e->getMessage() . PHP_EOL;
-        exit(-1);
+        $lock->release();
     }
 }
 
 if ($options['f'] === 'refresh_device_groups') {
-    try {
-        if (Config::get('distributed_poller')) {
-            MemcacheLock::lock('refresh_device_groups', 0, 86000);
-        }
-
+    $lock = Cache::lock('refresh_device_groups', 86000);
+    if ($lock->get()) {
         echo 'Refreshing device group table relationships' . PHP_EOL;
         DeviceGroup::all()->each(function ($deviceGroup) {
             if ($deviceGroup->type == 'dynamic') {
@@ -363,9 +328,7 @@ if ($options['f'] === 'refresh_device_groups') {
                 $deviceGroup->save();
             }
         });
-    } catch (LockException $e) {
-        echo $e->getMessage() . PHP_EOL;
-        exit(-1);
+        $lock->release();
     }
 }
 
@@ -380,14 +343,10 @@ if ($options['f'] === 'notify') {
 }
 
 if ($options['f'] === 'peeringdb') {
-    try {
-        if (Config::get('distributed_poller')) {
-            MemcacheLock::lock('peeringdb', 0, 86000);
-        }
+    $lock = Cache::lock('peeringdb', 86000);
+    if ($lock->get()) {
         cache_peeringdb();
-    } catch (LockException $e) {
-        echo $e->getMessage() . PHP_EOL;
-        exit(-1);
+        $lock->release();
     }
 }
 
@@ -399,10 +358,8 @@ if ($options['f'] === 'refresh_os_cache') {
 if ($options['f'] === 'recalculate_device_dependencies') {
     // fix broken dependency max_depth calculation in case things weren't done though eloquent
 
-    try {
-        if (Config::get('distributed_poller')) {
-            MemcacheLock::lock('recalculate_device_dependencies', 0, 86000);
-        }
+    $lock = Cache::lock('recalculate_device_dependencies', 86000);
+    if ($lock->get()) {
         \LibreNMS\DB\Eloquent::boot();
 
         // update all root nodes and recurse, chunk so we don't blow up
@@ -416,8 +373,6 @@ if ($options['f'] === 'recalculate_device_dependencies') {
 
             $devices->each($recurse);
         });
-    } catch (LockException $e) {
-        echo $e->getMessage() . PHP_EOL;
-        exit(-1);
+        $lock->release();
     }
 }
