@@ -18,29 +18,26 @@
  * @author Daniel Preussker
  * @copyright 2015 Daniel Preussker, QuxLabs UG
  * @license GPL
- * @package LibreNMS
- * @subpackage Notifications
  */
-
-$data['count']  = array(
+$data['count'] = [
     'query'  => 'select count(notifications.notifications_id) from notifications where not exists( select 1 from notifications_attribs where notifications.notifications_id = notifications_attribs.notifications_id and notifications_attribs.user_id = ?)',
-    'params' => array( Auth::id() )
-);
+    'params' => [Auth::id()],
+];
 
-$data['unread'] = array(
+$data['unread'] = [
     'query'  => 'select notifications.* from notifications where not exists( select 1 from notifications_attribs where notifications.notifications_id = notifications_attribs.notifications_id and notifications_attribs.user_id = ?) order by notifications.notifications_id desc',
-    'params' => array( Auth::id() )
-);
+    'params' => [Auth::id()],
+];
 
-$data['sticky'] = array(
+$data['sticky'] = [
     'query'  => 'select notifications.*,notifications_attribs.user_id from notifications inner join notifications_attribs on notifications.notifications_id = notifications_attribs.notifications_id where notifications_attribs.key = "sticky" && notifications_attribs.value = 1 order by notifications_attribs.attrib_id desc',
-);
+];
 
-$data['sticky_count'] = array(
+$data['sticky_count'] = [
     'query'  => 'select count(notifications.notifications_id) from notifications inner join notifications_attribs on notifications.notifications_id = notifications_attribs.notifications_id where notifications_attribs.key = "sticky" && notifications_attribs.value = 1',
-);
+];
 
-$data['read'] = array(
+$data['read'] = [
     'query'  => 'select notifications.* from notifications inner join notifications_attribs on notifications.notifications_id = notifications_attribs.notifications_id where notifications_attribs.user_id = ? && ( notifications_attribs.key = "read" && notifications_attribs.value = 1) && not exists( select 1 from notifications_attribs where notifications.notifications_id = notifications_attribs.notifications_id and notifications_attribs.key = "sticky" && notifications_attribs.value = "1") order by notifications_attribs.attrib_id desc',
-    'params' => array( Auth::id() )
-);
+    'params' => [Auth::id()],
+];
