@@ -16,8 +16,8 @@ if ($device['os'] == 'ironware') {
         foreach ($fdp_if_array as $entry_key => $fdp) {
             $remote_device_id = find_device_id($fdp['snFdpCacheDeviceId']);
 
-            if (!$remote_device_id &&
-                !can_skip_discovery($fdp['snFdpCacheDeviceId'], $fdp['snFdpCacheVersion'])
+            if (! $remote_device_id &&
+                ! can_skip_discovery($fdp['snFdpCacheDeviceId'], $fdp['snFdpCacheVersion'])
             ) {
                 if (Config::get('autodiscovery.xdp') === true) {
                     $remote_device_id = discover_new_device($fdp['snFdpCacheDeviceId'], $device, 'FDP', $interface);
@@ -53,13 +53,13 @@ foreach ($cdp_array as $key => $cdp_if_array) {
         $cdp_ip = IP::fromHexString($cdp['cdpCacheAddress'], true);
         $remote_device_id = find_device_id($cdp['cdpCacheDeviceId'], $cdp_ip);
 
-        if (!$remote_device_id &&
-            !can_skip_discovery($cdp['cdpCacheDeviceId'], $cdp['cdpCacheVersion'], $cdp['cdpCachePlatform'] &&
-            Config::get('autodiscovery.xdp') === true)
+        if (! $remote_device_id &&
+            ! can_skip_discovery($cdp['cdpCacheDeviceId'], $cdp['cdpCacheVersion'], $cdp['cdpCachePlatform']) &&
+            Config::get('autodiscovery.xdp') === true
         ) {
             $remote_device_id = discover_new_device($cdp['cdpCacheDeviceId'], $device, 'CDP', $interface);
 
-            if (!$remote_device_id && Config::get('discovery_by_ip', false)) {
+            if (! $remote_device_id && Config::get('discovery_by_ip', false)) {
                 $remote_device_id = discover_new_device($cdp_ip, $device, 'CDP', $interface);
             }
         }
@@ -84,25 +84,24 @@ echo PHP_EOL;
 
 if (($device['os'] == 'routeros')) {
     echo ' LLDP-MIB: ';
-    $lldp_array  = snmpwalk_group($device, 'lldpRemEntry', 'LLDP-MIB', 3);
-    if (!empty($lldp_array)) {
+    $lldp_array = snmpwalk_group($device, 'lldpRemEntry', 'LLDP-MIB', 3);
+    if (! empty($lldp_array)) {
         $lldp_ports = snmpwalk_group($device, 'mtxrInterfaceStatsName', 'MIKROTIK-MIB');
         $lldp_ports_num = snmpwalk_group($device, 'mtxrNeighborInterfaceID', 'MIKROTIK-MIB');
-    
 
         foreach ($lldp_array as $key => $lldp) {
             $local_port_ifName = $lldp_ports[hexdec($lldp_ports_num[$key]['mtxrNeighborInterfaceID'])]['mtxrInterfaceStatsName'];
             $local_port_id = find_port_id($local_port_ifName, null, $device['device_id']);
             $interface = get_port_by_id($local_port_id);
             if ($lldp['lldpRemPortIdSubtype'] == 3) { // 3 = macaddress
-                $remote_port_mac = str_replace(array(' ', ':', '-'), '', strtolower($lldp['lldpRemPortId']));
+                $remote_port_mac = str_replace([' ', ':', '-'], '', strtolower($lldp['lldpRemPortId']));
             }
 
             $remote_device_id = find_device_id($lldp['lldpRemSysName'], $lldp['lldpRemManAddr'], $remote_port_mac);
 
-            if (!$remote_device_id &&
+            if (! $remote_device_id &&
                 is_valid_hostname($lldp['lldpRemSysName']) &&
-                !can_skip_discovery($lldp['lldpRemSysName'], $lldp['lldpRemSysDesc']) &&
+                ! can_skip_discovery($lldp['lldpRemSysName'], $lldp['lldpRemSysDesc']) &&
                 Config::get('autodiscovery.xdp') === true) {
                 $remote_device_id = discover_new_device($lldp['lldpRemSysName'], $device, 'LLDP', $interface);
             }
@@ -126,16 +125,16 @@ if (($device['os'] == 'routeros')) {
     echo PHP_EOL;
 } elseif (($device['os'] == 'pbn' || $device['os'] == 'bdcom')) {
     echo ' NMS-LLDP-MIB: ';
-    $lldp_array  = snmpwalk_group($device, 'lldpRemoteSystemsData', 'NMS-LLDP-MIB');
+    $lldp_array = snmpwalk_group($device, 'lldpRemoteSystemsData', 'NMS-LLDP-MIB');
 
     foreach ($lldp_array as $key => $lldp) {
         d_echo($lldp);
         $interface = get_port_by_ifIndex($device['device_id'], $lldp['lldpRemLocalPortNum']);
         $remote_device_id = find_device_id($lldp['lldpRemSysName']);
 
-        if (!$remote_device_id &&
+        if (! $remote_device_id &&
             is_valid_hostname($lldp['lldpRemSysName']) &&
-            !can_skip_discovery($lldp['lldpRemSysName'], $lldp['lldpRemSysDesc'] &&
+            ! can_skip_discovery($lldp['lldpRemSysName'], $lldp['lldpRemSysDesc'] &&
             Config::get('autodiscovery.xdp') === true)
         ) {
             $remote_device_id = discover_new_device($lldp['lldpRemSysName'], $device, 'LLDP', $interface);
@@ -159,7 +158,7 @@ if (($device['os'] == 'routeros')) {
     echo PHP_EOL;
 } elseif (($device['os'] == 'timos')) {
     echo ' TIMETRA-LLDP-MIB: ';
-    $lldp_array  = snmpwalk_group($device, 'tmnxLldpRemoteSystemsData', 'TIMETRA-LLDP-MIB');
+    $lldp_array = snmpwalk_group($device, 'tmnxLldpRemoteSystemsData', 'TIMETRA-LLDP-MIB');
     foreach ($lldp_array as $key => $lldp) {
         $ifIndex = key($lldp['tmnxLldpRemPortId']);
         $MacIndex = key($lldp['tmnxLldpRemPortId'][$ifIndex]);
@@ -167,9 +166,9 @@ if (($device['os'] == 'routeros')) {
         $interface = get_port_by_ifIndex($device['device_id'], $ifIndex);
         $remote_device_id = find_device_id($lldp['tmnxLldpRemSysName'][$ifIndex][$MacIndex][$RemIndex]);
 
-        if (!$remote_device_id &&
+        if (! $remote_device_id &&
             is_valid_hostname($lldp['tmnxLldpRemSysName'][$ifIndex][$MacIndex][$RemIndex]) &&
-            !can_skip_discovery($lldp['tmnxLldpRemSysName'][$ifIndex][$MacIndex][$RemIndex], $lldp['tmnxLldpRemSysDesc'][$ifIndex][$MacIndex][$RemIndex]) &&
+            ! can_skip_discovery($lldp['tmnxLldpRemSysName'][$ifIndex][$MacIndex][$RemIndex], $lldp['tmnxLldpRemSysDesc'][$ifIndex][$MacIndex][$RemIndex]) &&
             Config::get('autodiscovery.xdp') === true
         ) {
             $remote_device_id = discover_new_device($lldp['tmnxLldpRemSysName'][$ifIndex][$MacIndex][$RemIndex], $device, 'LLDP', $interface);
@@ -194,7 +193,7 @@ if (($device['os'] == 'routeros')) {
 } else {
     echo ' LLDP-MIB: ';
     $lldp_array = snmpwalk_group($device, 'lldpRemTable', 'LLDP-MIB', 3);
-    if (!empty($lldp_array)) {
+    if (! empty($lldp_array)) {
         $lldp_remAddr_num = snmpwalk_cache_multi_oid($device, '.1.0.8802.1.1.2.1.4.2.1.3', [], 'LLDP-MIB', null, '-OQun');
         foreach ($lldp_remAddr_num as $key => $value) {
             $res = preg_match("/1\.0\.8802\.1\.1\.2\.1\.4\.2\.1\.3\.([^\.]*)\.([^\.]*)\.([^\.]*)\.([^\.]*)\.([^\.]*).(([^\.]*)(\.([^\.]*))+)/", $key, $matches);
@@ -239,17 +238,17 @@ if (($device['os'] == 'routeros')) {
                 // normalize MAC address if present
                 $remote_port_mac = '';
                 if ($lldp['lldpRemPortIdSubtype'] == 3) { // 3 = macaddress
-                    $remote_port_mac = str_replace(array(' ', ':', '-'), '', strtolower($lldp['lldpRemPortId']));
+                    $remote_port_mac = str_replace([' ', ':', '-'], '', strtolower($lldp['lldpRemPortId']));
                 }
 
                 $remote_device_id = find_device_id($lldp['lldpRemSysName'], $lldp['lldpRemManAddr'], $remote_port_mac);
 
                 // add device if configured to do so
-                if (!$remote_device_id && !can_skip_discovery($lldp['lldpRemSysName'], $lldp['lldpRemSysDesc']) &&
+                if (! $remote_device_id && ! can_skip_discovery($lldp['lldpRemSysName'], $lldp['lldpRemSysDesc']) &&
                 Config::get('autodiscovery.xdp') === true) {
                     $remote_device_id = discover_new_device($lldp['lldpRemSysName'], $device, 'LLDP', $interface);
 
-                    if (!$remote_device_id && Config::get('discovery_by_ip', false)) {
+                    if (! $remote_device_id && Config::get('discovery_by_ip', false)) {
                         $ptopo_array = snmpwalk_group($device, 'ptopoConnEntry', 'PTOPO-MIB');
                         d_echo($ptopo_array);
                         foreach ($ptopo_array as $ptopo) {
@@ -259,7 +258,7 @@ if (($device['os'] == 'routeros')) {
                                 break;
                             }
                         }
-                        if (!$remote_device_id && isset($lldp['lldpRemManAddr'])) {
+                        if (! $remote_device_id && isset($lldp['lldpRemManAddr'])) {
                             $remote_device_id = discover_new_device($lldp['lldpRemManAddr'], $device, 'LLDP', $interface);
                         }
                         unset($ptopo_array);
@@ -274,13 +273,13 @@ if (($device['os'] == 'routeros')) {
                 if ($remote_device['os'] == 'xos') {
                     $slot_port = explode(':', $lldp['lldpRemPortId']);
                     if (sizeof($slot_port) == 2) {
-                        $n_slot = (int)$slot_port[0];
-                        $n_port = (int)$slot_port[1];
+                        $n_slot = (int) $slot_port[0];
+                        $n_port = (int) $slot_port[1];
                     } else {
                         $n_slot = 1;
-                        $n_port = (int)$slot_port[0];
+                        $n_port = (int) $slot_port[0];
                     }
-                    $lldp['lldpRemPortId'] = (string)($n_slot * 1000 + $n_port);
+                    $lldp['lldpRemPortId'] = (string) ($n_slot * 1000 + $n_port);
                 }
 
                 $remote_port_id = find_port_id(
@@ -320,7 +319,7 @@ if (($device['os'] == 'routeros')) {
 if (Config::get('autodiscovery.ospf') === true) {
     echo ' OSPF Discovery: ';
     $sql = 'SELECT DISTINCT(`ospfNbrIpAddr`),`device_id` FROM `ospf_nbrs` WHERE `device_id`=?';
-    foreach (dbFetchRows($sql, array($device['device_id'])) as $nbr) {
+    foreach (dbFetchRows($sql, [$device['device_id']]) as $nbr) {
         try {
             $ip = IP::parse($nbr['ospfNbrIpAddr']);
 
@@ -329,7 +328,7 @@ if (Config::get('autodiscovery.ospf') === true) {
                 continue;
             }
 
-            if (!$ip->inNetworks(Config::get('nets'))) {
+            if (! $ip->inNetworks(Config::get('nets'))) {
                 echo 'i';
                 continue;
             }
@@ -345,22 +344,22 @@ if (Config::get('autodiscovery.ospf') === true) {
 
 d_echo($link_exists);
 
-$sql = "SELECT * FROM `links` AS L, `ports` AS I WHERE L.local_port_id = I.port_id AND I.device_id = ?";
-foreach (dbFetchRows($sql, array($device['device_id'])) as $test) {
-    $local_port_id   = $test['local_port_id'];
+$sql = 'SELECT * FROM `links` AS L, `ports` AS I WHERE L.local_port_id = I.port_id AND I.device_id = ?';
+foreach (dbFetchRows($sql, [$device['device_id']]) as $test) {
+    $local_port_id = $test['local_port_id'];
     $remote_hostname = $test['remote_hostname'];
-    $remote_port     = $test['remote_port'];
+    $remote_port = $test['remote_port'];
     d_echo("$local_port_id -> $remote_hostname -> $remote_port \n");
 
-    if (!$link_exists[$local_port_id][$remote_hostname][$remote_port]) {
+    if (! $link_exists[$local_port_id][$remote_hostname][$remote_port]) {
         echo '-';
-        $rows = dbDelete('links', '`id` = ?', array($test['id']));
+        $rows = dbDelete('links', '`id` = ?', [$test['id']]);
         d_echo("$rows deleted ");
     }
 }
 
 // remove orphaned links
-$deleted = (int)dbDeleteOrphans('links', array('devices.device_id.local_device_id'));
+$deleted = (int) dbDeleteOrphans('links', ['devices.device_id.local_device_id']);
 echo str_repeat('-', $deleted);
 d_echo(" $deleted orphaned links deleted\n");
 
