@@ -5,16 +5,16 @@ use Illuminate\Support\Str;
 echo "\nCaching OIDs:";
 
 if ($device['os'] == 'junos') {
-    $entity_array = array();
+    $entity_array = [];
     echo ' jnxBoxAnatomy';
     $entity_array = snmpwalk_cache_oid($device, 'jnxBoxAnatomy', $entity_array, 'JUNIPER-MIB');
 } elseif ($device['os'] == 'aruba-instant') {
-    $entity_array = array();
+    $entity_array = [];
     echo 'aruba-instant';
 
     $ai_mib = 'AI-AP-MIB';
     $ai_ig_data = snmpwalk_group($device, 'aiInfoGroup', $ai_mib);
-     discover_entity_physical(
+    discover_entity_physical(
          $valid,
          $device,
          1,                                              // entPhysicalIndex
@@ -39,15 +39,15 @@ if ($device['os'] == 'junos') {
     $entity_array = snmpwalk_group($device, 'aiAccessPointEntry', $ai_mib);
     $instant_index = 2;
 } elseif ($device['os'] == 'timos') {
-    $entity_array = array();
+    $entity_array = [];
     echo 'tmnxHwObjs';
     $entity_array = snmpwalk_cache_multi_oid($device, 'tmnxHwObjs', $entity_array, 'TIMETRA-CHASSIS-MIB', 'nokia');
 } else {
-    $entity_array = array();
+    $entity_array = [];
     echo ' entPhysicalEntry';
     $entity_array = snmpwalk_cache_oid($device, 'entPhysicalEntry', $entity_array, 'ENTITY-MIB:CISCO-ENTITY-VENDORTYPE-OID-MIB');
 
-    if (!empty($entity_array)) {
+    if (! empty($entity_array)) {
         echo ' entAliasMappingIdentifier';
         $entity_array = snmpwalk_cache_twopart_oid($device, 'entAliasMappingIdentifier', $entity_array, 'ENTITY-MIB:IF-MIB');
     }
@@ -103,7 +103,7 @@ if ($device['os'] == 'saf-cfm') {
         }
 
         foreach ([1 => 'm1Description', 2 => 'm2Description', 3 => 'm3Description', 4 => 'm4Description'] as $index => $item) {
-            if (!Str::contains($device_array[$item], 'N/A')) {
+            if (! Str::contains($device_array[$item], 'N/A')) {
                 $entity_array[] = [
                     'entPhysicalDescr' => $device_array[$item],
                     'entPhysicalVendorType' => 'module',
@@ -123,34 +123,34 @@ foreach ($entity_array as $entPhysicalIndex => $entry) {
     if ($device['os'] == 'junos') {
         // Juniper's MIB doesn't have the same objects as the Entity MIB, so some values
         // are made up here.
-        $entPhysicalDescr        = $entry['jnxContentsDescr'];
-        $entPhysicalContainedIn  = $entry['jnxContainersWithin'];
-        $entPhysicalClass        = $entry['jnxBoxClass'];
-        $entPhysicalName         = $entry['jnxOperatingDescr'];
-        $entPhysicalSerialNum    = $entry['jnxContentsSerialNo'];
-        $entPhysicalModelName    = $entry['jnxContentsPartNo'];
-        $entPhysicalMfgName      = 'Juniper';
-        $entPhysicalVendorType   = 'Juniper';
+        $entPhysicalDescr = $entry['jnxContentsDescr'];
+        $entPhysicalContainedIn = $entry['jnxContainersWithin'];
+        $entPhysicalClass = $entry['jnxBoxClass'];
+        $entPhysicalName = $entry['jnxOperatingDescr'];
+        $entPhysicalSerialNum = $entry['jnxContentsSerialNo'];
+        $entPhysicalModelName = $entry['jnxContentsPartNo'];
+        $entPhysicalMfgName = 'Juniper';
+        $entPhysicalVendorType = 'Juniper';
         $entPhysicalParentRelPos = -1;
-        $entPhysicalHardwareRev  = $entry['jnxContentsRevision'];
-        $entPhysicalFirmwareRev  = $entry['entPhysicalFirmwareRev'];
-        $entPhysicalSoftwareRev  = $entry['entPhysicalSoftwareRev'];
-        $entPhysicalIsFRU        = $entry['jnxFruType'];
-        $entPhysicalAlias        = $entry['entPhysicalAlias'];
-        $entPhysicalAssetID      = $entry['entPhysicalAssetID'];
+        $entPhysicalHardwareRev = $entry['jnxContentsRevision'];
+        $entPhysicalFirmwareRev = $entry['entPhysicalFirmwareRev'];
+        $entPhysicalSoftwareRev = $entry['entPhysicalSoftwareRev'];
+        $entPhysicalIsFRU = $entry['jnxFruType'];
+        $entPhysicalAlias = $entry['entPhysicalAlias'];
+        $entPhysicalAssetID = $entry['entPhysicalAssetID'];
         // fix for issue 1865, $entPhysicalIndex, as it contains a quad dotted number on newer Junipers
         // using str_replace to remove all dots should fix this even if it changes in future
         $entPhysicalIndex = str_replace('.', '', $entPhysicalIndex);
     } elseif ($device['os'] == 'aruba-instant') {
-        $entPhysicalDescr        = $entry['aiAPMACAddress'];
-        $entPhysicalContainedIn  = 1;
-        $entPhysicalSerialNum    = $entry['aiAPSerialNum'];
-        $entPhysicalModelName    = $entry['aiAPModel'];
-        $entPhysicalMfgName      = 'Aruba';
-        $entPhysicalVendorType   = 'Aruba';
+        $entPhysicalDescr = $entry['aiAPMACAddress'];
+        $entPhysicalContainedIn = 1;
+        $entPhysicalSerialNum = $entry['aiAPSerialNum'];
+        $entPhysicalModelName = $entry['aiAPModel'];
+        $entPhysicalMfgName = 'Aruba';
+        $entPhysicalVendorType = 'Aruba';
         $entPhysicalParentRelPos = -1;
-        $entPhysicalSoftwareRev  = $device['version'];
-        $entPhysicalIndex        = $instant_index;
+        $entPhysicalSoftwareRev = $device['version'];
+        $entPhysicalIndex = $instant_index;
 
         if ($entry['aiAPIPAddress'] == $ai_ig_data['aiMasterIPAddress.0']) {
             $entPhysicalName = sprintf('%s %s Cluster Master', $entry['aiAPName'], $entry['aiAPIPAddress']);
@@ -160,39 +160,39 @@ foreach ($entity_array as $entPhysicalIndex => $entry) {
 
         $instant_index += 1;
     } elseif ($device['os'] == 'timos') {
-        $entPhysicalDescr        = $entry['tmnxCardTypeDescription'];
-        $entPhysicalContainedIn  = $entry['tmnxHwContainedIn'];
-        $entPhysicalClass        = $entry['tmnxHwClass'];
-        $entPhysicalName         = $entry['tmnxCardTypeName'];
-        $entPhysicalSerialNum    = $entry['tmnxHwSerialNumber'];
-        $entPhysicalModelName    = $entry['tmnxHwMfgBoardNumber'];
-        $entPhysicalMfgName      = $entry['tmnxHwMfgBoardNumber'];
-        $entPhysicalVendorType   = $entry['tmnxCardTypeName'];
+        $entPhysicalDescr = $entry['tmnxCardTypeDescription'];
+        $entPhysicalContainedIn = $entry['tmnxHwContainedIn'];
+        $entPhysicalClass = $entry['tmnxHwClass'];
+        $entPhysicalName = $entry['tmnxCardTypeName'];
+        $entPhysicalSerialNum = $entry['tmnxHwSerialNumber'];
+        $entPhysicalModelName = $entry['tmnxHwMfgBoardNumber'];
+        $entPhysicalMfgName = $entry['tmnxHwMfgBoardNumber'];
+        $entPhysicalVendorType = $entry['tmnxCardTypeName'];
         $entPhysicalParentRelPos = $entry['tmnxHwParentRelPos'];
-        $entPhysicalHardwareRev  = '1.0';
-        $entPhysicalFirmwareRev  = $entry['tmnxHwBootCodeVersion'];
-        $entPhysicalSoftwareRev  = $entry['tmnxHwBootCodeVersion'];
-        $entPhysicalIsFRU        = $entry['tmnxHwIsFRU'];
-        $entPhysicalAlias        = $entry['tmnxHwAlias'];
-        $entPhysicalAssetID      = $entry['tmnxHwAssetID'];
+        $entPhysicalHardwareRev = '1.0';
+        $entPhysicalFirmwareRev = $entry['tmnxHwBootCodeVersion'];
+        $entPhysicalSoftwareRev = $entry['tmnxHwBootCodeVersion'];
+        $entPhysicalIsFRU = $entry['tmnxHwIsFRU'];
+        $entPhysicalAlias = $entry['tmnxHwAlias'];
+        $entPhysicalAssetID = $entry['tmnxHwAssetID'];
         $entPhysicalIndex = str_replace('.', '', $entPhysicalIndex);
     } elseif ($device['os'] == 'vrp') {
         //Add some details collected in the VRP Entity Mib
-        $entPhysicalDescr        = $entry['hwEntityBomEnDesc'];
-        $entPhysicalContainedIn  = $entry['entPhysicalContainedIn'];
-        $entPhysicalClass        = $entry['entPhysicalClass'];
-        $entPhysicalName         = $entry['entPhysicalName'];
-        $entPhysicalSerialNum    = $entry['entPhysicalSerialNum'];
-        $entPhysicalModelName    = $entry['hwEntityBoardType'];
-        $entPhysicalMfgName      = $entry['entPhysicalMfgName'];
-        $entPhysicalVendorType   = $entry['entPhysicalVendorType'];
+        $entPhysicalDescr = $entry['hwEntityBomEnDesc'];
+        $entPhysicalContainedIn = $entry['entPhysicalContainedIn'];
+        $entPhysicalClass = $entry['entPhysicalClass'];
+        $entPhysicalName = $entry['entPhysicalName'];
+        $entPhysicalSerialNum = $entry['entPhysicalSerialNum'];
+        $entPhysicalModelName = $entry['hwEntityBoardType'];
+        $entPhysicalMfgName = $entry['entPhysicalMfgName'];
+        $entPhysicalVendorType = $entry['entPhysicalVendorType'];
         $entPhysicalParentRelPos = $entry['entPhysicalParentRelPos'];
-        $entPhysicalHardwareRev  = $entry['entPhysicalHardwareRev'];
-        $entPhysicalFirmwareRev  = $entry['entPhysicalFirmwareRev'];
-        $entPhysicalSoftwareRev  = $entry['entPhysicalSoftwareRev'];
-        $entPhysicalIsFRU        = $entry['entPhysicalIsFRU'];
-        $entPhysicalAlias        = $entry['entPhysicalAlias'];
-        $entPhysicalAssetID      = $entry['entPhysicalAssetID'];
+        $entPhysicalHardwareRev = $entry['entPhysicalHardwareRev'];
+        $entPhysicalFirmwareRev = $entry['entPhysicalFirmwareRev'];
+        $entPhysicalSoftwareRev = $entry['entPhysicalSoftwareRev'];
+        $entPhysicalIsFRU = $entry['entPhysicalIsFRU'];
+        $entPhysicalAlias = $entry['entPhysicalAlias'];
+        $entPhysicalAssetID = $entry['entPhysicalAssetID'];
 
         //VRP devices seems to use LogicalEntity '1' instead of '0' like the default code checks.
         //Standard code is still run after anyway.
@@ -200,36 +200,36 @@ foreach ($entity_array as $entPhysicalIndex => $entry) {
             $ifIndex = preg_replace('/ifIndex\.(\d+).*/', '$1', $entry['1']['entAliasMappingIdentifier']);
         }
     } else {
-        $entPhysicalDescr        = array_key_exists('entPhysicalDescr', $entry)        ? $entry['entPhysicalDescr']        : '';
-        $entPhysicalContainedIn  = array_key_exists('entPhysicalContainedIn', $entry)  ? $entry['entPhysicalContainedIn']  : '';
-        $entPhysicalClass        = array_key_exists('entPhysicalClass', $entry)        ? $entry['entPhysicalClass']        : '';
-        $entPhysicalName         = array_key_exists('entPhysicalName', $entry)         ? $entry['entPhysicalName']         : '';
-        $entPhysicalSerialNum    = array_key_exists('entPhysicalSerialNum', $entry)    ? $entry['entPhysicalSerialNum']    : '';
-        $entPhysicalModelName    = array_key_exists('entPhysicalModelName', $entry)    ? $entry['entPhysicalModelName']    : '';
-        $entPhysicalMfgName      = array_key_exists('entPhysicalMfgName', $entry)      ? $entry['entPhysicalMfgName']      : '';
-        $entPhysicalVendorType   = array_key_exists('entPhysicalVendorType', $entry)   ? $entry['entPhysicalVendorType']   : '';
+        $entPhysicalDescr = array_key_exists('entPhysicalDescr', $entry) ? $entry['entPhysicalDescr'] : '';
+        $entPhysicalContainedIn = array_key_exists('entPhysicalContainedIn', $entry) ? $entry['entPhysicalContainedIn'] : '';
+        $entPhysicalClass = array_key_exists('entPhysicalClass', $entry) ? $entry['entPhysicalClass'] : '';
+        $entPhysicalName = array_key_exists('entPhysicalName', $entry) ? $entry['entPhysicalName'] : '';
+        $entPhysicalSerialNum = array_key_exists('entPhysicalSerialNum', $entry) ? $entry['entPhysicalSerialNum'] : '';
+        $entPhysicalModelName = array_key_exists('entPhysicalModelName', $entry) ? $entry['entPhysicalModelName'] : '';
+        $entPhysicalMfgName = array_key_exists('entPhysicalMfgName', $entry) ? $entry['entPhysicalMfgName'] : '';
+        $entPhysicalVendorType = array_key_exists('entPhysicalVendorType', $entry) ? $entry['entPhysicalVendorType'] : '';
         $entPhysicalParentRelPos = array_key_exists('entPhysicalParentRelPos', $entry) ? $entry['entPhysicalParentRelPos'] : '';
-        $entPhysicalHardwareRev  = array_key_exists('entPhysicalHardwareRev', $entry)  ? $entry['entPhysicalHardwareRev']  : '';
-        $entPhysicalFirmwareRev  = array_key_exists('entPhysicalFirmwareRev', $entry)  ? $entry['entPhysicalFirmwareRev']  : '';
-        $entPhysicalSoftwareRev  = array_key_exists('entPhysicalSoftwareRev', $entry)  ? $entry['entPhysicalSoftwareRev']  : '';
-        $entPhysicalIsFRU        = array_key_exists('entPhysicalIsFRU', $entry)        ? $entry['entPhysicalIsFRU']        : '';
-        $entPhysicalAlias        = array_key_exists('entPhysicalAlias', $entry)        ? $entry['entPhysicalAlias']        : '';
-        $entPhysicalAssetID      = array_key_exists('entPhysicalAssetID', $entry)      ? $entry['entPhysicalAssetID']      : '';
+        $entPhysicalHardwareRev = array_key_exists('entPhysicalHardwareRev', $entry) ? $entry['entPhysicalHardwareRev'] : '';
+        $entPhysicalFirmwareRev = array_key_exists('entPhysicalFirmwareRev', $entry) ? $entry['entPhysicalFirmwareRev'] : '';
+        $entPhysicalSoftwareRev = array_key_exists('entPhysicalSoftwareRev', $entry) ? $entry['entPhysicalSoftwareRev'] : '';
+        $entPhysicalIsFRU = array_key_exists('entPhysicalIsFRU', $entry) ? $entry['entPhysicalIsFRU'] : '';
+        $entPhysicalAlias = array_key_exists('entPhysicalAlias', $entry) ? $entry['entPhysicalAlias'] : '';
+        $entPhysicalAssetID = array_key_exists('entPhysicalAssetID', $entry) ? $entry['entPhysicalAssetID'] : '';
     }//end if
 
     if (isset($entity_array[$entPhysicalIndex]['0']['entAliasMappingIdentifier'])) {
         $ifIndex = $entity_array[$entPhysicalIndex]['0']['entAliasMappingIdentifier'];
-        if (!strpos($ifIndex, 'fIndex') || $ifIndex == '') {
+        if (! strpos($ifIndex, 'fIndex') || $ifIndex == '') {
             unset($ifIndex);
         } else {
             $ifIndex_array = explode('.', $ifIndex);
-            $ifIndex       = $ifIndex_array[1];
+            $ifIndex = $ifIndex_array[1];
             unset($ifIndex_array);
         }
     }
 
     // List of real names for cisco entities
-    $entPhysicalVendorTypes = array(
+    $entPhysicalVendorTypes = [
         'cevC7xxxIo1feTxIsl'   => 'C7200-IO-FE-MII',
         'cevChassis7140Dualfe' => 'C7140-2FE',
         'cevChassis7204'       => 'C7204',
@@ -248,9 +248,9 @@ foreach ($entity_array as $entPhysicalIndex => $entry) {
         'cevPaA8tX21'          => 'PA-8T-X21',
         'cevMGBIC1000BaseLX'   => '1000BaseLX GBIC',
         'cevPort10GigBaseLR'   => '10GigBaseLR',
-    );
+    ];
 
-    if ($entPhysicalVendorTypes[$entPhysicalVendorType] && !$entPhysicalModelName) {
+    if ($entPhysicalVendorTypes[$entPhysicalVendorType] && ! $entPhysicalModelName) {
         $entPhysicalModelName = $entPhysicalVendorTypes[$entPhysicalVendorType];
     }
 
