@@ -1,6 +1,6 @@
 <?php
 
-$sql = "SELECT * FROM `ports_stack` WHERE `device_id` = '".$device['device_id']."'";
+$sql = "SELECT * FROM `ports_stack` WHERE `device_id` = '" . $device['device_id'] . "'";
 
 $stack_db_array = [];
 foreach (dbFetchRows($sql) as $entry) {
@@ -11,7 +11,7 @@ unset(
     $entry
 );
 
-$stack_poll_array = snmpwalk_cache_twopart_oid($device, 'ifStackStatus', array(), 'IF-MIB');
+$stack_poll_array = snmpwalk_cache_twopart_oid($device, 'ifStackStatus', [], 'IF-MIB');
 
 foreach ($stack_poll_array as $port_id_high => $entry_high) {
     foreach ($entry_high as $port_id_low => $entry_low) {
@@ -20,13 +20,13 @@ foreach ($stack_poll_array as $port_id_high => $entry_high) {
             if ($stack_db_array[$port_id_high][$port_id_low]['ifStackStatus'] == $ifStackStatus) {
                 echo '.';
             } else {
-                dbUpdate(array('ifStackStatus' => $ifStackStatus), 'ports_stack', 'device_id=? AND port_id_high=? AND `port_id_low`=?', array($device['device_id'], $port_id_high, $port_id_low));
+                dbUpdate(['ifStackStatus' => $ifStackStatus], 'ports_stack', 'device_id=? AND port_id_high=? AND `port_id_low`=?', [$device['device_id'], $port_id_high, $port_id_low]);
                 echo 'U';
             }
 
             unset($stack_db_array[$port_id_high][$port_id_low]);
         } else {
-            dbInsert(array('device_id' => $device['device_id'], 'port_id_high' => $port_id_high, 'port_id_low' => $port_id_low, 'ifStackStatus' => $ifStackStatus), 'ports_stack');
+            dbInsert(['device_id' => $device['device_id'], 'port_id_high' => $port_id_high, 'port_id_low' => $port_id_low, 'ifStackStatus' => $ifStackStatus], 'ports_stack');
             echo '+';
         }
     }//end foreach
@@ -39,8 +39,8 @@ unset($stack_poll_array);
 
 foreach ($stack_db_array as $port_id_high => $array) {
     foreach ($array as $port_id_low => $blah) {
-        echo $device['device_id'].' '.$port_id_low.' '.$port_id_high."\n";
-        dbDelete('ports_stack', '`device_id` =  ? AND port_id_high = ? AND port_id_low = ?', array($device['device_id'], $port_id_high, $port_id_low));
+        echo $device['device_id'] . ' ' . $port_id_low . ' ' . $port_id_high . "\n";
+        dbDelete('ports_stack', '`device_id` =  ? AND port_id_high = ? AND port_id_low = ?', [$device['device_id'], $port_id_high, $port_id_low]);
         echo '-';
     }
 }
