@@ -1,36 +1,37 @@
 <?php
+
 // PDU - Phase
 $oids = snmp_walk($device, 'rPDUStatusPhaseIndex', '-OsqnU', 'PowerNet-MIB');
 if (empty($oids)) {
     $oids = snmp_walk($device, 'rPDULoadPhaseConfigIndex', '-OsqnU', 'PowerNet-MIB');
 }
 if ($oids) {
-    d_echo($oids."\n");
+    d_echo($oids . "\n");
     $oids = trim($oids);
     if ($oids) {
         echo 'APC PowerNet-MIB Phase ';
     }
-    $type      = 'apc';
+    $type = 'apc';
     $precision = '10';
     foreach (explode("\n", $oids) as $data) {
         $data = trim($data);
         if ($data) {
-            list($oid,$kind) = explode(' ', $data);
-            $split_oid       = explode('.', $oid);
-            $index           = $split_oid[(count($split_oid) - 1)];
-            $current_oid = '.1.3.6.1.4.1.318.1.1.12.2.3.1.1.2.'.$index;
+            [$oid,$kind] = explode(' ', $data);
+            $split_oid = explode('.', $oid);
+            $index = $split_oid[(count($split_oid) - 1)];
+            $current_oid = '.1.3.6.1.4.1.318.1.1.12.2.3.1.1.2.' . $index;
             // rPDULoadStatusLoad
-            $phase_oid = '.1.3.6.1.4.1.318.1.1.12.2.3.1.1.4.'.$index;
+            $phase_oid = '.1.3.6.1.4.1.318.1.1.12.2.3.1.1.4.' . $index;
             // rPDULoadStatusPhaseNumber
-            $limit_oid = '.1.3.6.1.4.1.318.1.1.12.2.2.1.1.4.'.$index;
+            $limit_oid = '.1.3.6.1.4.1.318.1.1.12.2.2.1.1.4.' . $index;
             // rPDULoadPhaseConfigOverloadThreshold
-            $lowlimit_oid = '.1.3.6.1.4.1.318.1.1.12.2.2.1.1.2.'.$index;
+            $lowlimit_oid = '.1.3.6.1.4.1.318.1.1.12.2.2.1.1.2.' . $index;
             // rPDULoadPhaseConfigLowLoadThreshold
-            $warnlimit_oid = '.1.3.6.1.4.1.318.1.1.12.2.2.1.1.3.'.$index;
+            $warnlimit_oid = '.1.3.6.1.4.1.318.1.1.12.2.2.1.1.3.' . $index;
             // rPDULoadPhaseConfigNearOverloadThreshold
-            $phase   = snmp_get($device, $phase_oid, '-Oqv', '');
+            $phase = snmp_get($device, $phase_oid, '-Oqv', '');
             $current = (snmp_get($device, $current_oid, '-Oqv', '') / $precision);
-            $limit   = snmp_get($device, $limit_oid, '-Oqv', '');
+            $limit = snmp_get($device, $limit_oid, '-Oqv', '');
             // No / $precision here! Nice, APC!
             $lowlimit = snmp_get($device, $lowlimit_oid, '-Oqv', '');
             // No / $precision here! Nice, APC!
@@ -54,9 +55,9 @@ if ($bank_count > 0) {
 // should work with firmware v2 and v3
 if ($oids) {
     echo 'APC PowerNet-MIB Banks ';
-    d_echo($oids."\n");
-    $oids      = trim($oids);
-    $type      = 'apc';
+    d_echo($oids . "\n");
+    $oids = trim($oids);
+    $type = 'apc';
     $precision = '10';
     // version 2 does some stuff differently- total power is first oid in index instead of the last.
     // will look something like "AOS v2.6.4 / App v2.6.5"
@@ -67,11 +68,11 @@ if ($oids) {
     foreach (explode("\n", $oids) as $data) {
         $data = trim($data);
         if ($data) {
-            list($oid,$kind) = explode(' ', $data);
-            $split_oid       = explode('.', $oid);
+            [$oid,$kind] = explode(' ', $data);
+            $split_oid = explode('.', $oid);
             $index = $split_oid[(count($split_oid) - 1)];
             $banknum = ($index - 1);
-            $descr   = 'Bank '.$banknum;
+            $descr = 'Bank ' . $banknum;
             if ($baseversion == '3') {
                 if ($index == '1') {
                     $descr = 'Bank Total';
@@ -82,20 +83,20 @@ if ($oids) {
                     $descr = 'Bank Total';
                 }
             }
-            $current_oid = '.1.3.6.1.4.1.318.1.1.12.2.3.1.1.2.'.$index;
+            $current_oid = '.1.3.6.1.4.1.318.1.1.12.2.3.1.1.2.' . $index;
             // rPDULoadStatusLoad
-            $bank_oid = '.1.3.6.1.4.1.318.1.1.12.2.3.1.1.5.'.$index;
+            $bank_oid = '.1.3.6.1.4.1.318.1.1.12.2.3.1.1.5.' . $index;
             // rPDULoadStatusBankNumber
-            $limit_oid = '.1.3.6.1.4.1.318.1.1.12.2.4.1.1.4.'.$index;
+            $limit_oid = '.1.3.6.1.4.1.318.1.1.12.2.4.1.1.4.' . $index;
             // rPDULoadBankConfigOverloadThreshold
-            $lowlimit_oid = '.1.3.6.1.4.1.318.1.1.12.2.4.1.1.2.'.$index;
+            $lowlimit_oid = '.1.3.6.1.4.1.318.1.1.12.2.4.1.1.2.' . $index;
             // rPDULoadBankConfigLowLoadThreshold
-            $warnlimit_oid = '.1.3.6.1.4.1.318.1.1.12.2.4.1.1.3.'.$index;
+            $warnlimit_oid = '.1.3.6.1.4.1.318.1.1.12.2.4.1.1.3.' . $index;
             // rPDULoadBankConfigNearOverloadThreshold
-            $bank      = snmp_get($device, $bank_oid, '-Oqv', '');
-            $current   = (snmp_get($device, $current_oid, '-Oqv', '') / $precision);
-            $limit     = snmp_get($device, $limit_oid, '-Oqv', '');
-            $lowlimit  = snmp_get($device, $lowlimit_oid, '-Oqv', '');
+            $bank = snmp_get($device, $bank_oid, '-Oqv', '');
+            $current = (snmp_get($device, $current_oid, '-Oqv', '') / $precision);
+            $limit = snmp_get($device, $limit_oid, '-Oqv', '');
+            $lowlimit = snmp_get($device, $lowlimit_oid, '-Oqv', '');
             $warnlimit = snmp_get($device, $warnlimit_oid, '-Oqv', '');
             if ($limit != -1 && $lowlimit != -1 && $warnlimit != -1) {
                 discover_sensor($valid['sensor'], 'current', $device, $current_oid, $index, $type, $descr, '10', '1', $lowlimit, null, $warnlimit, $limit, $current);
@@ -109,34 +110,34 @@ unset($oids);
 $oids = snmp_walk($device, '.1.3.6.1.4.1.318.1.1.26.9.4.3.1.1', '-t 30 -OsqnU', 'PowerNet-MIB');
 if ($oids) {
     echo 'APC PowerNet-MIB Outlets ';
-    d_echo($oids."\n");
-    $oids      = trim($oids);
-    $type      = 'apc';
+    d_echo($oids . "\n");
+    $oids = trim($oids);
+    $type = 'apc';
     $precision = '10';
     foreach (explode("\n", $oids) as $data) {
         $data = trim($data);
         if ($data) {
-            list($oid,$kind) = explode(' ', $data);
-            $split_oid       = explode('.', $oid);
+            [$oid,$kind] = explode(' ', $data);
+            $split_oid = explode('.', $oid);
             $index = $split_oid[(count($split_oid) - 1)];
             $voltage_oid = '.1.3.6.1.4.1.318.1.1.26.6.3.1.6';
             // rPDU2PhaseStatusVoltage
-            $current_oid = '.1.3.6.1.4.1.318.1.1.26.9.4.3.1.6.'.$index;
+            $current_oid = '.1.3.6.1.4.1.318.1.1.26.9.4.3.1.6.' . $index;
             // rPDU2OutletMeteredStatusCurrent
-            $limit_oid = '.1.3.6.1.4.1.318.1.1.26.9.4.1.1.7.'.$index;
+            $limit_oid = '.1.3.6.1.4.1.318.1.1.26.9.4.1.1.7.' . $index;
             // rPDU2OutletMeteredConfigOverloadCurrentThreshold
-            $lowlimit_oid = '.1.3.6.1.4.1.318.1.1.26.9.4.1.1.7.'.$index;
+            $lowlimit_oid = '.1.3.6.1.4.1.318.1.1.26.9.4.1.1.7.' . $index;
             // rPDU2OutletMeteredConfigLowLoadCurrentThreshold
-            $warnlimit_oid = '.1.3.6.1.4.1.318.1.1.26.9.4.1.1.6.'.$index;
+            $warnlimit_oid = '.1.3.6.1.4.1.318.1.1.26.9.4.1.1.6.' . $index;
             // rPDU2OutletMeteredConfigNearOverloadCurrentThreshold
-            $name_oid = '.1.3.6.1.4.1.318.1.1.26.9.4.3.1.3.'.$index;
+            $name_oid = '.1.3.6.1.4.1.318.1.1.26.9.4.3.1.3.' . $index;
             // rPDU2OutletMeteredStatusName
             $voltage = snmp_get($device, $voltage_oid, '-Oqv', '');
-            $current   = (snmp_get($device, $current_oid, '-Oqv', '') / $precision);
-            $limit     = (snmp_get($device, $limit_oid, '-Oqv', '') / $voltage);
-            $lowlimit  = (snmp_get($device, $lowlimit_oid, '-Oqv', '') / $voltage);
+            $current = (snmp_get($device, $current_oid, '-Oqv', '') / $precision);
+            $limit = (snmp_get($device, $limit_oid, '-Oqv', '') / $voltage);
+            $lowlimit = (snmp_get($device, $lowlimit_oid, '-Oqv', '') / $voltage);
             $warnlimit = (snmp_get($device, $warnlimit_oid, '-Oqv', '') / $voltage);
-            $descr     = 'Outlet '.$index.' - '.snmp_get($device, $name_oid, '-Oqv', '');
+            $descr = 'Outlet ' . $index . ' - ' . snmp_get($device, $name_oid, '-Oqv', '');
             discover_sensor($valid['sensor'], 'current', $device, $current_oid, $index, $type, $descr, '10', '1', $lowlimit, null, $warnlimit, $limit, $current);
         }
     }
@@ -146,7 +147,7 @@ unset($oids);
 $oids = snmp_walk($device, 'atsConfigPhaseTableIndex', '-OsqnU', 'PowerNet-MIB');
 if ($oids) {
     $type = 'apc';
-    d_echo($oids."\n");
+    d_echo($oids . "\n");
     $oids = trim($oids);
     if ($oids) {
         echo 'APC PowerNet-MIB ATS ';
@@ -161,7 +162,7 @@ if ($oids) {
     // atsConfigPhaseNearOverLoadThreshold
     $index = 1;
     $current = (snmp_get($device, $current_oid, '-Oqv', '') / $precision);
-    $limit   = snmp_get($device, $limit_oid, '-Oqv', '');
+    $limit = snmp_get($device, $limit_oid, '-Oqv', '');
     // No / $precision here! Nice, APC!
     $lowlimit = snmp_get($device, $lowlimit_oid, '-Oqv', '');
     // No / $precision here! Nice, APC!
@@ -174,7 +175,7 @@ unset($oids);
 
 // UPS
 
-    $phasecount =  $phasecount = $pre_cache['apcups_phase_count'];
+    $phasecount = $phasecount = $pre_cache['apcups_phase_count'];
 if ($phasecount > 1) {
     $oids = snmpwalk_cache_oid($device, 'upsPhaseOutputCurrent', $oids, 'PowerNet-MIB');
     $in_oids = snmpwalk_cache_oid($device, 'upsPhaseInputCurrent', $in_oids, 'PowerNet-MIB');
