@@ -10,13 +10,13 @@
  * the source code distribution for details.
  */
 
-echo "CiscoSB";
+echo 'CiscoSB';
 
 $multiplier = 1;
-$divisor    = 1000000;
+$divisor = 1000000;
 foreach ($pre_cache['ciscosb_rlPhyTestGetResult'] as $index => $ciscosb_data) {
     foreach ($ciscosb_data as $key => $value) {
-        $oid = '.1.3.6.1.4.1.9.6.1.101.90.1.2.1.3.'.$index.'.7';
+        $oid = '.1.3.6.1.4.1.9.6.1.101.90.1.2.1.3.' . $index . '.7';
         $sensor_type = 'rlPhyTestTableTxBias';
         $port_descr = get_port_by_index_cache($device['device_id'], str_replace('1.', '', $index));
         $descr = $port_descr['ifDescr'] . ' Bias Current';
