@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2019 Paul Parsons
  * @author     Paul Parsons <paul@cppmonkey.net>
@@ -33,7 +32,7 @@ if (is_numeric($rectifiersOutputCurrent) && is_numeric($rectifiersOutputCurrentM
 }
 $loadCurrent = snmp_get($device, 'es1dc1DataLoadLoadCurrent.0', '-Ovqe', 'SITE-MONITORING-MIB');
 $curOID = '.1.3.6.1.4.1.26854.3.2.1.20.1.20.1.13.3.52.0';
-$index = "es1dc1DataLoadLoadCurrent";
+$index = 'es1dc1DataLoadLoadCurrent';
 if (is_numeric($loadCurrent)) {
     $sensorType = 'compas';
     $descr = 'Load Current';
