@@ -12,22 +12,22 @@
 
 echo 'Comware ';
 
-$multiplier    = 1;
-$divisor       = 100000;
+$multiplier = 1;
+$divisor = 100000;
 $divisor_alarm = 1000000;
 foreach ($pre_cache['comware_oids'] as $index => $entry) {
     if (is_numeric($entry['hh3cTransceiverBiasCurrent']) && $entry['hh3cTransceiverBiasCurrent'] != 2147483647 && isset($entry['hh3cTransceiverDiagnostic'])) {
-        $oid                       = '.1.3.6.1.4.1.25506.2.70.1.1.1.17.' . $index;
-        $dbquery                   = dbFetchRows("SELECT `ifDescr` FROM `ports` WHERE `ifIndex`= ? AND `device_id` = ? AND `ifAdminStatus` = 'up'", [
+        $oid = '.1.3.6.1.4.1.25506.2.70.1.1.1.17.' . $index;
+        $dbquery = dbFetchRows("SELECT `ifDescr` FROM `ports` WHERE `ifIndex`= ? AND `device_id` = ? AND `ifAdminStatus` = 'up'", [
             $index,
-            $device['device_id']
+            $device['device_id'],
         ]);
-        $limit_low                 = $entry['hh3cTransceiverBiasLoAlarm'] / $divisor_alarm;
-        $warn_limit_low            = $entry['hh3cTransceiverBiasLoWarn'] / $divisor_alarm;
-        $limit                     = $entry['hh3cTransceiverBiasHiAlarm'] / $divisor_alarm;
-        $warn_limit                = $entry['hh3cTransceiverBiasHiWarn'] / $divisor_alarm;
-        $current                   = $entry['hh3cTransceiverBiasCurrent'] / $divisor;
-        $entPhysicalIndex          = $index;
+        $limit_low = $entry['hh3cTransceiverBiasLoAlarm'] / $divisor_alarm;
+        $warn_limit_low = $entry['hh3cTransceiverBiasLoWarn'] / $divisor_alarm;
+        $limit = $entry['hh3cTransceiverBiasHiAlarm'] / $divisor_alarm;
+        $warn_limit = $entry['hh3cTransceiverBiasHiWarn'] / $divisor_alarm;
+        $current = $entry['hh3cTransceiverBiasCurrent'] / $divisor;
+        $entPhysicalIndex = $index;
         $entPhysicalIndex_measured = 'ports';
         foreach ($dbquery as $dbindex => $dbresult) {
             $descr = makeshortif($dbresult['ifDescr']) . ' Bias Current';
