@@ -17,20 +17,18 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2016 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
  */
-
 echo 'Netonix: ';
 // NETONIX-SWITCH-MIB::fanTable .1.3.6.1.4.1.46242.2
 $oids = snmpwalk_cache_multi_oid($device, 'fanTable', [], 'NETONIX-SWITCH-MIB', 'netonix');
 if (is_array($oids)) {
     foreach ($oids as $index => $entry) {
         if (is_numeric($entry['fanSpeed']) && is_numeric($index)) {
-            $descr   = "Fan ".$index;
-            $oid     = '.1.3.6.1.4.1.46242.2.1.2.'.$index;
+            $descr = 'Fan ' . $index;
+            $oid = '.1.3.6.1.4.1.46242.2.1.2.' . $index;
             $current = $entry['fanSpeed'];
             discover_sensor($valid['sensor'], 'fanspeed', $device, $oid, $index, $device['os'], $descr, '1', '1', 0, 0, 8000, 9000, $current);
         }
