@@ -17,12 +17,10 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2017 Neil Lathwood
  * @author     Neil Lathwood <gh+n@laf.io>
  */
-
 $descr = 'Processor Humidity';
 $divisor = 1;
 $multiplier = '1';
@@ -30,26 +28,26 @@ d_echo('Humidity for Raritan PDU2');
 foreach ($pre_cache['raritan_extSensorConfig'] as $index => $data) {
     // sensor type 10 for temperature
     if ($data['externalSensorType'] == 'humidity') {
-        $descr           = $data['externalSensorName'];
-        $oid             = ".1.3.6.1.4.1.13742.6.5.5.3.1.4.$index";
-        $low_limit       = $data['externalSensorLowerCriticalThreshold'];
-        $low_warn_limit  = $data['externalSensorLowerWarningThreshold'];
-        $high_limit      = $data['externalSensorUpperCriticalThreshold'];
+        $descr = $data['externalSensorName'];
+        $oid = ".1.3.6.1.4.1.13742.6.5.5.3.1.4.$index";
+        $low_limit = $data['externalSensorLowerCriticalThreshold'];
+        $low_warn_limit = $data['externalSensorLowerWarningThreshold'];
+        $high_limit = $data['externalSensorUpperCriticalThreshold'];
         $high_warn_limit = $data['externalSensorUpperWarningThreshold'];
 
         $measure_data = $pre_cache['raritan_extSensorMeasure'][$index];
-        $current      = ($measure_data['measurementsExternalSensorValue'] / $divisor);
+        $current = ($measure_data['measurementsExternalSensorValue'] / $divisor);
         $sensor_available = $measure_data['measurementsExternalSensorIsAvailable'];
         $user_func = null;
-        if (is_numeric($current) && $current >= 0 && $sensor_available === "true") {
-            discover_sensor($valid['sensor'], 'humidity', $device, $oid, 'measurementsExternalSensorValue.'.$index, 'raritan', $descr, $divisor, $multiplier, $low_limit, $low_warn_limit, $high_warn_limit, $high_limit, $current, 'snmp', null, null, $user_func);
+        if (is_numeric($current) && $current >= 0 && $sensor_available === 'true') {
+            discover_sensor($valid['sensor'], 'humidity', $device, $oid, 'measurementsExternalSensorValue.' . $index, 'raritan', $descr, $divisor, $multiplier, $low_limit, $low_warn_limit, $high_warn_limit, $high_limit, $current, 'snmp', null, null, $user_func);
         }
     }
 }
 
 d_echo('Humidity for Raritan PDU');
-$oids = snmpwalk_cache_multi_oid($device, "externalSensorTable", array(), "PDU-MIB");
-$offset=0;
+$oids = snmpwalk_cache_multi_oid($device, 'externalSensorTable', [], 'PDU-MIB');
+$offset = 0;
 foreach ($oids as $index => $sensor) {
     if ($sensor['externalSensorType'] == 'humidity') {
         $oid = ".1.3.6.1.4.1.13742.4.3.3.1.41.$index";
