@@ -4,7 +4,6 @@
  *
  * LibreNMS Fan and Power Supply state Discovery module for Extreme/Avaya ERS
  */
-
 if ($device['os'] === 'boss') {
     $oid = snmpwalk_cache_oid($device, 's5ChasComTable', [], 'S5-CHASSIS-MIB');
     $cur_oid = '.1.3.6.1.4.1.45.1.6.3.3.1.1.10.';
@@ -34,12 +33,12 @@ if ($device['os'] === 'boss') {
                 $ers_sensors[$key] = $value;
             }
         }
-        
+
         $ps_num = 0;
         foreach ($ers_sensors as $index => $entry) {
             //Get unit number
-            $unit_array = explode(".", $index);
-            $unit = floor($unit_array[1]/10);
+            $unit_array = explode('.', $index);
+            $unit = floor($unit_array[1] / 10);
             //Set description with Power Supply number
             if ($unit_array[0] == 4) {
                 if ($unit != $temp_unit) {
@@ -52,7 +51,7 @@ if ($device['os'] === 'boss') {
                 $descr = "BOSS Unit $unit: $entry[s5ChasComDescr]";
             }
             //Discover Sensors
-            discover_sensor($valid['sensor'], 'state', $device, $cur_oid.$index, "s5ChasComOperState.$index", $state_name, $descr, 1, 1, null, null, null, null, $entry['s5ChasComOperState']);
+            discover_sensor($valid['sensor'], 'state', $device, $cur_oid . $index, "s5ChasComOperState.$index", $state_name, $descr, 1, 1, null, null, null, null, $entry['s5ChasComOperState']);
             //Create Sensor To State Index
             create_sensor_to_state_index($device, $state_name, "s5ChasComOperState.$index");
             $temp_unit = $unit;
