@@ -11,7 +11,7 @@
  */
 
 $role_data = snmpwalk_cache_oid($device, 'cswSwitchRole', [], 'CISCO-STACKWISE-MIB');
-$redundant_data = snmp_get($device, "cswRingRedundant.0", "-OQv", "CISCO-STACKWISE-MIB");
+$redundant_data = snmp_get($device, 'cswRingRedundant.0', '-OQv', 'CISCO-STACKWISE-MIB');
 
 $tables = [
     ['num_oid' => '.1.3.6.1.4.1.9.9.13.1.2.1.7.',       'oid' => 'ciscoEnvMonVoltageStatusTable',        'state_name' => 'ciscoEnvMonVoltageState',      'mib' => 'CISCO-ENVMON-MIB',                'descr' => 'ciscoEnvMonVoltageStatusDescr'],
@@ -63,7 +63,7 @@ foreach ($tables as $tablevalue) {
                 ['value' => 13, 'generic' => 1, 'graph' => 0, 'descr' => 'activePostconfig'],
                 ['value' => 14, 'generic' => 0, 'graph' => 0, 'descr' => 'active'],
                 ['value' => 15, 'generic' => 1, 'graph' => 0, 'descr' => 'activeExtraload'],
-                ['value' => 16, 'generic' => 1, 'graph' => 0, 'descr' => 'activeHandback']
+                ['value' => 16, 'generic' => 1, 'graph' => 0, 'descr' => 'activeHandback'],
             ];
         } elseif ($state_name == 'cRFCfgRedundancyOperMode') {
             $states = [
@@ -74,19 +74,19 @@ foreach ($tables as $tablevalue) {
                 ['value' => 5, 'generic' => 0, 'graph' => 0, 'descr' => 'dynamicLoadShareRedundant'],
                 ['value' => 6, 'generic' => 0, 'graph' => 0, 'descr' => 'coldStandbyRedundant'],
                 ['value' => 7, 'generic' => 0, 'graph' => 0, 'descr' => 'warmStandbyRedundant'],
-                ['value' => 8, 'generic' => 0, 'graph' => 0, 'descr' => 'hotStandbyRedundant']
+                ['value' => 8, 'generic' => 0, 'graph' => 0, 'descr' => 'hotStandbyRedundant'],
             ];
         } elseif ($state_name == 'cswRingRedundant') {
             $states = [
                 ['value' => 1, 'generic' => 0, 'graph' => 0, 'descr' => 'true'],
-                ['value' => 2, 'generic' => 2, 'graph' => 0, 'descr' => 'false']
+                ['value' => 2, 'generic' => 2, 'graph' => 0, 'descr' => 'false'],
             ];
         } elseif ($state_name == 'cswSwitchRole') {
             $states = [
                 ['value' => 1, 'generic' => 0, 'graph' => 0, 'descr' => 'master'],
                 ['value' => 2, 'generic' => 0, 'graph' => 0, 'descr' => 'member'],
                 ['value' => 3, 'generic' => 0, 'graph' => 0, 'descr' => 'notMember'],
-                ['value' => 4, 'generic' => 0, 'graph' => 0, 'descr' => 'standby']
+                ['value' => 4, 'generic' => 0, 'graph' => 0, 'descr' => 'standby'],
             ];
         } elseif ($state_name == 'cswSwitchState') {
             $states = [
@@ -100,7 +100,7 @@ foreach ($tables as $tablevalue) {
                 ['value' => 8, 'generic' => 2, 'graph' => 0, 'descr' => 'newMasterInit'],
                 ['value' => 9, 'generic' => 1, 'graph' => 0, 'descr' => 'provisioned'],
                 ['value' => 10, 'generic' => 2, 'graph' => 0, 'descr' => 'invalid'],
-                ['value' => 11, 'generic' => 1, 'graph' => 0, 'descr' => 'removed']
+                ['value' => 11, 'generic' => 1, 'graph' => 0, 'descr' => 'removed'],
             ];
         } elseif ($state_name == 'cefcFRUPowerOperStatus') {
             $states = [
@@ -115,7 +115,7 @@ foreach ($tables as $tablevalue) {
                 ['value' => 9, 'generic' => 1, 'graph' => 0, 'descr' => 'on (fan failed)'],
                 ['value' => 10, 'generic' => 2, 'graph' => 0, 'descr' => 'off (cooling)'],
                 ['value' => 11, 'generic' => 2, 'graph' => 0, 'descr' => 'off (connector rating)'],
-                ['value' => 12, 'generic' => 1, 'graph' => 0, 'descr' => 'on (no inline power)']
+                ['value' => 12, 'generic' => 1, 'graph' => 0, 'descr' => 'on (no inline power)'],
             ];
         } else {
             $states = [
@@ -124,7 +124,7 @@ foreach ($tables as $tablevalue) {
                 ['value' => 3, 'generic' => 2, 'graph' => 0, 'descr' => 'critical'],
                 ['value' => 4, 'generic' => 3, 'graph' => 0, 'descr' => 'shutdown'],
                 ['value' => 5, 'generic' => 3, 'graph' => 0, 'descr' => 'notPresent'],
-                ['value' => 6, 'generic' => 2, 'graph' => 0, 'descr' => 'notFunctioning']
+                ['value' => 6, 'generic' => 2, 'graph' => 0, 'descr' => 'notFunctioning'],
             ];
         }
         create_state_index($state_name, $states);
@@ -147,9 +147,9 @@ foreach ($tables as $tablevalue) {
                     $stack_port_descr = get_port_by_index_cache($device['device_id'], $index);
                     $descr = $tablevalue['descr'] . $stack_port_descr['ifDescr'];
                 } elseif ($state_name == 'cefcFRUPowerOperStatus') {
-                    $descr = snmp_get($device, 'entPhysicalName.'.$index, '-Oqv', 'ENTITY-MIB');
+                    $descr = snmp_get($device, 'entPhysicalName.' . $index, '-Oqv', 'ENTITY-MIB');
                 }
-                discover_sensor($valid['sensor'], 'state', $device, $cur_oid.$index, $index, $state_name, $descr, 1, 1, null, null, null, null, $temp[$index][$tablevalue['state_name']], 'snmp', $index);
+                discover_sensor($valid['sensor'], 'state', $device, $cur_oid . $index, $index, $state_name, $descr, 1, 1, null, null, null, null, $temp[$index][$tablevalue['state_name']], 'snmp', $index);
 
                 //Create Sensor To State Index
                 create_sensor_to_state_index($device, $state_name, $index);
