@@ -17,12 +17,10 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2018 Paul Heinrichs
  * @author     Paul Heinrichs <pdheinrichs@gmail.com>
  */
-
 $states = [
     'power' => [
         ['value' => 1, 'generic' => 0, 'graph' => 0, 'descr' => 'Power On'],
@@ -31,7 +29,7 @@ $states = [
     'sync' => [
         ['value' => 1, 'generic' => 0, 'graph' => 0, 'descr' => 'Sync Enabled'],
         ['value' => 0, 'generic' => 1, 'graph' => 0, 'descr' => 'Sync Off'],
-    ]
+    ],
 ];
 $octetSetup = [
     [
@@ -39,38 +37,38 @@ $octetSetup = [
         'state_name'    => 'portOnM',
         'states'        => $states['power'],
         'name'          => 'Master Port Enabled',
-        'num_oid'       => '.1.3.6.1.4.1.25868.1.12.0'
+        'num_oid'       => '.1.3.6.1.4.1.25868.1.12.0',
     ],
     [
         'oid'           => 'portSyncM.0',
         'state_name'    => 'portSyncM',
         'states'        => $states['sync'],
         'name'          => 'Master Port Sync Status',
-        'num_oid'       => '.1.3.6.1.4.1.25868.1.13.0'
+        'num_oid'       => '.1.3.6.1.4.1.25868.1.13.0',
     ],
     [
         'oid'           => 'portOnS.0',
         'state_name'    => 'portOnS',
         'states'        => $states['power'],
         'name'          => 'Slave Port Enabled',
-        'num_oid'       => '.1.3.6.1.4.1.25868.1.29.0'
+        'num_oid'       => '.1.3.6.1.4.1.25868.1.29.0',
     ],
     [
         'oid'           => 'portSyncS.0',
         'state_name'    => 'portSyncS',
         'states'        => $states['sync'],
         'name'          => 'Slave Port Sync Status',
-        'num_oid'       => '.1.3.6.1.4.1.25868.1.30.0'
+        'num_oid'       => '.1.3.6.1.4.1.25868.1.30.0',
     ],
 ];
 
 foreach ($octetSetup as $entry) {
-    $octetString = snmp_get($device, $entry['oid'], "-Ovqe", "CTMMIBCUSTOM");
+    $octetString = snmp_get($device, $entry['oid'], '-Ovqe', 'CTMMIBCUSTOM');
     if ($octetString) {
         $onStates = explode(',', $octetString);
-        
+
         create_state_index($entry['state_name'], $entry['states']);
-    
+
         foreach ($onStates as $index => $value) {
             $port_number = $index + 1;
             discover_sensor(
@@ -80,7 +78,7 @@ foreach ($octetSetup as $entry) {
                 $entry['num_oid'],
                 $port_number,
                 $entry['state_name'],
-                $entry['name'] ." $port_number",
+                $entry['name'] . " $port_number",
                 1,
                 1,
                 null,
