@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2017 Neil Lathwood
  * @author     Neil Lathwood <neil@lathwood.co.uk>
@@ -47,12 +46,12 @@ $sensors = [
 ];
 
 foreach ($sensors as $sensor) {
-    $temp = snmp_get($device, $sensor['state_name'].'.0', "-Ovqe", "ExaltComProducts");
+    $temp = snmp_get($device, $sensor['state_name'] . '.0', '-Ovqe', 'ExaltComProducts');
     $cur_oid = $sensor['num_oid'];
 
     if (is_numeric($temp)) {
         $state_name = $sensor['state_name'];
-        $index      = $state_name;
+        $index = $state_name;
         create_state_index($state_name, $states);
 
         $descr = $sensor['descr'];
