@@ -20,16 +20,16 @@ if ($device['os'] == 'hirschmann') {
 
         foreach ($oid as $index => $entry) {
             //Discover Sensors
-            discover_sensor($valid['sensor'], 'state', $device, $cur_oid.$index, 'hmPowerSupplyStatus'.$index, $state_name, 'Power Supply '.$oid[$index]['hmPSID'], 1, 1, null, null, null, null, $oid[$index]['hmPowerSupplyStatus'], 'snmp', 'hmPowerSupplyStatus'.$index);
+            discover_sensor($valid['sensor'], 'state', $device, $cur_oid . $index, 'hmPowerSupplyStatus' . $index, $state_name, 'Power Supply ' . $oid[$index]['hmPSID'], 1, 1, null, null, null, null, $oid[$index]['hmPowerSupplyStatus'], 'snmp', 'hmPowerSupplyStatus' . $index);
 
             //Create Sensor To State Index
-            create_sensor_to_state_index($device, $state_name, 'hmPowerSupplyStatus'.$index);
+            create_sensor_to_state_index($device, $state_name, 'hmPowerSupplyStatus' . $index);
         }
     }
 
-   ////////////////////////////////
-   /// Common LED Status States ///
-   ////////////////////////////////
+    ////////////////////////////////
+    /// Common LED Status States ///
+    ////////////////////////////////
     $states = [
         ['value' => 1, 'generic' => 0, 'graph' => 0, 'descr' => 'off'],
         ['value' => 2, 'generic' => 0, 'graph' => 0, 'descr' => 'green'],
@@ -37,50 +37,50 @@ if ($device['os'] == 'hirschmann') {
         ['value' => 4, 'generic' => 2, 'graph' => 0, 'descr' => 'red'],
     ];
 
-   ///////////////////////////////
-   /// LED Status Power Supply ///
-   ///////////////////////////////
-    $temp = snmp_get($device, "hmLEDRSPowerSupply.0", "-Ovqe", "HMPRIV-MGMT-SNMP-MIB");
+    ///////////////////////////////
+    /// LED Status Power Supply ///
+    ///////////////////////////////
+    $temp = snmp_get($device, 'hmLEDRSPowerSupply.0', '-Ovqe', 'HMPRIV-MGMT-SNMP-MIB');
     $cur_oid = '.1.3.6.1.4.1.248.14.1.1.35.1.1.0';
     $index = '0';
 
     if (is_numeric($temp)) {
-       //Create State Index
+        //Create State Index
         $state_name = 'hmLEDRSPowerSupply';
         create_state_index($state_name, $states);
 
         $descr = 'LED Status Power Supply';
-    //Discover Sensors
-        discover_sensor($valid['sensor'], 'state', $device, $cur_oid, 'hmLEDRSPowerSupply.'.$index, $state_name, $descr, 1, 1, null, null, null, null, $temp, 'snmp', 'hmLEDRSPowerSupply.'.$index);
+        //Discover Sensors
+        discover_sensor($valid['sensor'], 'state', $device, $cur_oid, 'hmLEDRSPowerSupply.' . $index, $state_name, $descr, 1, 1, null, null, null, null, $temp, 'snmp', 'hmLEDRSPowerSupply.' . $index);
 
-    //Create Sensor To State Index
-        create_sensor_to_state_index($device, $state_name, 'hmLEDRSPowerSupply.'.$index);
+        //Create Sensor To State Index
+        create_sensor_to_state_index($device, $state_name, 'hmLEDRSPowerSupply.' . $index);
     }
 
-   //////////////////////////
-   /// LED Status Standby ///
-   //////////////////////////
-    $temp = snmp_get($device, "hmLEDRStandby.0", "-Ovqe", "HMPRIV-MGMT-SNMP-MIB");
+    //////////////////////////
+    /// LED Status Standby ///
+    //////////////////////////
+    $temp = snmp_get($device, 'hmLEDRStandby.0', '-Ovqe', 'HMPRIV-MGMT-SNMP-MIB');
     $cur_oid = '.1.3.6.1.4.1.248.14.1.1.35.1.2.0';
     $index = '0';
- 
+
     if (is_numeric($temp)) {
         //Create State Index
         $state_name = 'hmLEDRStandby';
         create_state_index($state_name, $states);
- 
+
         $descr = 'LED Status Standby';
         //Discover Sensors
-        discover_sensor($valid['sensor'], 'state', $device, $cur_oid, 'hmLEDRStandby.'.$index, $state_name, $descr, 1, 1, null, null, null, null, $temp, 'snmp', 'hmLEDRStandby.'.$index);
+        discover_sensor($valid['sensor'], 'state', $device, $cur_oid, 'hmLEDRStandby.' . $index, $state_name, $descr, 1, 1, null, null, null, null, $temp, 'snmp', 'hmLEDRStandby.' . $index);
 
         //Create Sensor To State Index
-        create_sensor_to_state_index($device, $state_name, 'hmLEDRStandby.'.$index);
+        create_sensor_to_state_index($device, $state_name, 'hmLEDRStandby.' . $index);
     }
 
     /////////////////////////////////////
     /// LED Status Redundancy Manager ///
     /////////////////////////////////////
-    $temp = snmp_get($device, "hmLEDRSRedundancyManager.0", "-Ovqe", "HMPRIV-MGMT-SNMP-MIB");
+    $temp = snmp_get($device, 'hmLEDRSRedundancyManager.0', '-Ovqe', 'HMPRIV-MGMT-SNMP-MIB');
     $cur_oid = '.1.3.6.1.4.1.248.14.1.1.35.1.3.0';
     $index = '0';
 
@@ -91,16 +91,16 @@ if ($device['os'] == 'hirschmann') {
 
         $descr = 'LED Status Redundancy Manager';
         //Discover Sensors
-        discover_sensor($valid['sensor'], 'state', $device, $cur_oid, 'hmLEDRSRedundancyManager.'.$index, $state_name, $descr, 1, 1, null, null, null, null, $temp, 'snmp', 'hmLEDRSRedundancyManager.'.$index);
+        discover_sensor($valid['sensor'], 'state', $device, $cur_oid, 'hmLEDRSRedundancyManager.' . $index, $state_name, $descr, 1, 1, null, null, null, null, $temp, 'snmp', 'hmLEDRSRedundancyManager.' . $index);
 
         //Create Sensor To State Index
-        create_sensor_to_state_index($device, $state_name, 'hmLEDRSRedundancyManager.'.$index);
+        create_sensor_to_state_index($device, $state_name, 'hmLEDRSRedundancyManager.' . $index);
     }
 
     ////////////////////////
     /// LED Status Fault ///
     ////////////////////////
-    $temp = snmp_get($device, "hmLEDRSFault.0", "-Ovqe", "HMPRIV-MGMT-SNMP-MIB");
+    $temp = snmp_get($device, 'hmLEDRSFault.0', '-Ovqe', 'HMPRIV-MGMT-SNMP-MIB');
     $cur_oid = '.1.3.6.1.4.1.248.14.1.1.35.1.4.0';
     $index = '0';
 
@@ -111,9 +111,9 @@ if ($device['os'] == 'hirschmann') {
 
         $descr = 'LED Status Fault';
         //Discover Sensors
-        discover_sensor($valid['sensor'], 'state', $device, $cur_oid, 'hmLEDRSFault.'.$index, $state_name, $descr, 1, 1, null, null, null, null, $temp, 'snmp', 'hmLEDRSFault.'.$index);
+        discover_sensor($valid['sensor'], 'state', $device, $cur_oid, 'hmLEDRSFault.' . $index, $state_name, $descr, 1, 1, null, null, null, null, $temp, 'snmp', 'hmLEDRSFault.' . $index);
 
         //Create Sensor To State Index
-        create_sensor_to_state_index($device, $state_name, 'hmLEDRSFault.'.$index);
+        create_sensor_to_state_index($device, $state_name, 'hmLEDRSFault.' . $index);
     }
 }
