@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2017 Neil Lathwood
  * @author     Neil Lathwood <neil@lathwood.co.uk>
@@ -25,7 +24,7 @@
 
 // One could add more entries from deviceGroup, but this will do as a start
 $tables = [
-    ['cpqDaPhyDrvStatus','.1.3.6.1.4.1.232.3.2.5.1.1.6.','Status','CPQIDA-MIB', [
+    ['cpqDaPhyDrvStatus', '.1.3.6.1.4.1.232.3.2.5.1.1.6.', 'Status', 'CPQIDA-MIB', [
         ['value' => 1, 'generic' => 3, 'graph' => 0, 'descr' => 'other'],
         ['value' => 2, 'generic' => 0, 'graph' => 0, 'descr' => 'ok'],
         ['value' => 3, 'generic' => 2, 'graph' => 0, 'descr' => 'failed'],
@@ -36,7 +35,7 @@ $tables = [
         ['value' => 8, 'generic' => 2, 'graph' => 0, 'descr' => 'ssdWearOut'],
         ['value' => 9, 'generic' => 3, 'graph' => 0, 'descr' => 'notAuthenticated'],
     ]],
-    ['cpqDaPhyDrvSmartStatus','.1.3.6.1.4.1.232.3.2.5.1.1.57.','S.M.A.R.T.','CPQIDA-MIB', [
+    ['cpqDaPhyDrvSmartStatus', '.1.3.6.1.4.1.232.3.2.5.1.1.57.', 'S.M.A.R.T.', 'CPQIDA-MIB', [
         ['value' => 1, 'generic' => 3, 'graph' => 0, 'descr' => 'other'],
         ['value' => 2, 'generic' => 0, 'graph' => 0, 'descr' => 'ok'],
         ['value' => 3, 'generic' => 1, 'graph' => 0, 'descr' => 'replaceDrive'],
@@ -45,16 +44,16 @@ $tables = [
 ];
 
 foreach ($tables as $tablevalue) {
-    list($oid, $num_oid, $descr, $mib, $states) = $tablevalue;
+    [$oid, $num_oid, $descr, $mib, $states] = $tablevalue;
     $temp = snmpwalk_cache_multi_oid($device, $oid, [], $mib, 'hp', '-OQUse');
 
-    if (!empty($temp)) {
+    if (! empty($temp)) {
         //Create State Index
         $state_name = $oid;
         $state_index_id = create_state_index($state_name, $states);
 
         foreach ($temp as $index => $entry) {
-            $drive_bay = snmp_get($device, "cpqDaPhyDrvBay.$index", '-Ovqn', 'CPQIDA-MIB');
+            $drive_bay = snmp_get($device, "cpqDaPhyDrvBay.$index", '-Ovqn', 'CPQIDA-MIB', 'hp');
 
             //Discover Sensors
             discover_sensor(
