@@ -17,12 +17,10 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2017 Lorenzo Zafra
  * @author     Lorenzo Zafra<zafra@ualberta.ca>
  */
-
 $oids = snmpwalk_cache_oid($device, 'outputEntry', [], 'ICT-DISTRIBUTION-PANEL-MIB');
 
 if (is_array($oids)) {
@@ -35,8 +33,8 @@ if (is_array($oids)) {
 
     foreach ($oids as $index => $entry) {
         $fuse_state_oid = '.1.3.6.1.4.1.39145.10.8.1.4.' . $index;
-        $fuse_number = (int)$index + 1;
-        $descr = "Fuse #" . $fuse_number;
+        $fuse_number = (int) $index + 1;
+        $descr = 'Fuse #' . $fuse_number;
 
         $current_value_string = $entry[$state_name];
         if ($current_value_string == 'OK') {
