@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2019 Nick Hilliard
  * @author     Nick Hilliard <nick@foobar.org>
@@ -25,11 +24,11 @@
 
 // create state index
 $state_name = 'cardMode';
-$states = array(
-     array('value' => 0, 'generic' => 3, 'graph' => 0, 'descr' => 'notapplicable'),
-     array('value' => 1, 'generic' => 0, 'graph' => 0, 'descr' => 'normal'),
-     array('value' => 2, 'generic' => 1, 'graph' => 0, 'descr' => 'regen'),
- );
+$states = [
+    ['value' => 0, 'generic' => 3, 'graph' => 0, 'descr' => 'notapplicable'],
+    ['value' => 1, 'generic' => 0, 'graph' => 0, 'descr' => 'normal'],
+    ['value' => 2, 'generic' => 1, 'graph' => 0, 'descr' => 'regen'],
+];
 create_state_index($state_name, $states);
 
 $num_oid = '.1.3.6.1.4.1.42229.1.2.3.3.1.1.10.';
@@ -37,8 +36,8 @@ $num_oid = '.1.3.6.1.4.1.42229.1.2.3.3.1.1.10.';
 foreach ($pre_cache['infineragroove_slotTable'] as $index => $data) {
     if (is_array($data) && isset($data['cardMode'])) {
         // discover sensors
-        $descr = 'slot-'.str_replace('.', '/', $index).' ('.$data['slotActualCardType'].')';
-        discover_sensor($valid['sensor'], 'state', $device, $num_oid.$index, $index, $state_name, $descr, '1', '1', null, null, null, null, $data['cardMode'], 'snmp', $index);
+        $descr = 'slot-' . str_replace('.', '/', $index) . ' (' . $data['slotActualCardType'] . ')';
+        discover_sensor($valid['sensor'], 'state', $device, $num_oid . $index, $index, $state_name, $descr, '1', '1', null, null, null, null, $data['cardMode'], 'snmp', $index);
 
         // create sensor to state index
         create_sensor_to_state_index($device, $state_name, $index);
