@@ -3,12 +3,10 @@
  * LibreNMS - ADVA device support - Temperature Sensors
  *
  * @category   Network_Monitoring
- * @package    LibreNMS
- * @subpackage ADVA device support
  * @author     Christoph Zilian <czilian@hotmail.com>
  * @license    http://gnu.org/copyleft/gpl.html GNU GPL
  * @link       https://github.com/librenms/librenms/
-
+ *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation, either version 3 of the License, or (at your
@@ -60,8 +58,8 @@ foreach (array_keys($pre_cache['adva_fsp150']) as $index) {
     foreach ($sensors_adva as $entry) {
         $sensor_name = $entry['sensor_name'];
         if ($pre_cache['adva_fsp150'][$index][$sensor_name]) {
-            $oid = $entry['sensor_oid'] . "." . $index;
-            $descr = $pre_cache['adva_fsp150'][$index]['slotCardUnitName'] . " [#" . $pre_cache['adva_fsp150'][$index]['slotIndex'] . "]";
+            $oid = $entry['sensor_oid'] . '.' . $index;
+            $descr = $pre_cache['adva_fsp150'][$index]['slotCardUnitName'] . ' [#' . $pre_cache['adva_fsp150'][$index]['slotIndex'] . ']';
             $current = $pre_cache['adva_fsp150'][$index][$entry['sensor_name']] / $divisor;
 
             d_echo($pre_cache['adva_fsp150']);
@@ -97,7 +95,7 @@ foreach ($pre_cache['adva_fsp150_ports'] as $index => $entry) {
             $entPhysicalIndex = $entry['cmEthernetNetPortIfIndex'];
             $entPhysicalIndex_measured = 'ports';
             $descr = dbFetchCell('SELECT `ifName` FROM `ports` WHERE `ifIndex`= ? AND `device_id` = ?', [$entry['cmEthernetNetPortIfIndex'], $device['device_id']]);
-            
+
             discover_sensor(
                 $valid['sensor'],
                 'temperature',
@@ -127,7 +125,7 @@ foreach ($pre_cache['adva_fsp150_ports'] as $index => $entry) {
             $entPhysicalIndex = $entry['cmEthernetAccPortIfIndex'];
             $entPhysicalIndex_measured = 'ports';
             $descr = dbFetchCell('SELECT `ifName` FROM `ports` WHERE `ifIndex`= ? AND `device_id` = ?', [$entry['cmEthernetAccPortIfIndex'], $device['device_id']]);
-            
+
             discover_sensor(
                 $valid['sensor'],
                 'temperature',
@@ -157,7 +155,7 @@ foreach ($pre_cache['adva_fsp150_ports'] as $index => $entry) {
             $entPhysicalIndex = $entry['cmEthernetTrafficPortIfIndex'];
             $entPhysicalIndex_measured = 'ports';
             $descr = dbFetchCell('SELECT `ifName` FROM `ports` WHERE `ifIndex`= ? AND `device_id` = ?', [$entry['cmEthernetTrafficPortIfIndex'], $device['device_id']]);
-            
+
             discover_sensor(
                 $valid['sensor'],
                 'temperature',
