@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2017 Lorenzo Zafra
  * @author     Lorenzo Zafra<zafra@ualberta.ca>
@@ -28,9 +27,9 @@
 $temperature_unit = trim(snmp_get($device, '.1.3.6.1.4.1.7428.1.2.2.1.1.12.1', '-Oqv'), '" ');
 $temperature = trim(snmp_get($device, '.1.3.6.1.4.1.7428.1.2.2.1.1.11.1', '-Oqv'), '" ');
 
-if (!empty($temperature_unit) && !empty($temperature)) {
+if (! empty($temperature_unit) && ! empty($temperature)) {
     // If fahrenheit convert to celcius
-    if ($temperature_unit == "2") {
+    if ($temperature_unit == '2') {
         $temperature = ($temperature - 32) / 1.8;
     }
 
