@@ -17,12 +17,10 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2018 TheGreatDoc
  * @author     TheGreatDoc
  */
-
 $temp_oid = '1.3.6.1.4.1.2011.2.6.7.1.1.2.1.10.0';
 $descr_oid = '1.3.6.1.4.1.2011.2.6.7.1.1.2.1.7.0';
 
@@ -33,7 +31,7 @@ $data = reset($data);
 $descr_data = reset($descr_data);
 
 foreach ($data as $index => $value) {
-    if ($value < "999") {
+    if ($value < '999') {
         $tempCurr = $value;
         $temperature_oid = '.' . $temp_oid . '.' . $index;
         $descr = $descr_data[$index];
