@@ -40,7 +40,7 @@ foreach ($prefixes as $prefix => $numOidPrefix) {
             $lowWarnLimit = $oid[$prefix . 'Thresh3'];
             $highLimit = $oid[$prefix . 'Thresh1'];
             $highWarnLimit = $oid[$prefix . 'Thresh2'];
-            if ($oid[$prefix . 'Units'] == "Fahrenheit") {
+            if ($oid[$prefix . 'Units'] == 'Fahrenheit') {
                 $user_function = 'fahrenheit_to_celsius';
                 $value = fahrenheit_to_celsius($value);
                 $lowLimit = fahrenheit_to_celsius($lowLimit);
