@@ -3,12 +3,10 @@
  * LibreNMS - ADVA device support - Voltage Sensors
  *
  * @category   Network_Monitoring
- * @package    LibreNMS
- * @subpackage ADVA device support
  * @author     Christoph Zilian <czilian@hotmail.com>
  * @license    http://gnu.org/copyleft/gpl.html GNU GPL
  * @link       https://github.com/librenms/librenms/
-
+ *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation, either version 3 of the License, or (at your
@@ -21,22 +19,22 @@
 // *************************************************************
 
     $multiplier = 1;
-    $divisor    = 1000;
+    $divisor = 1000;
 
 if (is_array($pre_cache['adva_fsp3kr7_Card'])) {
     foreach (array_keys($pre_cache['adva_fsp3kr7_Card']) as $index) {
         if ($pre_cache['adva_fsp3kr7_Card'][$index]['eqptPhysInstValuePsuVoltInp']) {
-            $oid          = '.1.3.6.1.4.1.2544.1.11.11.1.2.1.1.1.7.'.$index;
-            $descr        = strtoupper($pre_cache['adva_fsp3kr7_Card'][$index]['entityEqptAidString'])." Input";
+            $oid = '.1.3.6.1.4.1.2544.1.11.11.1.2.1.1.1.7.' . $index;
+            $descr = strtoupper($pre_cache['adva_fsp3kr7_Card'][$index]['entityEqptAidString']) . ' Input';
             $rrd_filename = $descr;
-            $current      = $pre_cache['adva_fsp3kr7_Card'][$index]['eqptPhysInstValuePsuVoltInp']/$divisor;
+            $current = $pre_cache['adva_fsp3kr7_Card'][$index]['eqptPhysInstValuePsuVoltInp'] / $divisor;
 
             discover_sensor(
                 $valid['sensor'],
                 'voltage',
                 $device,
                 $oid,
-                'eqptPhysInstValuePsuVoltInp'.$index,
+                'eqptPhysInstValuePsuVoltInp' . $index,
                 'adva_fsp3kr7',
                 $descr,
                 $divisor,
