@@ -4,14 +4,14 @@ use LibreNMS\Config;
 
 if (Config::get('discover_services')) {
     // FIXME: use /etc/services?
-    $known_services = array(
+    $known_services = [
         22  => 'ssh',
         25  => 'smtp',
         53  => 'dns',
         80  => 'http',
         110 => 'pop',
         143 => 'imap',
-    );
+    ];
 
     // Services
     if ($device['type'] == 'server') {
@@ -19,10 +19,10 @@ if (Config::get('discover_services')) {
         foreach (explode("\n", $oids) as $data) {
             $data = trim($data);
             if ($data) {
-                list($oid, $tcpstatus) = explode(' ', $data);
+                [$oid, $tcpstatus] = explode(' ', $data);
                 if (trim($tcpstatus) == 'listen') {
                     $split_oid = explode('.', $oid);
-                    $tcp_port  = $split_oid[(count($split_oid) - 6)];
+                    $tcp_port = $split_oid[(count($split_oid) - 6)];
                     if ($known_services[$tcp_port]) {
                         discover_service($device, $known_services[$tcp_port]);
                     }
