@@ -17,22 +17,20 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2017 Neil Lathwood
  * @author     Neil Lathwood <gh+n@laf.io>
  */
-
 if ($device['os'] === 'onefs') {
     $oids = snmp_get_multi_oid($device, ['ifsTotalBytes.0', 'ifsUsedBytes.0', 'ifsAvailableBytes.0'], '-OUQn', 'ISILON-MIB');
 
-    $fstype = "ifs";
-    $descr  = "Internal File System";
-    $units  = 1024;
-    $index  = 0;
-    $free   = $oids['.1.3.6.1.4.1.12124.1.3.3.0'];
-    $total  = $oids['.1.3.6.1.4.1.12124.1.3.1.0'];
-    $used   = $oids['.1.3.6.1.4.1.12124.1.3.2.0'];
+    $fstype = 'ifs';
+    $descr = 'Internal File System';
+    $units = 1024;
+    $index = 0;
+    $free = $oids['.1.3.6.1.4.1.12124.1.3.3.0'];
+    $total = $oids['.1.3.6.1.4.1.12124.1.3.1.0'];
+    $used = $oids['.1.3.6.1.4.1.12124.1.3.2.0'];
     if (is_numeric($free) && is_numeric($total)) {
         discover_storage($valid_storage, $device, $index, $fstype, 'onefs', $descr, $total, $units, $used);
     }
