@@ -18,8 +18,8 @@
 
 require 'includes/html/collectd/CollectdColor.php';
 
-use LibreNMS\Config;
 use LibreNMS\CollectdColor;
+use LibreNMS\Config;
 
 define('REGEXP_HOST', '/^[a-zA-Z0-9]([a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(\\.[a-zA-Z0-9]([a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)*$/');
 define('REGEXP_PLUGIN', '/^[a-zA-Z0-9_.-]+$/');
@@ -39,8 +39,8 @@ function read_var($name, &$array, $default = null)
     if (isset($array[$name])) {
         if (is_array($array[$name])) {
             if (get_magic_quotes_gpc()) {
-                $ret = array();
-                while (list($k, $v) = each($array[$name])) {
+                $ret = [];
+                foreach ($array[$name] as $k => $v) {
                     $ret[stripslashes($k)] = stripslashes($v);
                 }
 
@@ -58,7 +58,6 @@ function read_var($name, &$array, $default = null)
     }
 }//end read_var()
 
-
 /*
  * Alphabetically compare host names, comparing label
  * from tld to node name
@@ -67,8 +66,8 @@ function collectd_compare_host($a, $b)
 {
     $ea = explode('.', $a);
     $eb = explode('.', $b);
-    $i  = (count($ea) - 1);
-    $j  = (count($eb) - 1);
+    $i = (count($ea) - 1);
+    $j = (count($eb) - 1);
     while ($i >= 0 && $j >= 0) {
         if (($r = strcmp($ea[$i--], $eb[$j--])) != 0) {
             return $r;
@@ -78,32 +77,31 @@ function collectd_compare_host($a, $b)
     return 0;
 }//end collectd_compare_host()
 
-
 /**
  * Fetch list of hosts found in collectd's datadirs.
  * @return array Sorted list of hosts (sorted by label from rigth to left)
  */
 function collectd_list_hosts()
 {
-    $hosts = array();
+    $hosts = [];
     foreach (Config::get('datadirs') as $datadir) {
         if ($d = @opendir($datadir)) {
             while (($dent = readdir($d)) !== false) {
-                if ($dent != '.' && $dent != '..' && is_dir($datadir.'/'.$dent) && preg_match(REGEXP_HOST, $dent)) {
+                if ($dent != '.' && $dent != '..' && is_dir($datadir . '/' . $dent) && preg_match(REGEXP_HOST, $dent)) {
                     $hosts[] = $dent;
                 }
             }
             closedir($d);
         } else {
-            error_log('Failed to open datadir: '.$datadir);
+            error_log('Failed to open datadir: ' . $datadir);
         }
     }
     $hosts = array_unique($hosts);
     usort($hosts, 'collectd_compare_host');
+
     return $hosts;
 }
 
-
 /**
  * Fetch list of plugins found in collectd's datadirs for given host.
  *
@@ -112,11 +110,11 @@ function collectd_list_hosts()
  */
 function collectd_list_plugins($arg_host)
 {
-    $plugins = array();
+    $plugins = [];
     foreach (Config::get('datadirs') as $datadir) {
-        if (preg_match(REGEXP_HOST, $arg_host) && ($d = @opendir($datadir.'/'.$arg_host))) {
+        if (preg_match(REGEXP_HOST, $arg_host) && ($d = @opendir($datadir . '/' . $arg_host))) {
             while (($dent = readdir($d)) !== false) {
-                if ($dent != '.' && $dent != '..' && is_dir($datadir.'/'.$arg_host.'/'.$dent)) {
+                if ($dent != '.' && $dent != '..' && is_dir($datadir . '/' . $arg_host . '/' . $dent)) {
                     if ($i = strpos($dent, '-')) {
                         $plugins[] = substr($dent, 0, $i);
                     } else {
@@ -131,10 +129,10 @@ function collectd_list_plugins($arg_host)
 
     $plugins = array_unique($plugins);
     sort($plugins);
+
     return $plugins;
 }//end collectd_list_plugins()
 
-
 /**
  * Fetch list of plugin instances found in collectd's datadirs for given host+plugin
  *
@@ -144,17 +142,17 @@ function collectd_list_plugins($arg_host)
  */
 function collectd_list_pinsts($arg_host, $arg_plugin)
 {
-    $pinsts = array();
+    $pinsts = [];
     foreach (Config::get('datadirs') as $datadir) {
-        if (preg_match(REGEXP_HOST, $arg_host) && ($d = opendir($datadir.'/'.$arg_host))) {
+        if (preg_match(REGEXP_HOST, $arg_host) && ($d = opendir($datadir . '/' . $arg_host))) {
             while (($dent = readdir($d)) !== false) {
-                if ($dent != '.' && $dent != '..' && is_dir($datadir.'/'.$arg_host.'/'.$dent)) {
+                if ($dent != '.' && $dent != '..' && is_dir($datadir . '/' . $arg_host . '/' . $dent)) {
                     if ($i = strpos($dent, '-')) {
                         $plugin = substr($dent, 0, $i);
-                        $pinst  = substr($dent, ($i + 1));
+                        $pinst = substr($dent, ($i + 1));
                     } else {
                         $plugin = $dent;
-                        $pinst  = '';
+                        $pinst = '';
                     }
 
                     if ($plugin == $arg_plugin) {
@@ -169,10 +167,10 @@ function collectd_list_pinsts($arg_host, $arg_plugin)
 
     $pinsts = array_unique($pinsts);
     sort($pinsts);
+
     return $pinsts;
 }//end collectd_list_pinsts()
 
-
 /**
  * Fetch list of types found in collectd's datadirs for given host+plugin+instance
  * @arg_host Name of host
@@ -182,16 +180,16 @@ function collectd_list_pinsts($arg_host, $arg_plugin)
  */
 function collectd_list_types($arg_host, $arg_plugin, $arg_pinst)
 {
-    $types     = array();
-    $my_plugin = $arg_plugin.(strlen($arg_pinst) ? '-'.$arg_pinst : '');
-    if (!preg_match(REGEXP_PLUGIN, $my_plugin)) {
+    $types = [];
+    $my_plugin = $arg_plugin . (strlen($arg_pinst) ? '-' . $arg_pinst : '');
+    if (! preg_match(REGEXP_PLUGIN, $my_plugin)) {
         return $types;
     }
 
     foreach (Config::get('datadirs') as $datadir) {
-        if (preg_match(REGEXP_HOST, $arg_host) && ($d = @opendir($datadir.'/'.$arg_host.'/'.$my_plugin))) {
+        if (preg_match(REGEXP_HOST, $arg_host) && ($d = @opendir($datadir . '/' . $arg_host . '/' . $my_plugin))) {
             while (($dent = readdir($d)) !== false) {
-                if ($dent != '.' && $dent != '..' && is_file($datadir.'/'.$arg_host.'/'.$my_plugin.'/'.$dent) && substr($dent, (strlen($dent) - 4)) == '.rrd') {
+                if ($dent != '.' && $dent != '..' && is_file($datadir . '/' . $arg_host . '/' . $my_plugin . '/' . $dent) && substr($dent, (strlen($dent) - 4)) == '.rrd') {
                     $dent = substr($dent, 0, (strlen($dent) - 4));
                     if ($i = strpos($dent, '-')) {
                         $types[] = substr($dent, 0, $i);
@@ -207,10 +205,10 @@ function collectd_list_types($arg_host, $arg_plugin, $arg_pinst)
 
     $types = array_unique($types);
     sort($types);
+
     return $types;
 }//end collectd_list_types()
 
-
 /**
  * Fetch list of type instances found in collectd's datadirs for given host+plugin+instance+type
  * @arg_host Name of host
@@ -221,22 +219,22 @@ function collectd_list_types($arg_host, $arg_plugin, $arg_pinst)
  */
 function collectd_list_tinsts($arg_host, $arg_plugin, $arg_pinst, $arg_type)
 {
-    $tinsts    = array();
-    $my_plugin = $arg_plugin.(strlen($arg_pinst) ? '-'.$arg_pinst : '');
-    if (!preg_match(REGEXP_PLUGIN, $my_plugin)) {
+    $tinsts = [];
+    $my_plugin = $arg_plugin . (strlen($arg_pinst) ? '-' . $arg_pinst : '');
+    if (! preg_match(REGEXP_PLUGIN, $my_plugin)) {
         return $tinsts;
     }
 
     foreach (Config::get('datadirs') as $datadir) {
-        if (preg_match(REGEXP_HOST, $arg_host) && ($d = @opendir($datadir.'/'.$arg_host.'/'.$my_plugin))) {
+        if (preg_match(REGEXP_HOST, $arg_host) && ($d = @opendir($datadir . '/' . $arg_host . '/' . $my_plugin))) {
             while (($dent = readdir($d)) !== false) {
-                if ($dent != '.' && $dent != '..' && is_file($datadir.'/'.$arg_host.'/'.$my_plugin.'/'.$dent) && substr($dent, (strlen($dent) - 4)) == '.rrd') {
+                if ($dent != '.' && $dent != '..' && is_file($datadir . '/' . $arg_host . '/' . $my_plugin . '/' . $dent) && substr($dent, (strlen($dent) - 4)) == '.rrd') {
                     $dent = substr($dent, 0, (strlen($dent) - 4));
                     if ($i = strpos($dent, '-')) {
-                        $type  = substr($dent, 0, $i);
+                        $type = substr($dent, 0, $i);
                         $tinst = substr($dent, ($i + 1));
                     } else {
-                        $type  = $dent;
+                        $type = $dent;
                         $tinst = '';
                     }
 
@@ -252,10 +250,10 @@ function collectd_list_tinsts($arg_host, $arg_plugin, $arg_pinst, $arg_type)
 
     $tinsts = array_unique($tinsts);
     sort($tinsts);
+
     return $tinsts;
 }//end collectd_list_tinsts()
 
-
 /**
  * Parse symlinks in order to get an identifier that collectd understands
  * (e.g. virtualisation is collected on host for individual VMs and can be
@@ -271,23 +269,23 @@ function collectd_list_tinsts($arg_host, $arg_plugin, $arg_pinst, $arg_type)
  */
 function collectd_identifier($host, $plugin, $type, $pinst, $tinst)
 {
-    $rrd_realpath    = null;
+    $rrd_realpath = null;
     $orig_identifier = sprintf('%s/%s%s%s/%s%s%s', $host, $plugin, strlen($pinst) ? '-' : '', $pinst, $type, strlen($tinst) ? '-' : '', $tinst);
-    $identifier      = null;
+    $identifier = null;
     foreach (Config::get('datadirs') as $datadir) {
-        if (is_file($datadir.'/'.$orig_identifier.'.rrd')) {
-            $rrd_realpath = realpath($datadir.'/'.$orig_identifier.'.rrd');
+        if (is_file($datadir . '/' . $orig_identifier . '.rrd')) {
+            $rrd_realpath = realpath($datadir . '/' . $orig_identifier . '.rrd');
             break;
         }
     }
 
     if ($rrd_realpath) {
-        $identifier   = basename($rrd_realpath);
-        $identifier   = substr($identifier, 0, (strlen($identifier) - 4));
+        $identifier = basename($rrd_realpath);
+        $identifier = substr($identifier, 0, (strlen($identifier) - 4));
         $rrd_realpath = dirname($rrd_realpath);
-        $identifier   = basename($rrd_realpath).'/'.$identifier;
+        $identifier = basename($rrd_realpath) . '/' . $identifier;
         $rrd_realpath = dirname($rrd_realpath);
-        $identifier   = basename($rrd_realpath).'/'.$identifier;
+        $identifier = basename($rrd_realpath) . '/' . $identifier;
     }
 
     if (is_null($identifier)) {
@@ -297,7 +295,6 @@ function collectd_identifier($host, $plugin, $type, $pinst, $tinst)
     }
 }//end collectd_identifier()
 
-
 /**
  * Tell collectd that it should FLUSH all data it has regarding the
  * graph we are about to generate.
@@ -307,15 +304,15 @@ function collectd_identifier($host, $plugin, $type, $pinst, $tinst)
  */
 function collectd_flush($identifier)
 {
-    if (!Config::get('collectd_sock')) {
+    if (! Config::get('collectd_sock')) {
         return false;
     }
 
-    if (is_null($identifier) || (is_array($identifier) && count($identifier) == 0) || !(is_string($identifier) || is_array($identifier))) {
+    if (is_null($identifier) || (is_array($identifier) && count($identifier) == 0) || ! (is_string($identifier) || is_array($identifier))) {
         return false;
     }
 
-    $u_errno  = 0;
+    $u_errno = 0;
     $u_errmsg = '';
     if ($socket = @fsockopen(Config::get('collectd_sock'), 0, $u_errno, $u_errmsg)) {
         $cmd = 'FLUSH plugin=rrdtool';
@@ -348,6 +345,7 @@ function collectd_flush($identifier)
     } else {
         error_log(sprintf('graph.php: Failed to open unix-socket to collectd: %d: %s', $u_errno, $u_errmsg));
     }
+
     return true;
 }//end collectd_flush()
 
@@ -366,7 +364,6 @@ function rrd_strip_quotes($str)
     }
 }//end rrd_strip_quotes()
 
-
 /**
  * Determine useful information about RRD file
  *
@@ -375,9 +372,9 @@ function rrd_strip_quotes($str)
  */
 function _rrd_info($file)
 {
-    $info = array('filename' => $file);
+    $info = ['filename' => $file];
 
-    $rrd = popen(RRDTOOL.' info '.escapeshellarg($file), 'r');
+    $rrd = popen(RRDTOOL . ' info ' . escapeshellarg($file), 'r');
     if ($rrd) {
         while (($s = fgets($rrd)) !== false) {
             $p = strpos($s, '=');
@@ -385,38 +382,38 @@ function _rrd_info($file)
                 continue;
             }
 
-            $key   = trim(substr($s, 0, $p));
+            $key = trim(substr($s, 0, $p));
             $value = trim(substr($s, ($p + 1)));
             if (strncmp($key, 'ds[', 3) == 0) {
                 // DS definition
-                $p  = strpos($key, ']');
+                $p = strpos($key, ']');
                 $ds = substr($key, 3, ($p - 3));
-                if (!isset($info['DS'])) {
-                    $info['DS'] = array();
+                if (! isset($info['DS'])) {
+                    $info['DS'] = [];
                 }
 
                 $ds_key = substr($key, ($p + 2));
 
                 if (strpos($ds_key, '[') === false) {
-                    if (!isset($info['DS']["$ds"])) {
-                        $info['DS']["$ds"] = array();
+                    if (! isset($info['DS']["$ds"])) {
+                        $info['DS']["$ds"] = [];
                     }
 
                     $info['DS']["$ds"]["$ds_key"] = rrd_strip_quotes($value);
                 }
             } elseif (strncmp($key, 'rra[', 4) == 0) {
                 // RRD definition
-                $p   = strpos($key, ']');
+                $p = strpos($key, ']');
                 $rra = substr($key, 4, ($p - 4));
-                if (!isset($info['RRA'])) {
-                    $info['RRA'] = array();
+                if (! isset($info['RRA'])) {
+                    $info['RRA'] = [];
                 }
 
                 $rra_key = substr($key, ($p + 2));
 
                 if (strpos($rra_key, '[') === false) {
-                    if (!isset($info['RRA']["$rra"])) {
-                        $info['RRA']["$rra"] = array();
+                    if (! isset($info['RRA']["$rra"])) {
+                        $info['RRA']["$rra"] = [];
                     }
 
                     $info['RRA']["$rra"]["$rra_key"] = rrd_strip_quotes($value);
@@ -432,11 +429,10 @@ function _rrd_info($file)
     return $info;
 }//end _rrd_info()
 
-
 function rrd_get_color($code, $line = true)
 {
-    $name = ($line ? 'f_' : 'h_').$code;
-    if (!Config::has("rrd_colors.$name")) {
+    $name = ($line ? 'f_' : 'h_') . $code;
+    if (! Config::has("rrd_colors.$name")) {
         $c_f = new CollectdColor('random');
         $c_h = new CollectdColor($c_f);
         $c_h->fade();
@@ -447,7 +443,6 @@ function rrd_get_color($code, $line = true)
     return Config::get("rrd_colors.$name");
 }//end rrd_get_color()
 
-
 /**
  * Draw RRD file based on it's structure
  *
@@ -459,11 +454,11 @@ function rrd_get_color($code, $line = true)
  * @param array $opts
  * @return string|false Commandline to call RRDGraph in order to generate the final graph* @internal param $
  */
-function collectd_draw_rrd($host, $plugin, $type, $pinst = null, $tinst = null, $opts = array())
+function collectd_draw_rrd($host, $plugin, $type, $pinst = null, $tinst = null, $opts = [])
 {
     $timespan_def = null;
     $timespans = Config::get('timespan');
-    if (!isset($opts['timespan'])) {
+    if (! isset($opts['timespan'])) {
         $timespan_def = reset($timespans);
     } else {
         foreach ($timespans as &$ts) {
@@ -473,8 +468,8 @@ function collectd_draw_rrd($host, $plugin, $type, $pinst = null, $tinst = null,
         }
     }
 
-    if (!isset($opts['rrd_opts'])) {
-        $opts['rrd_opts'] = array();
+    if (! isset($opts['rrd_opts'])) {
+        $opts['rrd_opts'] = [];
     }
 
     if (isset($opts['logarithmic']) && $opts['logarithmic']) {
@@ -484,8 +479,8 @@ function collectd_draw_rrd($host, $plugin, $type, $pinst = null, $tinst = null,
     $rrdinfo = null;
     $rrdfile = sprintf('%s/%s%s%s/%s%s%s', $host, $plugin, is_null($pinst) ? '' : '-', $pinst, $type, is_null($tinst) ? '' : '-', $tinst);
     foreach (Config::get('datadirs') as $datadir) {
-        if (is_file($datadir.'/'.$rrdfile.'.rrd')) {
-            $rrdinfo = _rrd_info($datadir.'/'.$rrdfile.'.rrd');
+        if (is_file($datadir . '/' . $rrdfile . '.rrd')) {
+            $rrdinfo = _rrd_info($datadir . '/' . $rrdfile . '.rrd');
             if (isset($rrdinfo['RRA']) && is_array($rrdinfo['RRA'])) {
                 break;
             } else {
@@ -498,13 +493,13 @@ function collectd_draw_rrd($host, $plugin, $type, $pinst = null, $tinst = null,
         return false;
     }
 
-    $graph   = array();
+    $graph = [];
     $has_avg = false;
     $has_max = false;
     $has_min = false;
     reset($rrdinfo['RRA']);
     $l_max = 0;
-    while (list($k, $v) = each($rrdinfo['RRA'])) {
+    foreach ($rrdinfo['RRA'] as $k => $v) {
         if ($v['cf'] == 'MAX') {
             $has_max = true;
         } elseif ($v['cf'] == 'AVERAGE') {
@@ -528,11 +523,11 @@ function collectd_draw_rrd($host, $plugin, $type, $pinst = null, $tinst = null,
     }
 
     if ($has_avg) {
-        $graph[] = "COMMENT:   Avg\\n";
+        $graph[] = 'COMMENT:   Avg\\n';
     }
 
     reset($rrdinfo['DS']);
-    while (list($k, $v) = each($rrdinfo['DS'])) {
+    foreach ($rrdinfo['DS'] as $k => $v) {
         if (strlen($k) > $l_max) {
             $l_max = strlen($k);
         }
@@ -553,7 +548,7 @@ function collectd_draw_rrd($host, $plugin, $type, $pinst = null, $tinst = null,
     if ($has_min && $has_max || $has_min && $has_avg || $has_avg && $has_max) {
         $n = 1;
         reset($rrdinfo['DS']);
-        while (list($k, $v) = each($rrdinfo['DS'])) {
+        foreach ($rrdinfo['DS'] as $k => $v) {
             $graph[] = sprintf('LINE:%s_%s', $k, $has_min ? 'min' : 'avg');
             $graph[] = sprintf('CDEF:%s_var=%s_%s,%s_%s,-', $k, $k, $has_max ? 'max' : 'avg', $k, $has_min ? 'min' : 'avg');
             $graph[] = sprintf('AREA:%s_var#%s::STACK', $k, rrd_get_color($n++, false));
@@ -562,8 +557,8 @@ function collectd_draw_rrd($host, $plugin, $type, $pinst = null, $tinst = null,
 
     reset($rrdinfo['DS']);
     $n = 1;
-    while (list($k, $v) = each($rrdinfo['DS'])) {
-        $graph[] = sprintf('LINE1:%s_avg#%s:%s ', $k, rrd_get_color($n++, true), $k.substr('                  ', 0, ($l_max - strlen($k))));
+    foreach ($rrdinfo['DS'] as $k => $v) {
+        $graph[] = sprintf('LINE1:%s_avg#%s:%s ', $k, rrd_get_color($n++, true), $k . substr('                  ', 0, ($l_max - strlen($k))));
         if (isset($opts['tinylegend']) && $opts['tinylegend']) {
             continue;
         }
@@ -586,7 +581,7 @@ function collectd_draw_rrd($host, $plugin, $type, $pinst = null, $tinst = null,
     }//end while
 
     // $rrd_cmd = array(RRDTOOL, 'graph', '-', '-E', '-a', 'PNG', '-w', Config::get('rrd_width'), '-h', Config::get('rrd_height'), '-t', $rrdfile);
-    $rrd_cmd = array(
+    $rrd_cmd = [
         RRDTOOL,
         'graph',
         '-',
@@ -597,31 +592,30 @@ function collectd_draw_rrd($host, $plugin, $type, $pinst = null, $tinst = null,
         Config::get('rrd_width'),
         '-h',
         Config::get('rrd_height'),
-    );
+    ];
     if (Config::get('rrd_width') <= '300') {
-        $small_opts = array(
+        $small_opts = [
             '--font',
             'LEGEND:7:mono',
             '--font',
             'AXIS:6:mono',
             '--font-render-mode',
             'normal',
-        );
-        $rrd_cmd    = array_merge($rrd_cmd, $small_opts);
+        ];
+        $rrd_cmd = array_merge($rrd_cmd, $small_opts);
     }
 
     $rrd_cmd = array_merge($rrd_cmd, Config::get('rrd_opts_array'), $opts['rrd_opts'], $graph);
 
-    $cmd               = RRDTOOL;
+    $cmd = RRDTOOL;
     $count_rrd_cmd = count($rrd_cmd);
     for ($i = 1; $i < $count_rrd_cmd; $i++) {
-        $cmd .= ' '.escapeshellarg($rrd_cmd[$i]);
+        $cmd .= ' ' . escapeshellarg($rrd_cmd[$i]);
     }
 
     return $cmd;
 }//end collectd_draw_rrd()
 
-
 /**
  * Draw RRD file based on it's structure
  *
@@ -648,13 +642,13 @@ function collectd_draw_generic($timespan, $host, $plugin, $type, $pinst = null,
         $timespan_def = reset($timespans);
     }
 
-    if (!isset($GraphDefs[$type])) {
+    if (! isset($GraphDefs[$type])) {
         return false;
     }
 
     $rrd_file = sprintf('%s/%s%s%s/%s%s%s', $host, $plugin, is_null($pinst) ? '' : '-', $pinst, $type, is_null($tinst) ? '' : '-', $tinst);
     // $rrd_cmd  = array(RRDTOOL, 'graph', '-', '-E', '-a', 'PNG', '-w', Config::get('rrd_width'), '-h', Config::get('rrd_height'), '-t', $rrd_file);
-    $rrd_cmd = array(
+    $rrd_cmd = [
         RRDTOOL,
         'graph',
         '-',
@@ -665,37 +659,37 @@ function collectd_draw_generic($timespan, $host, $plugin, $type, $pinst = null,
         Config::get('rrd_width'),
         '-h',
         Config::get('rrd_height'),
-    );
+    ];
 
     if (Config::get('rrd_width') <= '300') {
-        $small_opts = array(
+        $small_opts = [
             '--font',
             'LEGEND:7:mono',
             '--font',
             'AXIS:6:mono',
             '--font-render-mode',
             'normal',
-        );
-        $rrd_cmd    = array_merge($rrd_cmd, $small_opts);
+        ];
+        $rrd_cmd = array_merge($rrd_cmd, $small_opts);
     }
 
     $rrd_cmd = array_merge($rrd_cmd, Config::get('rrd_opts_array'));
     $rrd_args = $GraphDefs[$type];
 
     foreach (Config::get('datadirs') as $datadir) {
-        $file = $datadir.'/'.$rrd_file.'.rrd';
-        if (!is_file($file)) {
+        $file = $datadir . '/' . $rrd_file . '.rrd';
+        if (! is_file($file)) {
             continue;
         }
 
-        $file     = str_replace(':', '\\:', $file);
+        $file = str_replace(':', '\\:', $file);
         $rrd_args = str_replace('{file}', $file, $rrd_args);
 
-        $rrdgraph           = array_merge($rrd_cmd, $rrd_args);
-        $cmd                = RRDTOOL;
+        $rrdgraph = array_merge($rrd_cmd, $rrd_args);
+        $cmd = RRDTOOL;
         $count_rrdgraph = count($rrdgraph);
         for ($i = 1; $i < $count_rrdgraph; $i++) {
-            $cmd .= ' '.escapeshellarg($rrdgraph[$i]);
+            $cmd .= ' ' . escapeshellarg($rrdgraph[$i]);
         }
 
         return $cmd;
@@ -704,7 +698,6 @@ function collectd_draw_generic($timespan, $host, $plugin, $type, $pinst = null,
     return false;
 }//end collectd_draw_generic()
 
-
 /**
  * Draw stack-graph for set of RRD files
  * @param array $opts Graph options like colors
@@ -715,7 +708,7 @@ function collectd_draw_meta_stack(&$opts, &$sources)
 {
     $timespan_def = null;
     $timespans = Config::get('timespan');
-    if (!isset($opts['timespan'])) {
+    if (! isset($opts['timespan'])) {
         $timespan_def = reset($timespans);
     } else {
         foreach ($timespans as &$ts) {
@@ -725,16 +718,16 @@ function collectd_draw_meta_stack(&$opts, &$sources)
         }
     }
 
-    if (!isset($opts['title'])) {
+    if (! isset($opts['title'])) {
         $opts['title'] = 'Unknown title';
     }
 
-    if (!isset($opts['rrd_opts'])) {
-        $opts['rrd_opts'] = array();
+    if (! isset($opts['rrd_opts'])) {
+        $opts['rrd_opts'] = [];
     }
 
-    if (!isset($opts['colors'])) {
-        $opts['colors'] = array();
+    if (! isset($opts['colors'])) {
+        $opts['colors'] = [];
     }
 
     if (isset($opts['logarithmic']) && $opts['logarithmic']) {
@@ -743,7 +736,7 @@ function collectd_draw_meta_stack(&$opts, &$sources)
 
     // $cmd = array(RRDTOOL, 'graph', '-', '-E', '-a', 'PNG', '-w', Config::get('rrd_width'), '-h', Config::get('rrd_height'),
     // '-t', $opts['title']);
-    $cmd = array(
+    $cmd = [
         RRDTOOL,
         'graph',
         '-',
@@ -754,18 +747,18 @@ function collectd_draw_meta_stack(&$opts, &$sources)
         Config::get('rrd_width'),
         '-h',
         Config::get('rrd_height'),
-    );
+    ];
 
     if (Config::get('rrd_width') <= '300') {
-        $small_opts = array(
+        $small_opts = [
             '--font',
             'LEGEND:7:mono',
             '--font',
             'AXIS:6:mono',
             '--font-render-mode',
             'normal',
-        );
-        $cmd        = array_merge($cmd, $small_opts);
+        ];
+        $cmd = array_merge($cmd, $small_opts);
     }
 
     $cmd = array_merge($cmd, Config::get('rrd_opts_array'), $opts['rrd_opts']);
@@ -773,33 +766,33 @@ function collectd_draw_meta_stack(&$opts, &$sources)
 
     foreach ($sources as &$inst_data) {
         $inst_name = $inst_data['name'];
-        $file      = $inst_data['file'];
-        $ds        = isset($inst_data['ds']) ? $inst_data['ds'] : 'value';
+        $file = $inst_data['file'];
+        $ds = isset($inst_data['ds']) ? $inst_data['ds'] : 'value';
 
         if (strlen($inst_name) > $max_inst_name) {
             $max_inst_name = strlen($inst_name);
         }
 
-        if (!is_file($file)) {
+        if (! is_file($file)) {
             continue;
         }
 
-        $cmd[] = 'DEF:'.$inst_name.'_min='.$file.':'.$ds.':MIN';
-        $cmd[] = 'DEF:'.$inst_name.'_avg='.$file.':'.$ds.':AVERAGE';
-        $cmd[] = 'DEF:'.$inst_name.'_max='.$file.':'.$ds.':MAX';
-        $cmd[] = 'CDEF:'.$inst_name.'_nnl='.$inst_name.'_avg,UN,0,'.$inst_name.'_avg,IF';
+        $cmd[] = 'DEF:' . $inst_name . '_min=' . $file . ':' . $ds . ':MIN';
+        $cmd[] = 'DEF:' . $inst_name . '_avg=' . $file . ':' . $ds . ':AVERAGE';
+        $cmd[] = 'DEF:' . $inst_name . '_max=' . $file . ':' . $ds . ':MAX';
+        $cmd[] = 'CDEF:' . $inst_name . '_nnl=' . $inst_name . '_avg,UN,0,' . $inst_name . '_avg,IF';
     }
 
     $inst_data = end($sources);
     $inst_name = $inst_data['name'];
-    $cmd[]     = 'CDEF:'.$inst_name.'_stk='.$inst_name.'_nnl';
+    $cmd[] = 'CDEF:' . $inst_name . '_stk=' . $inst_name . '_nnl';
 
     $inst_data1 = end($sources);
     while (($inst_data0 = prev($sources)) !== false) {
         $inst_name0 = $inst_data0['name'];
         $inst_name1 = $inst_data1['name'];
 
-        $cmd[]      = 'CDEF:'.$inst_name0.'_stk='.$inst_name0.'_nnl,'.$inst_name1.'_stk,+';
+        $cmd[] = 'CDEF:' . $inst_name0 . '_stk=' . $inst_name0 . '_nnl,' . $inst_name1 . '_stk,+';
         $inst_data1 = $inst_data0;
     }
 
@@ -822,26 +815,25 @@ function collectd_draw_meta_stack(&$opts, &$sources)
         $area_color = new CollectdColor($line_color);
         $area_color->fade();
 
-        $cmd[] = 'AREA:'.$inst_name.'_stk#'.$area_color->toString();
-        $cmd[] = 'LINE1:'.$inst_name.'_stk#'.$line_color->toString().':'.$legend;
-        if (!(isset($opts['tinylegend']) && $opts['tinylegend'])) {
-            $cmd[]             = 'GPRINT:'.$inst_name.'_avg:LAST:'.$number_format.'';
-            $cmd[] = 'GPRINT:'.$inst_name.'_avg:AVERAGE:'.$number_format.'';
-            $cmd[]             = 'GPRINT:'.$inst_name.'_min:MIN:'.$number_format.'';
-            $cmd[]             = 'GPRINT:'.$inst_name.'_max:MAX:'.$number_format.'\\l';
+        $cmd[] = 'AREA:' . $inst_name . '_stk#' . $area_color->toString();
+        $cmd[] = 'LINE1:' . $inst_name . '_stk#' . $line_color->toString() . ':' . $legend;
+        if (! (isset($opts['tinylegend']) && $opts['tinylegend'])) {
+            $cmd[] = 'GPRINT:' . $inst_name . '_avg:LAST:' . $number_format . '';
+            $cmd[] = 'GPRINT:' . $inst_name . '_avg:AVERAGE:' . $number_format . '';
+            $cmd[] = 'GPRINT:' . $inst_name . '_min:MIN:' . $number_format . '';
+            $cmd[] = 'GPRINT:' . $inst_name . '_max:MAX:' . $number_format . '\\l';
         }
     }//end foreach
 
-    $rrdcmd        = RRDTOOL;
+    $rrdcmd = RRDTOOL;
     $count_cmd = count($cmd);
     for ($i = 1; $i < $count_cmd; $i++) {
-        $rrdcmd .= ' '.escapeshellarg($cmd[$i]);
+        $rrdcmd .= ' ' . escapeshellarg($cmd[$i]);
     }
 
     return $rrdcmd;
 }//end collectd_draw_meta_stack()
 
-
 /**
  * Draw stack-graph for set of RRD files
  * @param array $opts Graph options like colors
@@ -852,7 +844,7 @@ function collectd_draw_meta_line(&$opts, &$sources)
 {
     $timespan_def = null;
     $timespans = Config::get('timespan');
-    if (!isset($opts['timespan'])) {
+    if (! isset($opts['timespan'])) {
         $timespan_def = reset($timespans);
     } else {
         foreach ($timespans as &$ts) {
@@ -862,16 +854,16 @@ function collectd_draw_meta_line(&$opts, &$sources)
         }
     }
 
-    if (!isset($opts['title'])) {
+    if (! isset($opts['title'])) {
         $opts['title'] = 'Unknown title';
     }
 
-    if (!isset($opts['rrd_opts'])) {
-        $opts['rrd_opts'] = array();
+    if (! isset($opts['rrd_opts'])) {
+        $opts['rrd_opts'] = [];
     }
 
-    if (!isset($opts['colors'])) {
-        $opts['colors'] = array();
+    if (! isset($opts['colors'])) {
+        $opts['colors'] = [];
     }
 
     if (isset($opts['logarithmic']) && $opts['logarithmic']) {
@@ -880,7 +872,7 @@ function collectd_draw_meta_line(&$opts, &$sources)
 
     // $cmd = array(RRDTOOL, 'graph', '-', '-E', '-a', 'PNG', '-w', Config::get('rrd_width'), '-h', Config::get('rrd_height'), '-t', $opts['title']);
     // $cmd = array_merge($cmd, Config::get('rrd_opts_array'), $opts['rrd_opts']);
-    $cmd = array(
+    $cmd = [
         RRDTOOL,
         'graph',
         '-',
@@ -891,43 +883,43 @@ function collectd_draw_meta_line(&$opts, &$sources)
         Config::get('rrd_width'),
         '-h',
         Config::get('rrd_height'),
-    );
+    ];
 
     if (Config::get('rrd_width') <= '300') {
-        $small_opts = array(
+        $small_opts = [
             '--font',
             'LEGEND:7:mono',
             '--font',
             'AXIS:6:mono',
             '--font-render-mode',
             'normal',
-        );
-        $cmd        = array_merge($cmd, $small_opts);
+        ];
+        $cmd = array_merge($cmd, $small_opts);
     }
 
     $max_inst_name = 0;
 
     foreach ($sources as &$inst_data) {
         $inst_name = $inst_data['name'];
-        $file      = $inst_data['file'];
-        $ds        = isset($inst_data['ds']) ? $inst_data['ds'] : 'value';
+        $file = $inst_data['file'];
+        $ds = isset($inst_data['ds']) ? $inst_data['ds'] : 'value';
 
         if (strlen($inst_name) > $max_inst_name) {
             $max_inst_name = strlen($inst_name);
         }
 
-        if (!is_file($file)) {
+        if (! is_file($file)) {
             continue;
         }
 
-        $cmd[] = 'DEF:'.$inst_name.'_min='.$file.':'.$ds.':MIN';
-        $cmd[] = 'DEF:'.$inst_name.'_avg='.$file.':'.$ds.':AVERAGE';
-        $cmd[] = 'DEF:'.$inst_name.'_max='.$file.':'.$ds.':MAX';
+        $cmd[] = 'DEF:' . $inst_name . '_min=' . $file . ':' . $ds . ':MIN';
+        $cmd[] = 'DEF:' . $inst_name . '_avg=' . $file . ':' . $ds . ':AVERAGE';
+        $cmd[] = 'DEF:' . $inst_name . '_max=' . $file . ':' . $ds . ':MAX';
     }
 
     foreach ($sources as &$inst_data) {
         $inst_name = $inst_data['name'];
-        $legend    = sprintf('%s', $inst_name);
+        $legend = sprintf('%s', $inst_name);
         while (strlen($legend) < $max_inst_name) {
             $legend .= ' ';
         }
@@ -940,19 +932,19 @@ function collectd_draw_meta_line(&$opts, &$sources)
             $line_color = new CollectdColor('random');
         }
 
-        $cmd[] = 'LINE1:'.$inst_name.'_avg#'.$line_color->toString().':'.$legend;
-        if (!(isset($opts['tinylegend']) && $opts['tinylegend'])) {
-            $cmd[] = 'GPRINT:'.$inst_name.'_min:MIN:'.$number_format.'';
-            $cmd[] = 'GPRINT:'.$inst_name.'_avg:AVERAGE:'.$number_format.'';
-            $cmd[] = 'GPRINT:'.$inst_name.'_max:MAX:'.$number_format.'';
-            $cmd[] = 'GPRINT:'.$inst_name.'_avg:LAST:'.$number_format.'\\l';
+        $cmd[] = 'LINE1:' . $inst_name . '_avg#' . $line_color->toString() . ':' . $legend;
+        if (! (isset($opts['tinylegend']) && $opts['tinylegend'])) {
+            $cmd[] = 'GPRINT:' . $inst_name . '_min:MIN:' . $number_format . '';
+            $cmd[] = 'GPRINT:' . $inst_name . '_avg:AVERAGE:' . $number_format . '';
+            $cmd[] = 'GPRINT:' . $inst_name . '_max:MAX:' . $number_format . '';
+            $cmd[] = 'GPRINT:' . $inst_name . '_avg:LAST:' . $number_format . '\\l';
         }
     }//end foreach
 
-    $rrdcmd        = RRDTOOL;
+    $rrdcmd = RRDTOOL;
     $count_cmd = count($cmd);
     for ($i = 1; $i < $count_cmd; $i++) {
-        $rrdcmd .= ' '.escapeshellarg($cmd[$i]);
+        $rrdcmd .= ' ' . escapeshellarg($cmd[$i]);
     }
 
     return $rrdcmd;
