@@ -20,11 +20,11 @@ if (isset($settings['mode_select']) && $settings['mode_select'] !== '') {
     $mode = $settings['mode_select'];
 }
 
-$select_modes = array(
+$select_modes = [
     '0' => 'only devices',
     '1' => 'only services',
     '2' => 'devices and services',
-);
+];
 
 if (Config::get('webui.availability_map_compact') == 1) {
     $compact_tile = $settings['tile_size'];
@@ -41,7 +41,7 @@ if (defined('SHOW_SETTINGS')) {
                 <label for="title" class="control-label availability-map-widget-header">Widget title</label>
             </div>
             <div class="col-sm-6">
-                <input type="text" class="form-control" name="title" placeholder="Custom title for widget" value="'.htmlspecialchars($settings['title']).'">
+                <input type="text" class="form-control" name="title" placeholder="Custom title for widget" value="' . htmlspecialchars($settings['title']) . '">
             </div>
         </div>';
 
@@ -53,8 +53,8 @@ if (defined('SHOW_SETTINGS')) {
         </div>
         <div class="col-sm-6">
             <select class="form-control" name="color_only_select">
-                <option value="1"' . ($settings['color_only_select'] == 1 ? ' selected' : '')  . ' >yes</option>
-                <option value="0"' . ($settings['color_only_select'] == 1 ? '' : ' selected')  . ' >no</option>
+                <option value="1"' . ($settings['color_only_select'] == 1 ? ' selected' : '') . ' >yes</option>
+                <option value="0"' . ($settings['color_only_select'] == 1 ? '' : ' selected') . ' >no</option>
             </select>
         </div>
     </div>
@@ -68,7 +68,7 @@ if (defined('SHOW_SETTINGS')) {
                 <label for="tile_size" class="control-label availability-map-widget-header">Tile size</label>
             </div>
             <div class="col-sm-6">
-                <input type="text" class="form-control" name="tile_size" value="'.$compact_tile.'">
+                <input type="text" class="form-control" name="tile_size" value="' . $compact_tile . '">
             </div>
         </div>';
     }
@@ -88,8 +88,8 @@ if (defined('SHOW_SETTINGS')) {
         </div>
         <div class="col-sm-6">
             <select class="form-control" name="show_disabled_and_ignored">
-                <option value="1" '.$selected_yes.'>yes</option>
-                <option value="0" '.$selected_no.'>no</option>
+                <option value="1" ' . $selected_yes . '>yes</option>
+                <option value="0" ' . $selected_no . '>no</option>
             </select>
         </div>
     </div>';
@@ -106,7 +106,7 @@ if (defined('SHOW_SETTINGS')) {
         $common_output[] = '<option value="0" selected>only devices</option>';
     } else {
         foreach ($select_modes as $mode_select => $option) {
-            if ($mode_select == $settings["mode_select"]) {
+            if ($mode_select == $settings['mode_select']) {
                 $selected = 'selected';
             } else {
                 $selected = '';
@@ -126,13 +126,12 @@ if (defined('SHOW_SETTINGS')) {
                 <label for="tile_size" class="control-label availability-map-widget-header">Tile width</label>
             </div>
             <div class="col-sm-6">
-                <input class="form-control" type="text" onkeypress="return (event.charCode == 8 || event.charCode == 0) ? null : event.charCode >= 48 && event.charCode <= 57" name="tile_size" placeholder="Tile side in px" value="'.$compact_tile.'">
+                <input class="form-control" type="text" onkeypress="return (event.charCode == 8 || event.charCode == 0) ? null : event.charCode >= 48 && event.charCode <= 57" name="tile_size" placeholder="Tile side in px" value="' . $compact_tile . '">
             </div>
         </div>
         ';
     }
 
-
     $common_output[] = '
         <br style="clear:both;">
         <div class="form-group">
@@ -173,7 +172,7 @@ if (defined('SHOW_SETTINGS')) {
 
         $sql = 'SELECT `D`.`hostname`, `D`.`sysName`, `D`.`device_id`, `D`.`status`, `D`.`uptime`, `D`.`last_polled`, `D`.`os`, `D`.`icon`, `D`.`disable_notify`, `D`.`disabled` FROM `devices` AS `D`';
 
-        if (!Auth::user()->hasGlobalRead()) {
+        if (! Auth::user()->hasGlobalRead()) {
             $sql .= ' , `devices_perms` AS P WHERE D.`device_id` = P.`device_id` AND P.`user_id` = ? AND ';
             $param = [Auth::id()];
         } else {
@@ -187,24 +186,24 @@ if (defined('SHOW_SETTINGS')) {
             $sql .= '(`D`.`status` IN (0,1,2) OR `D`.`disable_notify` = 1 OR `D`.`disabled` = 1)';
         }
 
-        if (Config::get('webui.availability_map_use_device_groups') != 0 && !empty($in_devices)) {
-            $sql .= " AND `D`.`device_id` IN " . dbGenPlaceholders(count($in_devices));
+        if (Config::get('webui.availability_map_use_device_groups') != 0 && ! empty($in_devices)) {
+            $sql .= ' AND `D`.`device_id` IN ' . dbGenPlaceholders(count($in_devices));
             $param = array_merge($param, $in_devices);
         }
 
-        $sql .= " ORDER BY `".$deviceOrderBy."`";
+        $sql .= ' ORDER BY `' . $deviceOrderBy . '`';
 
-        $temp_output = array();
+        $temp_output = [];
 
         foreach (dbFetchRows($sql, $param) as $device) {
-            $updowntime = "";
+            $updowntime = '';
             if ($device['disabled'] == '1') {
-                $deviceState = "disabled";
-                $deviceLabel = "blackbg";
+                $deviceState = 'disabled';
+                $deviceLabel = 'blackbg';
                 $host_disabled_count++;
             } elseif ($device['disable_notify'] == '1') {
-                $deviceState = "alert-disabled";
-                $deviceLabel = "label-default";
+                $deviceState = 'alert-disabled';
+                $deviceLabel = 'label-default';
                 $host_disable_notify_count++;
             } elseif ($device['status'] == '1') {
                 if (($device['uptime'] < Config::get('uptime_warning')) && ($device['uptime'] != 0)) {
@@ -218,13 +217,13 @@ if (defined('SHOW_SETTINGS')) {
                     $deviceLabelOld = 'availability-map-oldview-box-up';
                     $host_up_count++;
                 }
-                $updowntime = ($device['uptime'] ? " - " : "") . formatUptime($device['uptime']);
+                $updowntime = ($device['uptime'] ? ' - ' : '') . formatUptime($device['uptime']);
             } else {
                 $deviceState = 'down';
                 $deviceLabel = 'label-danger';
                 $deviceLabelOld = 'availability-map-oldview-box-down';
                 $host_down_count++;
-                $updowntime = ($device['last_polled'] ? " - " . formatUptime(time() - strtotime($device['last_polled'])) : "") ;
+                $updowntime = ($device['last_polled'] ? ' - ' . formatUptime(time() - strtotime($device['last_polled'])) : '');
             }
 
             if (AlertUtil::isMaintenance($device['device_id'])) {
@@ -235,10 +234,10 @@ if (defined('SHOW_SETTINGS')) {
             $device_system_name = format_hostname($device);
 
             if (Config::get('webui.availability_map_compact') == 0) {
-                if ($directpage == "yes") {
+                if ($directpage == 'yes') {
                     $deviceIcon = getIconTag($device);
                     $temp_output[] = '
-                    <a href="' .generate_device_url($device). '" title="' . $device_system_name . $updowntime . '">
+                    <a href="' . generate_device_url($device) . '" title="' . $device_system_name . $updowntime . '">
                     <div class="device-availability ' . $deviceState . '" style="width:' . Config::get('webui.availability_map_box_size') . 'px;">
                         <span class="availability-label label ' . $deviceLabel . ' label-font-border">' . $deviceState . '</span>
                         <span class="device-icon">' . $deviceIcon . '</span><br>
@@ -251,7 +250,7 @@ if (defined('SHOW_SETTINGS')) {
                         $deviceLabel .= ' widget-availability-fixed';
                     }
                     $temp_output[] = '
-                    <a href="' .generate_device_url($device). '" title="' . $device_system_name . $updowntime . '">
+                    <a href="' . generate_device_url($device) . '" title="' . $device_system_name . $updowntime . '">
                         <span class="label ' . $deviceLabel . ' widget-availability label-font-border">' . $deviceState . '</span>
                     </a>';
                 }
@@ -263,40 +262,40 @@ if (defined('SHOW_SETTINGS')) {
 
     if (($mode == 1 || $mode == 2) && (Config::get('show_services') != 0)) {
         if (Auth::user()->hasGlobalRead()) {
-            $service_query = 'select `S`.`service_type`, `S`.`service_id`, `S`.`service_desc`, `S`.`service_status`, `D`.`hostname`, `D`.`sysName`, `D`.`device_id`, `D`.`os`, `D`.`icon` from services S, devices D where `S`.`device_id` = `D`.`device_id` ORDER BY '.$serviceOrderBy.';';
-            $service_par = array();
+            $service_query = 'select `S`.`service_type`, `S`.`service_id`, `S`.`service_desc`, `S`.`service_status`, `D`.`hostname`, `D`.`sysName`, `D`.`device_id`, `D`.`os`, `D`.`icon` from services S, devices D where `S`.`device_id` = `D`.`device_id` ORDER BY ' . $serviceOrderBy . ';';
+            $service_par = [];
         } else {
-            $service_query = 'select `S`.`service_type`, `S`.`service_id`, `S`.`service_desc`, `S`.`service_status`, `D`.`hostname`, `D`.`sysName`, `D`.`device_id`, `D`.`os`, `D`.`icon` from services S, devices D, devices_perms P where `S`.`device_id` = `D`.`device_id` AND D.device_id = P.device_id AND P.user_id = ? ORDER BY '.$serviceOrderBy.';';
-            $service_par = array(Auth::id());
+            $service_query = 'select `S`.`service_type`, `S`.`service_id`, `S`.`service_desc`, `S`.`service_status`, `D`.`hostname`, `D`.`sysName`, `D`.`device_id`, `D`.`os`, `D`.`icon` from services S, devices D, devices_perms P where `S`.`device_id` = `D`.`device_id` AND D.device_id = P.device_id AND P.user_id = ? ORDER BY ' . $serviceOrderBy . ';';
+            $service_par = [Auth::id()];
         }
         $services = dbFetchRows($service_query, $service_par);
         if (count($services) > 0) {
             foreach ($services as $service) {
                 if ($service['service_status'] == '0') {
-                    $serviceLabel = "label-success";
+                    $serviceLabel = 'label-success';
                     $serviceLabelOld = 'availability-map-oldview-box-up';
-                    $serviceState = "up";
+                    $serviceState = 'up';
                     $service_up_count++;
                 } elseif ($service['service_status'] == '1') {
-                    $serviceLabel = "label-warning";
+                    $serviceLabel = 'label-warning';
                     $serviceLabelOld = 'availability-map-oldview-box-warn';
-                    $serviceState = "warn";
+                    $serviceState = 'warn';
                     $service_warn_count++;
                 } else {
-                    $serviceLabel = "label-danger";
+                    $serviceLabel = 'label-danger';
                     $serviceLabelOld = 'availability-map-oldview-box-down';
-                    $serviceState = "down";
+                    $serviceState = 'down';
                     $service_down_count++;
                 }
                 $service_system_name = format_hostname($service);
 
                 if (Config::get('webui.availability_map_compact') == 0) {
-                    if ($directpage == "yes") {
+                    if ($directpage == 'yes') {
                         $deviceIcon = getIconTag($service);
                         $temp_output[] = '
-                        <a href="' . generate_url(array('page' => 'device', 'tab' => 'services', 'device' => $service['device_id'])) . '" title="' . $service_system_name . " - " . $service['service_type'] . " - " . $service['service_desc'] . '">
+                        <a href="' . generate_url(['page' => 'device', 'tab' => 'services', 'device' => $service['device_id']]) . '" title="' . $service_system_name . ' - ' . $service['service_type'] . ' - ' . $service['service_desc'] . '">
                             <div class="service-availability ' . $serviceState . '" style="width:' . Config::get('webui.availability_map_box_size') . 'px;">
-                                <span class="service-name-label label ' . $serviceLabel . ' label-font-border">' . $service["service_type"] . '</span>
+                                <span class="service-name-label label ' . $serviceLabel . ' label-font-border">' . $service['service_type'] . '</span>
                                 <span class="availability-label label ' . $serviceLabel . ' label-font-border">' . $serviceState . '</span>
                                 <span class="device-icon">' . $deviceIcon . '</span><br>
                                 <span class="small">' . shorthost($service_system_name) . '</span>
@@ -309,20 +308,20 @@ if (defined('SHOW_SETTINGS')) {
                             $serviceLabel .= ' widget-availability-fixed';
                         }
                         $temp_output[] = '
-                        <a href="' . generate_url(array('page' => 'device', 'tab' => 'services', 'device' => $service['device_id'])) . '" title="' . shorthost($service_system_name) . " - " . $service['service_type'] . " - " . $service['service_desc'] . '">
+                        <a href="' . generate_url(['page' => 'device', 'tab' => 'services', 'device' => $service['device_id']]) . '" title="' . shorthost($service_system_name) . ' - ' . $service['service_type'] . ' - ' . $service['service_desc'] . '">
                             <span class="label ' . $serviceLabel . ' widget-availability label-font-border">' . $serviceText . '</span>
                         </a>';
                     }
                 } else {
-                    $temp_output[] = "<a href='" . generate_url(array('page' => 'device', 'tab' => 'services', 'device' => $service['device_id'])) . "' title='${service_system_name} - ${service['service_type']} - ${service['service_desc']}'><div class='" . $serviceLabelOld . "' style='width:${compact_tile}px;height:${compact_tile}px;'></div></a>";
+                    $temp_output[] = "<a href='" . generate_url(['page' => 'device', 'tab' => 'services', 'device' => $service['device_id']]) . "' title='${service_system_name} - ${service['service_type']} - ${service['service_desc']}'><div class='" . $serviceLabelOld . "' style='width:${compact_tile}px;height:${compact_tile}px;'></div></a>";
                 }
             }
         } else {
-            $temp_output [] = '';
+            $temp_output[] = '';
         }
     }
 
-    if ($directpage == "yes") {
+    if ($directpage == 'yes') {
         $temp_header[] = '
         <div class="page-availability-title-left">
             <span class="page-availability-title">Availability map for</span>
@@ -373,7 +372,7 @@ if (defined('SHOW_SETTINGS')) {
         }
     }
 
-    if ($directpage == "yes") {
+    if ($directpage == 'yes') {
         $deviceClass = 'page-availability-report-host';
         $serviceClass = 'page-availability-report-host';
     } else {
@@ -383,21 +382,21 @@ if (defined('SHOW_SETTINGS')) {
 
     if ($show_disabled_ignored == 1) {
         $disabled_ignored_header = '
-            <span class="label label-default label-font-border label-border">alert-disabled: '.$host_disable_notify_count.'</span>
-            <span class="label blackbg label-font-border label-border">disabled: '.$host_disabled_count.'</span>';
+            <span class="label label-default label-font-border label-border">alert-disabled: ' . $host_disable_notify_count . '</span>
+            <span class="label blackbg label-font-border label-border">disabled: ' . $host_disabled_count . '</span>';
     }
 
     if ($mode == 0 || $mode == 2) {
         $temp_header[] = '
             <div class="' . $deviceClass . '">
                 <span>Total hosts</span>
-                <span class="label label-success label-font-border label-border">up: '.$host_up_count.'</span>
-                <span class="label label-warning label-font-border label-border">warn: '.$host_warn_count.'</span>
-                <span class="label label-danger label-font-border label-border">down: '.$host_down_count.'</span>';
+                <span class="label label-success label-font-border label-border">up: ' . $host_up_count . '</span>
+                <span class="label label-warning label-font-border label-border">warn: ' . $host_warn_count . '</span>
+                <span class="label label-danger label-font-border label-border">down: ' . $host_down_count . '</span>';
         if ($host_maintenance_count) {
-            $temp_header[] = '<span class="label label-default label-font-border label-border">maintenance: '.$host_maintenance_count.'</span>';
+            $temp_header[] = '<span class="label label-default label-font-border label-border">maintenance: ' . $host_maintenance_count . '</span>';
         }
-        $temp_header[] = $disabled_ignored_header.'
+        $temp_header[] = $disabled_ignored_header . '
             </div>';
     }
 
@@ -405,9 +404,9 @@ if (defined('SHOW_SETTINGS')) {
         $temp_header[] = '
             <div class="' . $serviceClass . '">
                 <span>Total services</span>
-                <span class="label label-success label-font-border label-border">up: '.$service_up_count.'</span>
-                <span class="label label-warning label-font-border label-border">warn: '.$service_warn_count.'</span>
-                <span class="label label-danger label-font-border label-border">down: '.$service_down_count.'</span>
+                <span class="label label-success label-font-border label-border">up: ' . $service_up_count . '</span>
+                <span class="label label-warning label-font-border label-border">warn: ' . $service_warn_count . '</span>
+                <span class="label label-danger label-font-border label-border">down: ' . $service_down_count . '</span>
             </div>';
     }
 
