@@ -54,9 +54,9 @@ if ($vars['stream']) {
 }
 $tmp_output .= '"</select>&nbsp;</div>"+';
 
-if (!empty($filter_device)) {
+if (! empty($filter_device)) {
     $tmp_output .= '
-            "<input type=\"hidden\" name=\"device\" id=\"device\" value=\"'. $filter_device .'\">"+
+            "<input type=\"hidden\" name=\"device\" id=\"device\" value=\"' . $filter_device . '\">"+
 ';
 } else {
     $tmp_output .= '
@@ -83,14 +83,14 @@ $tmp_output .= '
                 "<div class=\"form-group\">"+
                 "<select name=\"loglevel\" id=\"loglevel\" class=\"form-control\">"+
                 "<option value=\"\" disabled selected>Log Level</option>"+
-                "<option value=\"0\">'.("(0) " . __("syslog.severity.0")).'</option>"+
-                "<option value=\"1\">'.("(1) " . __("syslog.severity.1")).'</option>"+
-                "<option value=\"2\">'.("(2) " . __("syslog.severity.2")).'</option>"+
-                "<option value=\"3\">'.("(3) " . __("syslog.severity.3")).'</option>"+
-                "<option value=\"4\">'.("(4) " . __("syslog.severity.4")).'</option>"+
-                "<option value=\"5\">'.("(5) " . __("syslog.severity.5")).'</option>"+
-                "<option value=\"6\">'.("(6) " . __("syslog.severity.6")).'</option>"+
-                "<option value=\"7\">'.("(7) " . __("syslog.severity.7")).'</option>"+
+                "<option value=\"0\">' . ('(0) ' . __('syslog.severity.0')) . '</option>"+
+                "<option value=\"1\">' . ('(1) ' . __('syslog.severity.1')) . '</option>"+
+                "<option value=\"2\">' . ('(2) ' . __('syslog.severity.2')) . '</option>"+
+                "<option value=\"3\">' . ('(3) ' . __('syslog.severity.3')) . '</option>"+
+                "<option value=\"4\">' . ('(4) ' . __('syslog.severity.4')) . '</option>"+
+                "<option value=\"5\">' . ('(5) ' . __('syslog.severity.5')) . '</option>"+
+                "<option value=\"6\">' . ('(6) ' . __('syslog.severity.6')) . '</option>"+
+                "<option value=\"7\">' . ('(7) ' . __('syslog.severity.7')) . '</option>"+
                 "</select>&nbsp;</div>"+
                 "<div class=\"form-group\"><select name=\"range\" class=\"form-control\">"+
                 "<option value=\"0\">Search all time</option>"+
@@ -113,15 +113,15 @@ $tmp_output .= '
 
     var graylog_grid = $("#graylog").bootgrid({
         ajax: true,
-        rowCount: ['. $results_limit .', 25,50,100,250,-1],
+        rowCount: [' . $results_limit . ', 25,50,100,250,-1],
         formatters: {
             "browserTime": function(column, row) {
-                return '.$timezone.'
+                return ' . $timezone . '
             }
         },
 ';
 
-if (!isset($no_form) && $no_form !== true) {
+if (! isset($no_form) && $no_form !== true) {
     $tmp_output .= '
         templates: {
             header: searchbar
@@ -135,8 +135,8 @@ $tmp_output .= '
             return {
                 stream: "' . (isset($_POST['stream']) ? mres($_POST['stream']) : '') . '",
                 device: "' . (isset($filter_device) ? $filter_device : '') . '",
-                range: "' . (isset($_POST['range']) ? mres($_POST['range']) : '')  . '",
-                loglevel: "' . (isset($_POST['loglevel']) ? mres($_POST['loglevel']) : '')  . '",
+                range: "' . (isset($_POST['range']) ? mres($_POST['range']) : '') . '",
+                loglevel: "' . (isset($_POST['loglevel']) ? mres($_POST['loglevel']) : '') . '",
             };
         },
         url: "' . url('/ajax/table/graylog') . '",
