@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2018 Vivia Nguyen-Tran
  * @author     Vivia Nguyen-Tran <vivia@ualberta.ca>
@@ -31,20 +30,20 @@ use Illuminate\Validation\Factory;
 
 header('Content-type: application/json');
 
-if (!Auth::user()->hasGlobalAdmin()) {
-    die(json_encode([
+if (! Auth::user()->hasGlobalAdmin()) {
+    exit(json_encode([
         'status' => 'error',
-        'message' => 'You need to be admin'
+        'message' => 'You need to be admin',
     ]));
 }
 
 $status = 'ok';
 $message = '';
 
-$transport_id        = $vars['transport_id'];
-$name                = $vars['name'];
-$is_default          = (int)(isset($vars['is_default']) && $vars['is_default'] == 'on');
-$transport_type      = $vars['transport-type'];
+$transport_id = $vars['transport_id'];
+$name = $vars['name'];
+$is_default = (int) (isset($vars['is_default']) && $vars['is_default'] == 'on');
+$transport_type = $vars['transport-type'];
 
 if (empty($name)) {
     $status = 'error';
@@ -53,10 +52,10 @@ if (empty($name)) {
     $status = 'error';
     $message = 'Missing transport information';
 } else {
-    $details = array(
+    $details = [
         'transport_name' => $name,
-        'is_default' => $is_default
-    );
+        'is_default' => $is_default,
+    ];
 
     if (is_numeric($transport_id) && $transport_id > 0) {
         // Update the fields -- json config field will be updated later
@@ -68,17 +67,17 @@ if (empty($name)) {
     }
 
     if ($transport_id) {
-        $class = 'LibreNMS\\Alert\\Transport\\'.ucfirst($transport_type);
+        $class = 'LibreNMS\\Alert\\Transport\\' . ucfirst($transport_type);
 
-        if (!method_exists($class, 'configTemplate')) {
-            die(json_encode([
+        if (! method_exists($class, 'configTemplate')) {
+            exit(json_encode([
                 'status' => 'error',
-                'message' => 'This transport type is not yet supported'
+                'message' => 'This transport type is not yet supported',
             ]));
         }
-        
+
         // Build config values
-        $result = call_user_func_array($class.'::configTemplate', []);
+        $result = call_user_func_array($class . '::configTemplate', []);
         $loader = new FileLoader(new Filesystem, "$install_dir/resources/lang");
         $translator = new Translator($loader, 'en');
         $validation = new Factory($translator, new Container);
@@ -90,7 +89,7 @@ if (empty($name)) {
             }
             $status = 'error';
         } else {
-            $transport_config = (array)json_decode(dbFetchCell('SELECT transport_config FROM alert_transports WHERE transport_id=?', [$transport_id]), true);
+            $transport_config = (array) json_decode(dbFetchCell('SELECT transport_config FROM alert_transports WHERE transport_id=?', [$transport_id]), true);
             foreach ($result['config'] as $tmp_config) {
                 if (isset($tmp_config['name']) && $tmp_config['type'] !== 'hidden') {
                     $transport_config[$tmp_config['name']] = $vars[$tmp_config['name']];
@@ -99,7 +98,7 @@ if (empty($name)) {
             //Update the json config field
             $detail = [
                 'transport_type' => $transport_type,
-                'transport_config' => json_encode($transport_config)
+                'transport_config' => json_encode($transport_config),
             ];
             $where = 'transport_id=?';
 
@@ -119,7 +118,7 @@ if (empty($name)) {
     }
 }
 
-die(json_encode([
+exit(json_encode([
     'status'       => $status,
-    'message'      => $message
+    'message'      => $message,
 ]));
