@@ -2,11 +2,11 @@
 
 header('Content-type: application/json');
 
-if (!Auth::user()->hasGlobalAdmin()) {
-    $response = array(
+if (! Auth::user()->hasGlobalAdmin()) {
+    $response = [
         'status'  => 'error',
         'message' => 'Need to be admin',
-    );
+    ];
     echo _json_encode($response);
     exit;
 }
@@ -14,36 +14,36 @@ if (!Auth::user()->hasGlobalAdmin()) {
 $status = 'ok';
 $message = '';
 
-$device_id      = $_POST['device_id'];
-$id             = $_POST['ccustomoid_id'];
-$action         = mres($_POST['action']);
-$name           = mres($_POST['name']);
-$oid            = mres($_POST['oid']);
-$datatype       = mres($_POST['datatype']);
+$device_id = $_POST['device_id'];
+$id = $_POST['ccustomoid_id'];
+$action = mres($_POST['action']);
+$name = mres($_POST['name']);
+$oid = mres($_POST['oid']);
+$datatype = mres($_POST['datatype']);
 if (empty(mres($_POST['unit']))) {
-    $unit           = array('NULL');
+    $unit = ['NULL'];
 } else {
-    $unit           = mres($_POST['unit']);
+    $unit = mres($_POST['unit']);
 }
-if (!empty(mres($_POST['limit'])) && is_numeric(mres($_POST['limit']))) {
-    $limit          = mres($_POST['limit']);
+if (! empty(mres($_POST['limit'])) && is_numeric(mres($_POST['limit']))) {
+    $limit = mres($_POST['limit']);
 } else {
-    $limit          = array('NULL');
+    $limit = ['NULL'];
 }
-if (!empty(mres($_POST['limit_warn'])) && is_numeric(mres($_POST['limit_warn']))) {
-    $limit_warn     = mres($_POST['limit_warn']);
+if (! empty(mres($_POST['limit_warn'])) && is_numeric(mres($_POST['limit_warn']))) {
+    $limit_warn = mres($_POST['limit_warn']);
 } else {
-    $limit_warn     = array('NULL');
+    $limit_warn = ['NULL'];
 }
-if (!empty(mres($_POST['limit_low'])) && is_numeric(mres($_POST['limit_low']))) {
-    $limit_low      = mres($_POST['limit_low']);
+if (! empty(mres($_POST['limit_low'])) && is_numeric(mres($_POST['limit_low']))) {
+    $limit_low = mres($_POST['limit_low']);
 } else {
-    $limit_low      = array('NULL');
+    $limit_low = ['NULL'];
 }
-if (!empty(mres($_POST['limit_low_warn'])) && is_numeric(mres($_POST['limit_low_warn']))) {
+if (! empty(mres($_POST['limit_low_warn'])) && is_numeric(mres($_POST['limit_low_warn']))) {
     $limit_low_warn = mres($_POST['limit_low_warn']);
 } else {
-    $limit_low_warn = array('NULL');
+    $limit_low_warn = ['NULL'];
 }
 if (mres($_POST['alerts']) == 'on') {
     $alerts = 1;
@@ -55,50 +55,50 @@ if (mres($_POST['passed']) == 'on') {
 } else {
     $passed = 0;
 }
-if (!empty(mres($_POST['divisor'])) && is_numeric(mres($_POST['divisor']))) {
-    $divisor        = mres($_POST['divisor']);
+if (! empty(mres($_POST['divisor'])) && is_numeric(mres($_POST['divisor']))) {
+    $divisor = mres($_POST['divisor']);
 } else {
-    $divisor        = 1;
+    $divisor = 1;
 }
-if (!empty(mres($_POST['multiplier'])) && is_numeric(mres($_POST['multiplier']))) {
-    $multiplier     = mres($_POST['multiplier']);
+if (! empty(mres($_POST['multiplier'])) && is_numeric(mres($_POST['multiplier']))) {
+    $multiplier = mres($_POST['multiplier']);
 } else {
-    $multiplier     = 1;
+    $multiplier = 1;
 }
-if (!empty(mres($_POST['user_func']))) {
+if (! empty(mres($_POST['user_func']))) {
     $user_func = mres($_POST['user_func']);
 } else {
-    $user_func = array('NULL');
+    $user_func = ['NULL'];
 }
 
-if ($action == "test") {
-    $query = "SELECT * FROM `devices` WHERE `device_id` = ? LIMIT 1";
+if ($action == 'test') {
+    $query = 'SELECT * FROM `devices` WHERE `device_id` = ? LIMIT 1';
     $device = dbFetchRow($query, [$device_id]);
 
     $rawdata = snmp_get($device, $oid, '-Oqv');
 
     if (is_numeric($rawdata)) {
         if (dbUpdate(
-            array(
+            [
                 'customoid_passed' => 1,
-            ),
+            ],
             'customoids',
             'customoid_id=?',
-            array($id)
+            [$id]
         ) >= 0) {
             $message = "Test successful for <i>$name</i>, value $rawdata received";
         } else {
-            $status   = 'error';
+            $status = 'error';
             $message = "Failed to set pass on OID <i>$name</i>";
         }
     } else {
-        $status  = 'error';
+        $status = 'error';
         $message = "Invalid data in SNMP reply, value $rawdata received";
     }
 } else {
     if (is_numeric($id) && $id > 0) {
         if (dbUpdate(
-            array(
+            [
                 'customoid_descr'          => $name,
                 'customoid_oid'            => $oid,
                 'customoid_datatype'       => $datatype,
@@ -111,28 +111,28 @@ if ($action == "test") {
                 'customoid_limit_low_warn' => $limit_low_warn,
                 'customoid_alert'          => $alerts,
                 'customoid_passed'         => $passed,
-                'user_func'                => $user_func
-            ),
+                'user_func'                => $user_func,
+            ],
             'customoids',
-            "`customoid_id` = ?",
-            array($id)
+            '`customoid_id` = ?',
+            [$id]
         ) >= 0) { //end if condition
             $message = "Edited OID: <i>$name</i>";
         } else {
-            $status   = 'error';
+            $status = 'error';
             $message = "Failed to edit OID <i>$name</i>";
         }
     } else {
         if (empty($name)) {
-            $status  = 'error';
+            $status = 'error';
             $message = 'No OID name provided';
         } else {
-            if (dbFetchCell('SELECT 1 FROM `customoids` WHERE `customoid_descr` = ? AND `device_id`=?', array($name, $device_id))) {
+            if (dbFetchCell('SELECT 1 FROM `customoids` WHERE `customoid_descr` = ? AND `device_id`=?', [$name, $device_id])) {
                 $status = 'error';
                 $message = "OID named <i>$name</i> on this device already exists";
             } else {
                 $id = dbInsert(
-                    array(
+                    [
                         'device_id'                => $device_id,
                         'customoid_descr'          => $name,
                         'customoid_oid'            => $oid,
@@ -146,8 +146,8 @@ if ($action == "test") {
                         'customoid_limit_low_warn' => $limit_low_warn,
                         'customoid_alert'          => $alerts,
                         'customoid_passed'         => $passed,
-                        'user_func'                => $user_func
-                    ),
+                        'user_func'                => $user_func,
+                    ],
                     'customoids'
                 );
                 if ($id) {
@@ -161,7 +161,7 @@ if ($action == "test") {
     }
 }
 
-die(json_encode([
+exit(json_encode([
     'status'       => $status,
     'message'      => $message,
 ]));
