@@ -18,41 +18,38 @@
  * @author Daniel Preussker
  * @copyright 2015 Daniel Preussker, QuxLabs UG
  * @license GPL
- * @package LibreNMS
- * @subpackage Dashboards
  */
-
 header('Content-type: application/json');
 
-if (!Auth::check()) {
-    $response = array(
+if (! Auth::check()) {
+    $response = [
         'status'  => 'error',
         'message' => 'Unauthenticated',
-    );
+    ];
     echo _json_encode($response);
     exit;
 }
 
-$status    = 'error';
-$message   = 'unknown error';
+$status = 'error';
+$message = 'unknown error';
 
-$dashboard_id = (int)$_REQUEST['dashboard_id'];
+$dashboard_id = (int) $_REQUEST['dashboard_id'];
 
 if ($dashboard_id) {
     dbDelete('users_widgets', 'user_id = ? && dashboard_id = ?', [Auth::id(), $dashboard_id]);
     if (dbDelete('dashboards', 'user_id = ? && dashboard_id = ?', [Auth::id(), $dashboard_id])) {
-        $status  = 'ok';
+        $status = 'ok';
         $message = 'Dashboard deleted';
     } else {
-        $message = 'ERROR: Could not delete dashboard '. $dashboard_id;
+        $message = 'ERROR: Could not delete dashboard ' . $dashboard_id;
     }
 } else {
     $message = 'ERROR: Not enough params';
 }
 
-$response = array(
+$response = [
     'status'        => $status,
-    'message'       => $message
-);
+    'message'       => $message,
+];
 
 echo _json_encode($response);
