@@ -11,16 +11,16 @@
  * the source code distribution for details.
  */
 
-if (!Auth::user()->hasGlobalAdmin()) {
-    $status = array('status' =>1, 'message' => 'ERROR: You need to be admin to delete services');
+if (! Auth::user()->hasGlobalAdmin()) {
+    $status = ['status' =>1, 'message' => 'ERROR: You need to be admin to delete services'];
 } else {
-    if (!is_numeric($vars['service_id'])) {
-        $status = array('status' =>1, 'message' => 'No Service has been selected');
+    if (! is_numeric($vars['service_id'])) {
+        $status = ['status' =>1, 'message' => 'No Service has been selected'];
     } else {
         if (delete_service($vars['service_id'])) {
-            $status = array('status' =>0, 'message' => 'Service: <i>'.$vars['service_id'].', has been deleted.</i>');
+            $status = ['status' =>0, 'message' => 'Service: <i>' . $vars['service_id'] . ', has been deleted.</i>'];
         } else {
-            $status = array('status' =>1, 'message' => 'Service: <i>'.$vars['service_id'].', has NOT been deleted.</i>');
+            $status = ['status' =>1, 'message' => 'Service: <i>' . $vars['service_id'] . ', has NOT been deleted.</i>'];
         }
     }
 }
