@@ -18,30 +18,26 @@
  * @author Daniel Preussker
  * @copyright 2015 Daniel Preussker, QuxLabs UG
  * @license GPL
- * @package LibreNMS
- * @subpackage Notifications
  */
-
 header('Content-type: application/json');
 
-if (!isset($_REQUEST['action'])) {
-    die(json_encode([
+if (! isset($_REQUEST['action'])) {
+    exit(json_encode([
         'status' => 'error',
         'message' => 'ERROR: Missing Params',
     ]));
 }
 
-if (in_array($_REQUEST['action'], ['stick', 'unstick', 'create']) && !Auth::user()->hasGlobalAdmin()) {
-    die(json_encode([
+if (in_array($_REQUEST['action'], ['stick', 'unstick', 'create']) && ! Auth::user()->hasGlobalAdmin()) {
+    exit(json_encode([
         'status' => 'error',
         'message' => 'ERROR: Need to be GlobalAdmin or DemoUser',
     ]));
 }
 
-
 if ($_REQUEST['action'] == 'read' && isset($_REQUEST['notification_id'])) {
-    if (dbInsert(['notifications_id'=>$_REQUEST['notification_id'],'user_id'=>Auth::id(),'key'=>'read','value'=>1], 'notifications_attribs')) {
-        die(json_encode([
+    if (dbInsert(['notifications_id'=>$_REQUEST['notification_id'], 'user_id'=>Auth::id(), 'key'=>'read', 'value'=>1], 'notifications_attribs')) {
+        exit(json_encode([
             'status' => 'ok',
             'message' => 'Set as Read',
         ]));
@@ -54,44 +50,44 @@ if ($_REQUEST['action'] == 'read' && isset($_REQUEST['notification_id'])) {
                 'notifications_id' => $notification_id,
                 'user_id' => Auth::id(),
                 'key' => 'read',
-                'value' => 1
+                'value' => 1,
             ],
             'notifications_attribs'
         );
     }
-    die(json_encode([
+    exit(json_encode([
         'status' => 'ok',
         'message' => 'All notifications set as read',
     ]));
 } elseif ($_REQUEST['action'] == 'stick' && isset($_REQUEST['notification_id'])) {
-    if (dbInsert(['notifications_id'=>$_REQUEST['notification_id'],'user_id'=>Auth::id(),'key'=>'sticky','value'=>1], 'notifications_attribs')) {
-        die(json_encode([
+    if (dbInsert(['notifications_id'=>$_REQUEST['notification_id'], 'user_id'=>Auth::id(), 'key'=>'sticky', 'value'=>1], 'notifications_attribs')) {
+        exit(json_encode([
             'status' => 'ok',
             'message' => 'Set as Sticky',
         ]));
     }
 } elseif ($_REQUEST['action'] == 'unstick' && isset($_REQUEST['notification_id'])) {
-    if (dbDelete('notifications_attribs', "notifications_id = ? && user_id = ? AND `key`='sticky'", [$_REQUEST['notification_id'],Auth::id()])) {
-        die(json_encode([
+    if (dbDelete('notifications_attribs', "notifications_id = ? && user_id = ? AND `key`='sticky'", [$_REQUEST['notification_id'], Auth::id()])) {
+        exit(json_encode([
             'status' => 'ok',
             'message' => 'Removed Sticky',
         ]));
     }
-} elseif ($_REQUEST['action'] == 'create' && (!empty($_REQUEST['title']) && !empty($_REQUEST['body']))) {
-    if (dbInsert(['title'=>$_REQUEST['title'],'body'=>$_REQUEST['body'],'checksum'=>hash('sha512', Auth::id().'.LOCAL.'.$_REQUEST['title']),'source'=>Auth::id()], 'notifications')) {
-        die(json_encode([
+} elseif ($_REQUEST['action'] == 'create' && (! empty($_REQUEST['title']) && ! empty($_REQUEST['body']))) {
+    if (dbInsert(['title'=>$_REQUEST['title'], 'body'=>$_REQUEST['body'], 'checksum'=>hash('sha512', Auth::id() . '.LOCAL.' . $_REQUEST['title']), 'source'=>Auth::id()], 'notifications')) {
+        exit(json_encode([
             'status' => 'ok',
             'message' => 'Created',
         ]));
     }
 } else {
-    die(json_encode([
+    exit(json_encode([
         'status' => 'error',
         'message' => 'ERROR: Missing Params',
     ]));
 }
 
-die(json_encode(array(
+exit(json_encode([
     'status'       => 'error',
     'message'      => 'unknown error',
-)));
+]));
