@@ -14,22 +14,22 @@ header('Content-type: application/json');
 
 $device_hostname = clean($_POST['device_hostname']);
 if (Auth::user()->hasGlobalAdmin() && isset($device_hostname)) {
-    if (oxidized_node_update($device_hostname, "LibreNMS GUI refresh", Auth::user()->username)) {
-        $status  = 'ok';
+    if (oxidized_node_update($device_hostname, 'LibreNMS GUI refresh', Auth::user()->username)) {
+        $status = 'ok';
         $message = 'Queued refresh in oxidized for device ' . $device_hostname;
     } else {
-        $status  = 'error';
+        $status = 'error';
         $message = 'ERROR: Could not queue refresh of oxidized device' . $device_hostname;
-    };
+    }
 } else {
-    $status  = 'error';
+    $status = 'error';
     $message = 'ERROR: Could not queue refresh oxidized device';
 }
 
-$output = array(
+$output = [
     'status'  => $status,
     'message' => $message,
-);
+];
 
 header('Content-type: application/json');
 echo _json_encode($output);
