@@ -14,28 +14,28 @@
 
 header('Content-type: application/json');
 
-if (!Auth::user()->hasGlobalAdmin()) {
-    $response = array(
+if (! Auth::user()->hasGlobalAdmin()) {
+    $response = [
         'status'  => 'error',
         'message' => 'Need to be admin',
-    );
+    ];
     echo _json_encode($response);
     exit;
 }
 
-$status  = 'error';
+$status = 'error';
 $message = 'Error updating routing information';
 
 $device_id = $_POST['device_id'];
 $routing_id = $_POST['routing_id'];
 $data = $_POST['data'];
 
-if (!is_numeric($device_id)) {
+if (! is_numeric($device_id)) {
     $message = 'Missing device id';
-} elseif (!is_numeric($routing_id)) {
+} elseif (! is_numeric($routing_id)) {
     $message = 'Missing routing id';
 } else {
-    if (dbUpdate(array('bgpPeerDescr'=>$data), 'bgpPeers', '`bgpPeer_id`=? AND `device_id`=?', array($routing_id,$device_id)) >= 0) {
+    if (dbUpdate(['bgpPeerDescr'=>$data], 'bgpPeers', '`bgpPeer_id`=? AND `device_id`=?', [$routing_id, $device_id]) >= 0) {
         $message = 'Routing information updated';
         $status = 'ok';
     } else {
@@ -43,9 +43,9 @@ if (!is_numeric($device_id)) {
     }
 }
 
-$response = array(
+$response = [
     'status'        => $status,
     'message'       => $message,
     'extra'         => $extra,
-);
+];
 echo _json_encode($response);
