@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * @package    LibreNMS
  * @link       http://librenms.org
  * @copyright  2018 Neil Lathwood
  * @author     Neil Lathwood <gh+n@laf.io>
@@ -28,8 +27,8 @@ use LibreNMS\Config;
 
 header('Content-type: application/json');
 
-if (!Auth::user()->hasGlobalAdmin()) {
-    die(json_encode([
+if (! Auth::user()->hasGlobalAdmin()) {
+    exit(json_encode([
         'status' => 'error',
         'message' => 'ERROR: You need to be admin',
     ]));
@@ -52,15 +51,15 @@ if (is_numeric($template_id)) {
         'status' => 'ok',
         'name' => $rule['name'],
         'builder' => $rule['builder'] ?: QueryBuilderParser::fromOld($rule['rule'])->toArray(),
-        'extra' => array_replace($default_extra, (array)$rule['extra']),
+        'extra' => array_replace($default_extra, (array) $rule['extra']),
         'severity' => $rule['severity'] ?: Config::get('alert_rule.severity'),
-        'invert_map' => Config::get('alert_rule.invert_map')
+        'invert_map' => Config::get('alert_rule.invert_map'),
     ];
 } else {
     $output = [
         'status' => 'error',
-        'message' => 'Invalid template'
+        'message' => 'Invalid template',
     ];
 }
 
-die(json_encode($output));
+exit(json_encode($output));
