@@ -14,30 +14,30 @@
 
 header('Content-type: application/json');
 
-if (!Auth::user()->hasGlobalAdmin()) {
-    $response = array(
+if (! Auth::user()->hasGlobalAdmin()) {
+    $response = [
         'status'  => 'error',
         'message' => 'Need to be admin',
-    );
+    ];
     echo _json_encode($response);
     exit;
 }
 
-$status  = 'error';
+$status = 'error';
 $message = 'Error updating storage information';
 
 $device_id = mres($_POST['device_id']);
 $storage_id = mres($_POST['storage_id']);
 $data = mres($_POST['data']);
 
-if (!is_numeric($device_id)) {
+if (! is_numeric($device_id)) {
     $message = 'Missing device id';
-} elseif (!is_numeric($storage_id)) {
+} elseif (! is_numeric($storage_id)) {
     $message = 'Missing storage id';
-} elseif (!is_numeric($data)) {
+} elseif (! is_numeric($data)) {
     $message = 'Missing value';
 } else {
-    if (dbUpdate(array('storage_perc_warn'=>$data), 'storage', '`storage_id`=? AND `device_id`=?', array($storage_id,$device_id)) >= 0) {
+    if (dbUpdate(['storage_perc_warn'=>$data], 'storage', '`storage_id`=? AND `device_id`=?', [$storage_id, $device_id]) >= 0) {
         $message = 'Storage information updated';
         $status = 'ok';
     } else {
@@ -45,9 +45,9 @@ if (!is_numeric($device_id)) {
     }
 }
 
-$response = array(
+$response = [
     'status'        => $status,
     'message'       => $message,
     'extra'         => $extra,
-);
+];
 echo _json_encode($response);
