@@ -21,30 +21,30 @@
 require 'includes/html/graphs/common.inc.php';
 $name = 'exim-stats';
 $app_id = $app['app_id'];
-$scale_min     = 0;
-$colours       = 'mixed';
-$unit_text     = 'Queue';
-$unitlen       = 18;
-$bigdescrlen   = 18;
+$scale_min = 0;
+$colours = 'mixed';
+$unit_text = 'Queue';
+$unitlen = 18;
+$bigdescrlen = 18;
 $smalldescrlen = 18;
-$dostack       = 0;
-$printtotal    = 0;
-$addarea       = 1;
-$transparency  = 33;
+$dostack = 0;
+$printtotal = 0;
+$addarea = 1;
+$transparency = 33;
 
-$rrd_filename = rrd_name($device['hostname'], array('app', $name, $app_id));
+$rrd_filename = rrd_name($device['hostname'], ['app', $name, $app_id]);
 
-$array = array(
-    'queue' => array('descr' => 'Queue emails','colour' => 'c13a38',),
-);
+$array = [
+    'queue' => ['descr' => 'Queue emails', 'colour' => 'c13a38'],
+];
 
 $i = 0;
 if (rrdtool_check_rrd_exists($rrd_filename)) {
     foreach ($array as $ds => $var) {
         $rrd_list[$i]['filename'] = $rrd_filename;
-        $rrd_list[$i]['descr']    = $var['descr'];
-        $rrd_list[$i]['ds']       = $ds;
-        $rrd_list[$i]['colour']   = $var['colour'];
+        $rrd_list[$i]['descr'] = $var['descr'];
+        $rrd_list[$i]['ds'] = $ds;
+        $rrd_list[$i]['colour'] = $var['colour'];
         $i++;
     }
 } else {
