@@ -4,25 +4,25 @@ require 'memcached.inc.php';
 require 'includes/html/graphs/common.inc.php';
 
 $scale_min = 0;
-$colours   = 'mixed';
-$nototal   = 0;
+$colours = 'mixed';
+$nototal = 0;
 $unit_text = 'Items';
-$array     = array(
-    'curr_items' => array(
+$array = [
+    'curr_items' => [
         'descr'  => 'Items',
         'colour' => '555555',
-    ),
-);
+    ],
+];
 
 $i = 0;
 
 if (rrdtool_check_rrd_exists($rrd_filename)) {
     foreach ($array as $ds => $var) {
         $rrd_list[$i]['filename'] = $rrd_filename;
-        $rrd_list[$i]['descr']    = $var['descr'];
-        $rrd_list[$i]['ds']       = $ds;
-        $rrd_list[$i]['colour']   = $var['colour'];
-        if (!empty($var['areacolour'])) {
+        $rrd_list[$i]['descr'] = $var['descr'];
+        $rrd_list[$i]['ds'] = $ds;
+        $rrd_list[$i]['colour'] = $var['colour'];
+        if (! empty($var['areacolour'])) {
             $rrd_list[$i]['areacolour'] = $var['areacolour'];
         }
 
