@@ -2,15 +2,15 @@
 
 require 'includes/html/graphs/common.inc.php';
 
-$mysql_rrd = rrd_name($device['hostname'], array('app', 'mysql', $app['app_id']));
+$mysql_rrd = rrd_name($device['hostname'], ['app', 'mysql', $app['app_id']]);
 
 if (rrdtool_check_rrd_exists($mysql_rrd)) {
     $rrd_filename = $mysql_rrd;
 }
 
-$rrd_options .= ' DEF:a='.$rrd_filename.':IDBLBSe:AVERAGE ';
-$rrd_options .= ' DEF:b='.$rrd_filename.':IBLFh:AVERAGE ';
-$rrd_options .= ' DEF:c='.$rrd_filename.':IBLWn:AVERAGE ';
+$rrd_options .= ' DEF:a=' . $rrd_filename . ':IDBLBSe:AVERAGE ';
+$rrd_options .= ' DEF:b=' . $rrd_filename . ':IBLFh:AVERAGE ';
+$rrd_options .= ' DEF:c=' . $rrd_filename . ':IBLWn:AVERAGE ';
 
 $rrd_options .= 'COMMENT:"            Current    Average   Maximum\n" ';
 
