@@ -14,32 +14,32 @@
 */
 
 require 'includes/html/graphs/common.inc.php';
-$scale_min     = 0;
-$colours       = 'mixed';
-$unit_text     = 'NFS v4 Stats';
-$unitlen       = 10;
-$bigdescrlen   = 15;
+$scale_min = 0;
+$colours = 'mixed';
+$unit_text = 'NFS v4 Stats';
+$unitlen = 10;
+$bigdescrlen = 15;
 $smalldescrlen = 15;
-$dostack       = 0;
-$printtotal    = 0;
-$addarea       = 1;
-$transparency  = 33;
+$dostack = 0;
+$printtotal = 0;
+$addarea = 1;
+$transparency = 33;
 
-$rrd_filename  = rrd_name($device['hostname'], array('app', 'nfs-server-proc4', $app['app_id']));
+$rrd_filename = rrd_name($device['hostname'], ['app', 'nfs-server-proc4', $app['app_id']]);
 
-$array         = array(
-                     'proc4_null' => array('descr' => 'Null','colour' => '630606'), // these should be very low
-                     'proc4_compound' => array('descr' => 'Compound','colour' => '50C150') // basically this are 1 or more ops
-                );
+$array = [
+    'proc4_null' => ['descr' => 'Null', 'colour' => '630606'], // these should be very low
+    'proc4_compound' => ['descr' => 'Compound', 'colour' => '50C150'], // basically this are 1 or more ops
+];
 
 $i = 0;
 
 if (rrdtool_check_rrd_exists($rrd_filename)) {
     foreach ($array as $ds => $var) {
         $rrd_list[$i]['filename'] = $rrd_filename;
-        $rrd_list[$i]['descr']    = $var['descr'];
-        $rrd_list[$i]['ds']       = $ds;
-        $rrd_list[$i]['colour']   = $var['colour'];
+        $rrd_list[$i]['descr'] = $var['descr'];
+        $rrd_list[$i]['ds'] = $ds;
+        $rrd_list[$i]['colour'] = $var['colour'];
         $i++;
     }
 } else {
