@@ -1,46 +1,47 @@
 <?php
+
 $name = 'postfix';
 $app_id = $app['app_id'];
-$scale_min     = 0;
-$colours       = 'mixed';
-$unit_text     = 'Messages';
-$unitlen       = 11;
-$bigdescrlen   = 11;
+$scale_min = 0;
+$colours = 'mixed';
+$unit_text = 'Messages';
+$unitlen = 11;
+$bigdescrlen = 11;
 $smalldescrlen = 11;
-$dostack       = 0;
-$printtotal    = 0;
-$addarea       = 1;
-$transparency  = 15;
+$dostack = 0;
+$printtotal = 0;
+$addarea = 1;
+$transparency = 15;
 
-$rrd_filename = rrd_name($device['hostname'], array('app', $name, $app_id));
+$rrd_filename = rrd_name($device['hostname'], ['app', $name, $app_id]);
 
 if (rrdtool_check_rrd_exists($rrd_filename)) {
-    $rrd_list = array(
-        array(
+    $rrd_list = [
+        [
             'filename' => $rrd_filename,
             'descr'    => 'Senders',
             'ds'       => 'senders',
-            'colour'   => '582A72'
-        ),
-        array(
+            'colour'   => '582A72',
+        ],
+        [
             'filename' => $rrd_filename,
             'descr'    => 'Sending H/D',
             'ds'       => 'sendinghd',
-            'colour'   => '28774F'
-        ),
-        array(
+            'colour'   => '28774F',
+        ],
+        [
             'filename' => $rrd_filename,
             'descr'    => 'Recipients',
             'ds'       => 'recipients',
-            'colour'   => '88CC88'
-        ),
-        array(
+            'colour'   => '88CC88',
+        ],
+        [
             'filename' => $rrd_filename,
             'descr'    => 'Recip H/D',
             'ds'       => 'recipienthd',
-            'colour'   => 'D46A6A'
-        )
-    );
+            'colour'   => 'D46A6A',
+        ],
+    ];
 } else {
     echo "file missing: $rrd_filename";
 }
