@@ -24,21 +24,21 @@ $dostack = 0;
 $printtotal = 0;
 $addarea = 1;
 $transparency = 33;
-$rrd_filename = rrd_name($device['hostname'], array('app', $app['app_type'], $app['app_id']));
+$rrd_filename = rrd_name($device['hostname'], ['app', $app['app_type'], $app['app_id']]);
 
-$array = array(
-    'downstream_timeout' => array('descr' => 'Timeout', 'colour' => 'BF3F7F',),
-    'downstream_err' => array('descr' => 'Errors', 'colour' => 'BF3F3F',),
-);
+$array = [
+    'downstream_timeout' => ['descr' => 'Timeout', 'colour' => 'BF3F7F'],
+    'downstream_err' => ['descr' => 'Errors', 'colour' => 'BF3F3F'],
+];
 
 $i = 0;
 
 if (rrdtool_check_rrd_exists($rrd_filename)) {
     foreach ($array as $ds => $var) {
         $rrd_list[$i]['filename'] = $rrd_filename;
-        $rrd_list[$i]['descr']    = $var['descr'];
-        $rrd_list[$i]['ds']       = $ds;
-        $rrd_list[$i]['colour']   = $var['colour'];
+        $rrd_list[$i]['descr'] = $var['descr'];
+        $rrd_list[$i]['ds'] = $ds;
+        $rrd_list[$i]['colour'] = $var['colour'];
         $i++;
     }
 } else {
